@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -30,93 +30,17 @@
 #include <gmerlin/plugin.h>
 #include <gmerlin/pluginregistry.h>
 #include <gmerlin/filters.h>
+#include <gmerlin/translation.h>
 
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "webcam"
 
 #include "webcam.h"
+#include "webcam_priv.h"
 
-#ifdef HAVE_V4L
-#include <vloopback.h>
-#endif
 
 #define FRAMERATE_INTERVAL 10
 
-struct gmerlin_webcam_s
-  {
-  gavl_video_frame_t     * monitor_frame;
-  gavl_video_converter_t * monitor_cnv;
-  bg_plugin_handle_t     * monitor_handle;
-  bg_ov_plugin_t         * monitor;
-
-  gavl_video_frame_t       * capture_frame;
-  gavl_video_converter_t   * capture_cnv;
-  bg_plugin_handle_t       * capture_handle;
-  bg_image_writer_plugin_t * capture;
-  
-  int do_convert_monitor;
-  int do_convert_capture;
-  
-  int do_monitor;
-  
-  int monitor_open;
-  int input_open;
-  int capture_open;
-
-  int capture_initialized;
-
-  gavl_timer_t * timer;
-  gavl_time_t next_capture_time;
-  gavl_time_t capture_interval;
-  
-  int auto_capture;
-  
-  uint32_t capture_frame_counter;
-
-  uint32_t frame_counter;
-
-  gavl_video_format_t cam_format;
-  
-  gavl_video_format_t input_format;
-  gavl_video_format_t monitor_format;
-  gavl_video_format_t capture_format;
-  
-  bg_plugin_handle_t * input_handle;
-
-  bg_recorder_plugin_t     * input;
-  
-  gavl_video_frame_t * input_frame;
-
-  pthread_t thread;
-  pthread_mutex_t mutex;
-
-  bg_msg_queue_t * cmd_queue;
-  bg_msg_queue_t * msg_queue;
-
-  char * capture_directory;
-  char * capture_namebase;
-  
-  bg_video_filter_chain_t * fc;
-
-  bg_plugin_registry_t * plugin_reg;
-
-  bg_gavl_video_options_t opt;
-  
-  int do_quit;
-
-  bg_read_video_func_t read_func;
-  void * read_data;
-  int read_stream;
-
-  int running;
-  int interrupted;
-
-#ifdef HAVE_V4L
-  bg_vloopback_t * vloopback;
-  int do_vloopback;
-  pthread_mutex_t vloopback_mutex;
-#endif  
-  };
 
 static int read_func(void * data, gavl_video_frame_t * f, int stream)
   {
@@ -300,9 +224,6 @@ static char * create_filename(gmerlin_webcam_t * cam)
       pos++;
       }
     }
-
-  filename =
-    bg_strcat(filename, cam->capture->get_extension(cam->capture_handle->priv));
   
   return filename;
   }
@@ -356,7 +277,7 @@ static void do_capture(gmerlin_webcam_t * cam)
   cam->capture->write_image(cam->capture_handle->priv, cam->capture_frame);
 
   /* Update capture frame counter */
-    
+  
   cam->capture_frame_counter++;
   msg = bg_msg_queue_lock_write(cam->msg_queue);
   bg_msg_set_id(msg, MSG_FRAME_COUNT);
@@ -526,10 +447,13 @@ static void handle_cmd(gmerlin_webcam_t * cam, bg_msg_t * msg)
         open_monitor(cam);
       break;
     case CMD_SET_INPUT_PLUGIN:          /* ARG0: plugin_handle */
+      if(cam->do_monitor)
+        close_monitor(cam);
+      
       if(cam->input)
         {
-        bg_plugin_unref(cam->input_handle);
         close_input(cam);
+        bg_plugin_unref(cam->input_handle);
         }
       h = bg_msg_get_arg_ptr_nocopy(msg, 0);
       cam->input_handle = h;
@@ -538,6 +462,10 @@ static void handle_cmd(gmerlin_webcam_t * cam, bg_msg_t * msg)
 
       cam->input = (bg_recorder_plugin_t*)cam->input_handle->plugin;
       open_input(cam);
+
+      if(cam->do_monitor)
+        open_monitor(cam);
+      
       break;
     case CMD_INPUT_REOPEN:
       if(cam->do_monitor)
@@ -661,7 +589,7 @@ static void * thread_func(void * data)
         bg_vloopback_put_frame(w->vloopback, w->input_frame);
       pthread_mutex_unlock(&w->vloopback_mutex);
 #endif      
-      /* Caculate framerate */
+      /* Calculate framerate */
       
       w->frame_counter++;
       if(w->frame_counter == FRAMERATE_INTERVAL)
@@ -720,7 +648,8 @@ void gmerlin_webcam_quit(gmerlin_webcam_t * w)
   }
 
 
-const bg_parameter_info_t * gmerlin_webcam_get_filter_parameters(gmerlin_webcam_t * w)
+const bg_parameter_info_t *
+gmerlin_webcam_get_filter_parameters(gmerlin_webcam_t * w)
   {
   return bg_video_filter_chain_get_parameters(w->fc);
   }
@@ -798,3 +727,34 @@ void gmerlin_webcam_set_vloopback_parameter(void * data, const char * name,
   pthread_mutex_unlock(&w->vloopback_mutex);
   }
 #endif
+
+static const bg_parameter_info_t parameters[] =
+  {
+    {
+      .name = "video_capture",
+      .long_name = TRS("Video capture"),
+      .type = BG_PARAMETER_SECTION,
+    },
+    {
+      .name      = "max_framerate",
+      .long_name = TRS("Maximum framerate"),
+      .type      = BG_PARAMETER_INT,
+      .val_min       = { .val_i = 1 },
+      .val_max       = { .val_i = 100 },
+      .val_default   = { .val_i = 25 },
+    },
+    { /* End */ }
+  };
+
+const bg_parameter_info_t *
+gmerlin_webcam_get_parameters(gmerlin_webcam_t * w)
+  {
+  return parameters;
+  }
+
+void
+gmerlin_webcam_set_parameter(void * data, const char * name,
+                             const bg_parameter_value_t * val)
+  {
+  
+  }
