@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -73,3 +73,11 @@ const bg_parameter_info_t * gmerlin_webcam_get_vloopback_parameters(gmerlin_webc
 void gmerlin_webcam_set_vloopback_parameter(void * data, const char * name,
                                             const bg_parameter_value_t * val);
 #endif
+
+const bg_parameter_info_t *
+gmerlin_webcam_get_parameters(gmerlin_webcam_t * w);
+
+void
+gmerlin_webcam_set_parameter(void * data, const char * name,
+                             const bg_parameter_value_t * val);
+
