@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -102,7 +102,7 @@ static void set_input_plugin(const bg_plugin_info_t * info, void * data)
   bg_plugin_handle_t * h;
   w = (gmerlin_webcam_window_t *)data;
   h = bg_gtk_plugin_widget_single_load_plugin(w->input_plugin);
-  bg_plugin_registry_set_default(w->plugin_reg, BG_PLUGIN_RECORDER_VIDEO, info->name);
+  bg_plugin_registry_set_default(w->plugin_reg, BG_PLUGIN_RECORDER_VIDEO, BG_PLUGIN_RECORDER, info->name);
 
   msg = bg_msg_queue_lock_write(w->cmd_queue);
   bg_msg_set_id(msg, CMD_SET_INPUT_PLUGIN);
@@ -119,7 +119,7 @@ static void set_capture_plugin(const bg_plugin_info_t * info, void *  data)
   bg_plugin_handle_t * h;
   w = (gmerlin_webcam_window_t *)data;
   h = bg_gtk_plugin_widget_single_load_plugin(w->capture_plugin);
-  bg_plugin_registry_set_default(w->plugin_reg, BG_PLUGIN_IMAGE_WRITER, info->name);
+  bg_plugin_registry_set_default(w->plugin_reg, BG_PLUGIN_IMAGE_WRITER, BG_PLUGIN_FILE, info->name);
   
   msg = bg_msg_queue_lock_write(w->cmd_queue);
   bg_msg_set_id(msg, CMD_SET_CAPTURE_PLUGIN);
@@ -132,10 +132,40 @@ static void set_monitor_plugin(const bg_plugin_info_t * info, void *  data)
   bg_msg_t * msg;
   gmerlin_webcam_window_t * w;
   bg_plugin_handle_t * h;
+  bg_ov_plugin_t * p;
+
   w = (gmerlin_webcam_window_t *)data;
   h = bg_gtk_plugin_widget_single_load_plugin(w->monitor_plugin);
-  bg_plugin_registry_set_default(w->plugin_reg, BG_PLUGIN_OUTPUT_VIDEO, info->name);
-                                 
+  bg_plugin_registry_set_default(w->plugin_reg, 
+                                 BG_PLUGIN_OUTPUT_VIDEO, BG_PLUGIN_PLAYBACK,
+                                 info->name);
+  p = (bg_ov_plugin_t*)h->plugin;
+  if(p->set_window_options)
+    {
+    gavl_video_frame_t * icon = NULL;
+    gavl_video_format_t icon_format;
+    char * icon_path;
+
+    memset(&icon_format, 0, sizeof(icon_format));
+    
+    /* Load icon */
+    icon_path = bg_search_file_read("icons", WINDOW_ICON);
+    if(icon_path)       
+      {
+      icon = 
+        bg_plugin_registry_load_image(w->plugin_reg,
+                                      icon_path,
+                                      &icon_format,
+                                      (bg_metadata_t*)0);
+       }
+    p->set_window_options(h->priv, WINDOW_NAME, WINDOW_CLASS, 
+                          icon, &icon_format);
+    if(icon)
+      gavl_video_frame_destroy(icon);
+    if(icon_path)
+      free(icon_path);
+    }
+
   msg = bg_msg_queue_lock_write(w->cmd_queue);
   bg_msg_set_id(msg, CMD_SET_MONITOR_PLUGIN);
   bg_msg_set_arg_ptr_nocopy(msg, 0, h);
@@ -390,7 +420,7 @@ gmerlin_webcam_window_create(gmerlin_webcam_t * w,
                                     &(ret->msg_queue));
   
   ret->plugin_reg = reg;
-    
+  
   ret->win = bg_gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
   gtk_window_set_title(GTK_WINDOW(ret->win), "Camelot-"VERSION);
