@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -21,6 +21,10 @@
 
 typedef struct gmerlin_webcam_window_s gmerlin_webcam_window_t;
 
+#define WINDOW_NAME  "Camelot"
+#define WINDOW_CLASS "camelot"
+#define WINDOW_ICON "camelot_icon.png"
+
 gmerlin_webcam_window_t *
 gmerlin_webcam_window_create(gmerlin_webcam_t * w,
                              bg_plugin_registry_t * reg,
