@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -790,6 +790,7 @@ static int handle_message(bg_player_t * player,
           bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Player now seeking");
           break;
         case BG_PLAYER_STATE_CHANGING:
+        case BG_PLAYER_STATE_EOF:
           bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Player now changing");
           if(time_active) { putc('\n', stderr); time_active = 0; }
           
@@ -806,9 +807,6 @@ static int handle_message(bg_player_t * player,
           break;
         case BG_PLAYER_STATE_PAUSED:
           break;
-        case BG_PLAYER_STATE_FINISHING:
-          bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Player finishing");
-          break;
         }
       break;
     case BG_PLAYER_MSG_TRACK_CHANGED:
@@ -974,7 +972,7 @@ int main(int argc, char ** argv)
   if(!oa_handle)
     {
     info = bg_plugin_registry_get_default(plugin_reg,
-                                          BG_PLUGIN_OUTPUT_AUDIO);
+                                          BG_PLUGIN_OUTPUT_AUDIO, BG_PLUGIN_PLAYBACK);
 
     if(info)
       {
@@ -989,7 +987,7 @@ int main(int argc, char ** argv)
   if(!ov_info)
     {
     ov_info = bg_plugin_registry_get_default(plugin_reg,
-                                             BG_PLUGIN_OUTPUT_VIDEO);
+                                             BG_PLUGIN_OUTPUT_VIDEO, BG_PLUGIN_PLAYBACK);
     }
 
   if(ov_info)
