@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -45,7 +45,7 @@ static bg_accelerator_t accels[] =
     { BG_KEY_RIGHT,   BG_KEY_CONTROL_MASK,                     ACCEL_SEEK_FORWARD            },
     { BG_KEY_0,       0,                                       ACCEL_SEEK_START              },
     { BG_KEY_SPACE,   0,                                       ACCEL_PAUSE                   },
-    { BG_KEY_M,       0,                                       ACCEL_MUTE                    },
+    { BG_KEY_m,       BG_KEY_CONTROL_MASK,                     ACCEL_MUTE                    },
     { BG_KEY_PAGE_UP, BG_KEY_CONTROL_MASK|BG_KEY_SHIFT_MASK,   ACCEL_NEXT_CHAPTER            },
     { BG_KEY_PAGE_DOWN, BG_KEY_CONTROL_MASK|BG_KEY_SHIFT_MASK, ACCEL_PREV_CHAPTER            },
  
@@ -53,7 +53,6 @@ static bg_accelerator_t accels[] =
     { BG_KEY_PAGE_UP,   BG_KEY_CONTROL_MASK,                   ACCEL_PREV                    },
     { BG_KEY_q,         BG_KEY_CONTROL_MASK,                   ACCEL_QUIT                    },
     { BG_KEY_o,         BG_KEY_CONTROL_MASK,                   ACCEL_OPTIONS                 },
-    { BG_KEY_p,         BG_KEY_CONTROL_MASK,                   ACCEL_PLUGINS                 },
     { BG_KEY_g,         BG_KEY_CONTROL_MASK,                   ACCEL_GOTO_CURRENT            },
     { BG_KEY_F9,        0,                                     ACCEL_CURRENT_TO_FAVOURITES   },
     { BG_KEY_NONE,      0,                                     0                             },
@@ -75,11 +74,11 @@ static void gmerlin_apply_config(gmerlin_t * g)
 
   bg_cfg_section_apply(g->display_section, parameters,
                        display_set_parameter, (void*)(g->player_window->display));
-
+#if 0
   parameters = bg_media_tree_get_parameters(g->tree);
   bg_cfg_section_apply(g->tree_section, parameters,
                        bg_media_tree_set_parameter, (void*)(g->tree));
-
+#endif
   parameters = bg_remote_server_get_parameters(g->remote);
   bg_cfg_section_apply(g->remote_section, parameters,
                        bg_remote_server_set_parameter, (void*)(g->remote));
@@ -205,13 +204,6 @@ static void logwindow_close_callback(bg_gtk_log_window_t * w, void * data)
   g->show_log_window = 0;
   }
 
-static void pluginwindow_close_callback(plugin_window_t * w, void * data)
-  {
-  gmerlin_t * g;
-  g = (gmerlin_t*)data;
-  main_menu_set_plugin_window_item(g->player_window->main_menu, 0);
-  }
-
 static void treewindow_close_callback(bg_gtk_tree_window_t * win,
                                void * data)
   {
@@ -221,6 +213,24 @@ static void treewindow_close_callback(bg_gtk_tree_window_t * win,
   g->show_tree_window = 0;
   }
 
+static const bg_parameter_info_t input_plugin_parameters[] =
+  {
+    {
+      .name = "input_plugins",
+      .long_name = "Input plugins",
+    },
+    { /* */ },
+  };
+
+static const bg_parameter_info_t image_reader_parameters[] =
+  {
+    {
+      .name = "image_readers",
+      .long_name = "Image readers",
+    },
+    { /* */ },
+  };
+
 gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
   {
   int remote_port;
@@ -270,6 +280,21 @@ gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
     bg_cfg_registry_find_section(cfg_reg, "Infowindow");
   ret->visualization_section =
     bg_cfg_registry_find_section(cfg_reg, "Visualization");
+
+  ret->input_plugin_parameters = bg_parameter_info_copy_array(input_plugin_parameters);
+  bg_plugin_registry_set_parameter_info_input(ret->plugin_reg,
+                                              BG_PLUGIN_INPUT,
+                                              BG_PLUGIN_FILE|
+                                              BG_PLUGIN_URL|
+                                              BG_PLUGIN_REMOVABLE|
+                                              BG_PLUGIN_TUNER,
+                                              ret->input_plugin_parameters);
+  
+  ret->image_reader_parameters = bg_parameter_info_copy_array(image_reader_parameters);
+  bg_plugin_registry_set_parameter_info_input(ret->plugin_reg,
+                                              BG_PLUGIN_IMAGE_READER,
+                                              BG_PLUGIN_FILE,
+                                              ret->image_reader_parameters);
   
   /* Log window should be created quite early so we can catch messages
      during startup */
@@ -297,12 +322,17 @@ gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
     }
   
   ret->tree = bg_media_tree_create(tmp_string, ret->plugin_reg);
+  free(tmp_string);
   
   bg_media_tree_set_play_callback(ret->tree, tree_play_callback, ret);
   bg_media_tree_set_userpass_callback(ret->tree, bg_gtk_get_userpass, NULL);
-  
-  free(tmp_string);
 
+  /* Apply tree config */
+  bg_cfg_section_apply(ret->tree_section, bg_media_tree_get_parameters(ret->tree),
+                       bg_media_tree_set_parameter, (void*)(ret->tree));
+
+  bg_media_tree_init(ret->tree);
+  
   /* Start creating the GUI */
 
   ret->accel_group = gtk_accel_group_new();
@@ -324,9 +354,6 @@ gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
                                                infowindow_close_callback, 
                                                ret);
 
-  ret->plugin_window = plugin_window_create(ret,
-                                            pluginwindow_close_callback, 
-                                            ret);
   
   
   ret->lcdproc = bg_lcdproc_create(ret->player);
@@ -366,7 +393,6 @@ gmerlin_t * gmerlin_create(bg_cfg_registry_t * cfg_reg)
 void gmerlin_destroy(gmerlin_t * g)
   {
     
-  plugin_window_destroy(g->plugin_window);
   player_window_destroy(g->player_window);
 
   /* Must destroy the dialogs early, because the
@@ -388,7 +414,9 @@ void gmerlin_destroy(gmerlin_t * g)
   
   bg_gtk_tree_window_destroy(g->tree_window);
 
-
+  bg_parameter_info_destroy_array(g->input_plugin_parameters);
+  bg_parameter_info_destroy_array(g->image_reader_parameters);
+  
   /* Fetch parameters */
   
   bg_cfg_section_get(g->infowindow_section,
@@ -536,9 +564,9 @@ void gmerlin_pause(gmerlin_t * g)
 
 void gmerlin_next_track(gmerlin_t * g)
   {
-  int result, keep_going, removable;
+  int result, keep_going, removable, num_tries = 0, num_entries;
   bg_album_t * album;
-
+  
   if(g->playback_flags & PLAYBACK_NOADVANCE)
     {
     bg_player_stop(g->player);
@@ -549,6 +577,8 @@ void gmerlin_next_track(gmerlin_t * g)
   if(!album)
     return;
 
+  num_entries = bg_album_get_num_entries(album);
+  
   removable = (bg_album_get_type(album) == BG_ALBUM_TYPE_REMOVABLE) ? 1 : 0;
 
   result = 1;
@@ -588,6 +618,13 @@ void gmerlin_next_track(gmerlin_t * g)
           if(result)
             keep_going = 0;
           }
+        
+        num_tries++;
+        if(num_tries >= num_entries)
+          {
+          bg_player_stop(g->player);
+          keep_going = 0;
+          }
         break;
       case  NUM_REPEAT_MODES:
         break;
@@ -747,7 +784,7 @@ static const bg_parameter_info_t parameters[] =
       .long_name =   "Skin Directory",
       .type =        BG_PARAMETER_DIRECTORY,
       .flags =       BG_PARAMETER_HIDE_DIALOG,
-      .val_default = { .val_str = GMERLIN_DATA_DIR"/skins/Default" },
+      .val_default = { .val_str = DATA_DIR"/skins/Default" },
     },
     { /* End of Parameters */ }
   };
