@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -85,7 +85,8 @@ int main(int argc, char ** argv)
   srand(time(NULL));
   
   bg_translation_init();
-  bg_gtk_init(&argc, &argv, "player_icon.png");
+  bg_gtk_init(&argc, &argv, WINDOW_ICON, WINDOW_NAME, 
+              WINDOW_CLASS);
   
   cfg_reg = bg_cfg_registry_create();
   
