@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -20,6 +20,8 @@
  * *****************************************************************/
 
 #include <config.h>
+#include <string.h>
+
 #include <gmerlin/translation.h>
 #include "gmerlin.h"
 #include <gmerlin/utils.h>
@@ -39,7 +41,8 @@ typedef struct
   const bg_plugin_info_t * plugin_info;
   bg_plugin_handle_t * plugin_handle;
   bg_plugin_type_t type;
-
+  uint32_t flags;
+  
   bg_cfg_section_t * section;
   int no_callback;
 
@@ -107,7 +110,6 @@ struct help_menu_s
 struct options_menu_s
   {
   GtkWidget * preferences;
-  GtkWidget * plugins;
   GtkWidget * skins;
   GtkWidget * kbd;
   GtkWidget * menu;
@@ -253,7 +255,7 @@ plugin_menu_set_plugin(plugin_menu_t * s, int index)
                                            s->type, BG_PLUGIN_ALL);
 
   /* Save for future use */
-  bg_plugin_registry_set_default(s->g->plugin_reg, s->type,
+  bg_plugin_registry_set_default(s->g->plugin_reg, s->type, s->flags,
                                  s->plugin_info->name);
   
   if(s->plugin_handle)
@@ -273,7 +275,36 @@ plugin_menu_set_plugin(plugin_menu_t * s, int index)
     }
   else if(s->type == BG_PLUGIN_OUTPUT_VIDEO)
     {
+    bg_ov_plugin_t * plugin;
+
     s->plugin_handle = bg_plugin_load(s->g->plugin_reg, s->plugin_info);
+    plugin = (bg_ov_plugin_t *)s->plugin_handle->plugin;
+    if(plugin->set_window_options)
+      {
+      gavl_video_frame_t * icon = NULL;
+      gavl_video_format_t icon_format;
+      char * icon_path;
+
+      memset(&icon_format, 0, sizeof(icon_format));
+
+      /* Load icon */
+      icon_path = bg_search_file_read("icons", WINDOW_ICON);
+      if(icon_path)
+        {
+        icon = 
+          bg_plugin_registry_load_image(s->g->plugin_reg,
+                                        icon_path,
+                                        &icon_format,
+                                        (bg_metadata_t*)0);
+        }
+      plugin->set_window_options(s->plugin_handle->priv,
+                                 WINDOW_NAME, WINDOW_CLASS,
+                                 icon, &icon_format);
+      if(icon)
+        gavl_video_frame_destroy(icon);
+      if(icon_path)
+        free(icon_path);
+      }
     bg_player_set_ov_plugin(s->g->player, s->plugin_handle);
     }
   else if(s->type == BG_PLUGIN_VISUALIZATION)
@@ -377,11 +408,6 @@ static void menu_callback(GtkWidget * w, gpointer data)
       g->skin_browser = gmerlin_skin_browser_create(g);
     gmerlin_skin_browser_show(g->skin_browser);
     }
-  else if(w == the_menu->options_menu.plugins)
-    {
-    plugin_window_show(g->plugin_window);
-    gtk_widget_set_sensitive(the_menu->options_menu.plugins, 0);
-    }
   else if(w == the_menu->options_menu.kbd)
     {
     system("gmerlin_kbd_config &");
@@ -645,7 +671,7 @@ typedef struct stream_menu_s
 #endif
 
 static void plugin_menu_init(plugin_menu_t * m, gmerlin_t * gmerlin,
-                             bg_plugin_type_t plugin_type)
+                             bg_plugin_type_t plugin_type, uint32_t flags)
   {
   int i;
   const bg_plugin_info_t * info;
@@ -654,6 +680,7 @@ static void plugin_menu_init(plugin_menu_t * m, gmerlin_t * gmerlin,
   GSList * group = (GSList*)0;
 
   m->type = plugin_type;
+  m->flags = flags;
   m->menu = create_menu();
   m->g = gmerlin;
   
@@ -694,7 +721,7 @@ static void plugin_menu_finalize(plugin_menu_t * m)
   const bg_plugin_info_t * info;
   int default_index = 0, i;
   default_info = bg_plugin_registry_get_default(m->g->plugin_reg,
-                                                m->type);
+                                                m->type, m->flags);
 
   m->no_callback = 1;
   for(i = 0; i < m->num_plugins; i++)
@@ -741,7 +768,7 @@ static void stream_menu_init(stream_menu_t * s, gmerlin_t * gmerlin,
     {
     s->plugins = create_pixmap_item(TR("Output plugin..."), "plugin_16.png",
                                     gmerlin, s->menu);
-    plugin_menu_init(&s->plugin_menu, gmerlin, plugin_type);
+    plugin_menu_init(&s->plugin_menu, gmerlin, plugin_type, BG_PLUGIN_PLAYBACK);
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(s->plugins), s->plugin_menu.menu);
     }
   }
@@ -775,7 +802,8 @@ static void visualization_menu_init(visualization_menu_t * s, gmerlin_t * gmerli
   
   s->plugins = create_pixmap_item(TR("Plugin..."), "plugin_16.png",
                                   gmerlin, s->menu);
-  plugin_menu_init(&s->plugin_menu, gmerlin, BG_PLUGIN_VISUALIZATION);
+  plugin_menu_init(&s->plugin_menu, gmerlin, BG_PLUGIN_VISUALIZATION,
+                   BG_PLUGIN_VISUALIZE_FRAME | BG_PLUGIN_VISUALIZE_GL);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(s->plugins), s->plugin_menu.menu);
   
   }
@@ -898,15 +926,8 @@ void main_menu_set_audio_info(main_menu_t * m, int stream,
   {
   char * label;
   GtkWidget * w;
-  if(info && language && *language)
-    label = bg_sprintf("%s [%s]", info, bg_get_language_name(language));
-  else if(info)
-    label = bg_sprintf("%s", info);
-  else if(language && *language)
-    label = bg_sprintf(TR("Stream %d [%s]"), stream+1, bg_get_language_name(language));
-  else
-    label = bg_sprintf(TR("Stream %d"), stream+1);
-
+  
+  label = bg_get_stream_label(stream, info, language);
   w = m->audio_stream_menu.stream_items[stream];
   gtk_label_set_text(GTK_LABEL(gtk_bin_get_child(GTK_BIN(w))), label);
   free(label);
@@ -1046,12 +1067,6 @@ main_menu_t * main_menu_create(gmerlin_t * gmerlin)
                              GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   
-
-  ret->options_menu.plugins =
-    create_pixmap_item(TR("Input plugins..."), "plugin_16.png", gmerlin, ret->options_menu.menu);
-  gtk_widget_add_accelerator(ret->options_menu.plugins, "activate", ret->g->accel_group,
-                             GDK_p, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
   ret->options_menu.skins =
     create_item(TR("Skins..."), gmerlin, ret->options_menu.menu);
 
@@ -1274,7 +1289,3 @@ void main_menu_set_log_window_item(main_menu_t * m, int state)
                            m->windows_menu.logwindow_id);
   }
 
-void main_menu_set_plugin_window_item(main_menu_t * m, int state)
-  {
-  gtk_widget_set_sensitive(m->options_menu.plugins, !state);
-  }
