@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -235,14 +235,26 @@ static gboolean motion_callback(GtkWidget * w, GdkEventMotion * evt,
 static void seek_change_callback(bg_gtk_slider_t * slider, float perc,
                                  void * data)
   {
+  gavl_time_t time;
   player_window_t * win = (player_window_t *)data;
+  
+  time = (gavl_time_t)(perc * (double)win->duration);
 
-  win->seek_active = 1;
+  if(!win->seek_active)
+    {
+    if(win->gmerlin->player_state == BG_PLAYER_STATE_PAUSED)
+      win->seek_active = 2;
+    else
+      {
+      win->seek_active = 1;
+      bg_player_pause(win->gmerlin->player);
+      }
+    }
   
   //  player_window_t * win = (player_window_t *)data;
 
-  display_set_time(win->display, (gavl_time_t)(perc *
-                                               (float)win->duration + 0.5));
+  bg_player_seek(win->gmerlin->player, time, GAVL_TIME_SCALE);
+  display_set_time(win->display, time);
   }
 
 static void seek_release_callback(bg_gtk_slider_t * slider, float perc,
@@ -254,8 +266,10 @@ static void seek_release_callback(bg_gtk_slider_t * slider, float perc,
   time = (gavl_time_t)(perc * (double)win->duration);
   
   //  player_window_t * win = (player_window_t *)data;
-  bg_player_seek(win->gmerlin->player, time);
-  
+  bg_player_seek(win->gmerlin->player, time, GAVL_TIME_SCALE);
+
+  if(win->seek_active == 1)
+    bg_player_pause(win->gmerlin->player);
   }
 
 static void
@@ -402,7 +416,6 @@ static void handle_message(player_window_t * win,
           break;
         case BG_PLAYER_STATE_SEEKING:
           display_set_state(win->display, win->gmerlin->player_state, NULL);
-          win->seek_active = 0;
           break;
         case BG_PLAYER_STATE_ERROR:
           bg_gtk_log_window_flush(win->gmerlin->log_window);
@@ -416,6 +429,7 @@ static void handle_message(player_window_t * win,
         case BG_PLAYER_STATE_PLAYING:
           display_set_state(win->display, win->gmerlin->player_state, NULL);
           bg_media_tree_mark_error(win->gmerlin->tree, 0);
+          win->seek_active = 0;
           break;
         case BG_PLAYER_STATE_STOPPED:
           bg_gtk_slider_set_state(win->seek_slider,
@@ -428,6 +442,10 @@ static void handle_message(player_window_t * win,
           if(arg_i_2)
             gmerlin_next_track(win->gmerlin);
           break;
+        case BG_PLAYER_STATE_EOF:
+          display_set_state(win->display, win->gmerlin->player_state, NULL);
+          gmerlin_next_track(win->gmerlin);
+          break;
         }
       break;
     case BG_PLAYER_MSG_TRACK_NAME:
@@ -473,7 +491,7 @@ static void handle_message(player_window_t * win,
           bg_player_seek_rel(win->gmerlin->player,   2 * GAVL_TIME_SCALE );
           break;
         case ACCEL_SEEK_START:
-          bg_player_seek(win->gmerlin->player,   0 );
+          bg_player_seek(win->gmerlin->player,0, GAVL_TIME_SCALE );
           break;
         case ACCEL_PAUSE:
           bg_player_pause(win->gmerlin->player);
@@ -509,10 +527,6 @@ static void handle_message(player_window_t * win,
         case ACCEL_GOTO_CURRENT:
           bg_gtk_tree_window_goto_current(win->gmerlin->tree_window);
           break;
-        case ACCEL_PLUGINS:
-          plugin_window_show(win->gmerlin->plugin_window);
-          main_menu_set_plugin_window_item(win->main_menu, 1);
-          break;
         }
       break;
     case BG_PLAYER_MSG_TRACK_DURATION:
@@ -565,7 +579,6 @@ static void handle_message(player_window_t * win,
       main_menu_set_video_info(win->main_menu, arg_i_1, arg_str_1, arg_str_2);
       if(arg_str_1) free(arg_str_1);
       if(arg_str_2) free(arg_str_2);
-      
       break;
     case BG_PLAYER_MSG_SUBTITLE_STREAM_INFO:
       arg_i_1 = bg_msg_get_arg_int(msg, 0);
