@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -125,7 +125,7 @@ static skin_info_t * skin_info_create()
 
   skin_info_t * ret_end;
 
-  directory = bg_sprintf("%s/%s", GMERLIN_DATA_DIR, "skins");
+  directory = bg_sprintf("%s/%s", DATA_DIR, "skins");
 
   system_skins = scan_directory(directory);
   free(directory);
