@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -140,7 +140,8 @@ static void set_video_encoder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
 
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_VIDEO|BG_PLUGIN_ENCODER, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg,
+                                 BG_PLUGIN_ENCODER_VIDEO|BG_PLUGIN_ENCODER, BG_PLUGIN_FILE | BG_PLUGIN_BROADCAST, info->name);
 
   if(!info->max_audio_streams)
     {
@@ -186,55 +187,55 @@ static void set_video_encoder(const bg_plugin_info_t * info, void * data)
 static void set_audio_encoder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_AUDIO, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_AUDIO, BG_PLUGIN_FILE, info->name);
   }
 
 static void set_subtitle_text_encoder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_SUBTITLE_TEXT, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_SUBTITLE_TEXT, BG_PLUGIN_FILE, info->name);
   }
 
 static void set_subtitle_overlay_encoder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_SUBTITLE_OVERLAY, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_SUBTITLE_OVERLAY, BG_PLUGIN_FILE, info->name);
   }
 
 static void set_audio_recorder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_RECORDER_AUDIO, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_RECORDER_AUDIO, BG_PLUGIN_RECORDER, info->name);
   }
 
 static void set_video_recorder(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_RECORDER_VIDEO, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_RECORDER_VIDEO, BG_PLUGIN_RECORDER, info->name);
   }
 
 static void set_audio_output(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_OUTPUT_AUDIO, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_OUTPUT_AUDIO, BG_PLUGIN_PLAYBACK, info->name);
   }
 
 static void set_video_output(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_OUTPUT_VIDEO, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_OUTPUT_VIDEO, BG_PLUGIN_PLAYBACK, info->name);
   }
 
 static void set_encoder_pp(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_PP, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_ENCODER_PP, BG_PLUGIN_PP, info->name);
   }
 
 static void set_image_writer(const bg_plugin_info_t * info, void * data)
   {
   app_window * win = (app_window *)data;
-  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_IMAGE_WRITER, info->name);
+  bg_plugin_registry_set_default(win->plugin_reg, BG_PLUGIN_IMAGE_WRITER, BG_PLUGIN_FILE, info->name);
   }
 
 
@@ -363,7 +364,7 @@ static app_window * create_window(bg_plugin_registry_t * reg)
     bg_gtk_plugin_widget_single_create("Video", reg,
                                        BG_PLUGIN_ENCODER_VIDEO |
                                        BG_PLUGIN_ENCODER,
-                                       BG_PLUGIN_FILE);
+                                       BG_PLUGIN_FILE | BG_PLUGIN_BROADCAST);
   bg_gtk_plugin_widget_single_set_change_callback(ret->video_encoder_plugins, set_video_encoder, ret);
   
   /* Postprocessors */
@@ -650,7 +651,7 @@ int main(int argc, char ** argv)
   bg_cfg_registry_t * cfg_reg;
   bg_cfg_section_t * cfg_section;
 
-  bg_gtk_init(&argc, &argv, "plugincfg_icon.png");
+  bg_gtk_init(&argc, &argv, "plugincfg_icon.png", NULL, NULL);
   cfg_reg = bg_cfg_registry_create();
     
   config_path = bg_search_file_read("generic", "config.xml");
