@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -135,6 +135,8 @@ typedef struct
   int x, y, width, height;
   
   bg_gtk_log_window_t * log_window;
+
+  bg_ov_callbacks_t cb;
   } visualizer_t;
 
 static gboolean configure_callback(GtkWidget * w, GdkEventConfigure *event,
@@ -488,7 +490,7 @@ static void set_ra_plugin(const bg_plugin_info_t * plugin,
                           void * data)
   {
   visualizer_t * v = (visualizer_t*)data;
-  bg_plugin_registry_set_default(v->plugin_reg, BG_PLUGIN_RECORDER_AUDIO,
+  bg_plugin_registry_set_default(v->plugin_reg, BG_PLUGIN_RECORDER_AUDIO, BG_PLUGIN_RECORDER,
                                  plugin->name);
   
   v->ra_info = plugin;
@@ -554,11 +556,7 @@ static void plugin_window_init(plugin_window_t * win, visualizer_t * v)
   gtk_container_add(GTK_CONTAINER(win->window),  table);
   }
 
-
-
-static gboolean motion_callback(GtkWidget * w,
-                                GdkEventMotion * evt,
-                                gpointer data)
+static int motion_callback(void * data, int x, int y)
   {
   visualizer_t * v = (visualizer_t*)data;
   if(v->toolbar_trigger & TOOLBAR_TRIGGER_MOUSE)
@@ -571,6 +569,7 @@ static gboolean key_callback(GtkWidget * w,
                              gpointer data)
   {
   visualizer_t * v = (visualizer_t*)data;
+  
   //  gtk_widget_show(v->toolbar);
   //  g_timeout_add(2000, toolbar_timeout, v);
   switch(evt->keyval)
@@ -608,7 +607,6 @@ static void window_init(visualizer_t * v,
   w->socket = gtk_socket_new();
   w->box = gtk_vbox_new(0, 0);
   gtk_widget_show(w->box);
-  gtk_widget_show(w->socket);
 
   table = gtk_table_new(1, 1, 0);
 
@@ -620,8 +618,8 @@ static void window_init(visualizer_t * v,
   gtk_widget_show(table);
   
   gtk_widget_set_events(w->socket,
-                        GDK_KEY_PRESS_MASK | 
-                        GDK_POINTER_MOTION_MASK);
+                        GDK_KEY_PRESS_MASK |
+                        GDK_BUTTON_PRESS_MASK);
   
   //  gtk_window_set_focus_on_map(w->window, 0);
   
@@ -631,10 +629,6 @@ static void window_init(visualizer_t * v,
                    G_CALLBACK(delete_callback),
                    v);
   
-  g_signal_connect(G_OBJECT(w->socket), "motion-notify-event",
-                   G_CALLBACK(motion_callback),
-                   v);
-  
   g_signal_connect(G_OBJECT(w->socket), "plug-removed",
                    G_CALLBACK(plug_removed_callback),
                    v);
@@ -651,6 +645,8 @@ static void window_init(visualizer_t * v,
                    G_CALLBACK(key_callback),
                    v);
   
+  gtk_widget_show(w->socket);
+  
   if(fullscreen)
     gtk_window_fullscreen(GTK_WINDOW(w->window));
   //  else
@@ -954,7 +950,7 @@ static gboolean idle_func(void * data)
     if(v->toolbar_visible)
       bg_gtk_vumeter_update(v->vumeter, v->audio_frame);
     
-    bg_visualizer_update(v->visualizer, v->audio_frame);
+    //    bg_visualizer_update(v->visualizer, v->audio_frame);
     }
   return TRUE;
   }
@@ -979,6 +975,7 @@ static void set_vis_plugin(const bg_plugin_info_t * plugin,
   visualizer_t * v = (visualizer_t*)data;
   bg_visualizer_set_vis_plugin(v->visualizer, plugin);
   bg_plugin_registry_set_default(v->plugin_reg, BG_PLUGIN_VISUALIZATION,
+                                 BG_PLUGIN_VISUALIZE_FRAME | BG_PLUGIN_VISUALIZE_GL,
                                  plugin->name);
   if(bg_visualizer_need_restart(v->visualizer))
     {
@@ -1015,7 +1012,10 @@ static visualizer_t * visualizer_create()
   bg_cfg_section_t * cfg_section;
   
   ret = calloc(1, sizeof(*ret));
-
+  
+  ret->cb.motion_callback = motion_callback;
+  ret->cb.data = ret;
+  
   window_init(ret, &ret->normal_window, 0);
   window_init(ret, &ret->fullscreen_window, 1);
   ret->current_window = &ret->normal_window;
@@ -1085,6 +1085,8 @@ static visualizer_t * visualizer_create()
   ret->plugin_reg = bg_plugin_registry_create(cfg_section);
   ret->visualizer = bg_visualizer_create(ret->plugin_reg);
 
+  bg_visualizer_set_callbacks(ret->visualizer, &ret->cb);
+  
   /* Create vis plugin widget */
 
   ret->vis_plugins =
@@ -1242,7 +1244,7 @@ int main(int argc, char ** argv)
   {
   visualizer_t * win;
   
-  bg_gtk_init(&argc, &argv, "visualizer_icon.png");
+  bg_gtk_init(&argc, &argv, "visualizer_icon.png", NULL, NULL);
 
   win = visualizer_create();
   gtk_main();
