@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -34,7 +34,7 @@ typedef struct
   int fixed_samplerate;
   int samplerate;
   int fixed_channel_setup;
-
+  
   gavl_sample_format_t force_format;
   
   int num_front_channels;
@@ -60,6 +60,7 @@ void bg_gavl_audio_options_set_format(const bg_gavl_audio_options_t *,
 typedef struct
   {
   gavl_video_options_t * opt;
+  gavl_pixelformat_t pixelformat;
   
   int framerate_mode;
   int frame_duration;
@@ -83,6 +84,18 @@ void bg_gavl_video_options_init(bg_gavl_video_options_t *);
 
 void bg_gavl_video_options_free(bg_gavl_video_options_t *);
 
+void bg_gavl_video_options_set_framerate(const bg_gavl_video_options_t *,
+                                         const gavl_video_format_t * in_format,
+                                         gavl_video_format_t * out_format);
+
+void bg_gavl_video_options_set_frame_size(const bg_gavl_video_options_t * opt,
+                                          const gavl_video_format_t * in_format,
+                                          gavl_video_format_t * out_format);
+
+void bg_gavl_video_options_set_pixelformat(const bg_gavl_video_options_t * opt,
+                                           const gavl_video_format_t * in_format,
+                                           gavl_video_format_t * out_format);
+
 void bg_gavl_video_options_set_format(const bg_gavl_video_options_t *,
                                       const gavl_video_format_t * in_format,
                                       gavl_video_format_t * out_format);
@@ -608,7 +621,7 @@ BG_GAVL_PARAM_CHANNEL_SETUP_NOSOURCE
 
 #define BG_GAVL_PARAM_FORCE_SAMPLEFORMAT \
     { \
-      .name =      "force_sampleformat", \
+      .name =      "sampleformat", \
       .long_name = TRS("Force sampleformat"), \
       .type =      BG_PARAMETER_STRINGLIST,\
       .flags =       BG_PARAMETER_SYNC, \
@@ -618,6 +631,18 @@ BG_GAVL_PARAM_CHANNEL_SETUP_NOSOURCE
       .help_string = TRS("Force a sampleformat to be used for processing. None means to take the input format.") \
     }
 
+#define BG_GAVL_PARAM_SAMPLEFORMAT \
+    { \
+      .name =      "sampleformat", \
+      .long_name = TRS("Sampleformat"), \
+      .type =      BG_PARAMETER_STRINGLIST,\
+      .flags =       BG_PARAMETER_SYNC, \
+      .val_default = { .val_str = "f" },\
+      .multi_names  = (char const *[]){ "16", "32", "f", "d", (char*)0 },\
+      .multi_labels = (char const *[]){ TRS("16 bit"), TRS("32 bit"), TRS("Float"), TRS("Double"), (char*)0 }, \
+      .help_string = TRS("Sampleformat to be used for processing.") \
+    }
+
 #define BG_GAVL_PARAM_AUDIO_DITHER_MODE \
     { \
       .name =      "dither_mode", \
