@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -53,9 +53,12 @@ void bg_socket_disconnect(int);
 
 /* Server socket (stream oriented) */
 
+// #define BG_SOCKET_IPV6     (1<<0)
+#define BG_SOCKET_LOOPBACK (1<<1)
+
 int bg_listen_socket_create_inet(int port,
                                  int queue_size,
-                                 uint32_t addr);
+                                 int flags);
 
 int bg_listen_socket_create_unix(const char * name,
                                  int queue_size);
