@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -23,6 +23,7 @@
 #define __BG_CFG_DIALOG_H_
 
 #include <gmerlin/cfg_registry.h>
+#include <gmerlin/pluginregistry.h>
 
 /* Opaque pointer, will look different with all toolkits */
 
@@ -43,6 +44,9 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * config,
 
 bg_dialog_t * bg_dialog_create_multi(const char * label);
 
+void bg_dialog_set_plugin_registry(bg_dialog_t *, bg_plugin_registry_t * plugin_reg);
+
+
 /* Add sections to a dialog */
 
 void bg_dialog_add(bg_dialog_t *d,
