@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -100,6 +100,17 @@ void bg_cfg_registry_load(bg_cfg_registry_t * reg, const char * filename);
 
 void bg_cfg_registry_save(bg_cfg_registry_t * reg, const char * filename);
 
+/** \ingroup cfg_registry
+ *  \brief Check if a registry has a section
+ *  \param reg A configuration registry.
+ *  \param name Name of the section
+ *  \returns 1 if the section is present, 0 else
+ */
+
+
+int bg_cfg_registry_has_section(bg_cfg_registry_t * r, const char * name);
+
+
 /* The name and xml tag of the section must be set before */
 
 /** \ingroup cfg_section
@@ -124,6 +135,16 @@ void bg_cfg_section_2_xml(bg_cfg_section_t * section, xmlNodePtr xml_section);
 void bg_cfg_xml_2_section(xmlDocPtr xml_doc, xmlNodePtr xml_section,
                           bg_cfg_section_t * section);
 
+/** \ingroup cfg_section
+ *  \brief Dump a config section to a file
+ *  \param section Configuration section
+ *  \param filename File to write this to
+ *
+ *  Used for debugging
+ */
+
+void bg_cfg_section_dump(bg_cfg_section_t * section, const char * filename);
+
 /*
  *  Path looks like "section:subsection:subsubsection"
  */
@@ -243,15 +264,6 @@ void bg_cfg_section_destroy(bg_cfg_section_t * section);
 
 bg_cfg_section_t * bg_cfg_section_copy(const bg_cfg_section_t * src);
 
-/** \ingroup cfg_section
- *  \brief Restore a configuration section from a previously copied one
- *  \param section       Configuration section
- *  \param section_saved Saved configuration section
- *  \returns A newly allocated section with all values copied from src.
- */
-
-void bg_cfg_section_restore(bg_cfg_section_t * section, bg_cfg_section_t * section_saved);
-
 /** \ingroup cfg_section
  *  \brief Set values in a configuration section from another section
  *  \param src Source section
@@ -264,6 +276,14 @@ void bg_cfg_section_restore(bg_cfg_section_t * section, bg_cfg_section_t * secti
 
 void bg_cfg_section_transfer(bg_cfg_section_t * src, bg_cfg_section_t * dst);
 
+/** \ingroup cfg_section
+ *  \brief Insert a reference to a section as child
+ *  \param src s
+ *  \param dst Child section to be added as reference
+ */
+
+void bg_cfg_section_add_ref(bg_cfg_section_t * s, bg_cfg_section_t * ref);
+
 /*
  *  Get/Set section names
  */
