@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -96,34 +96,23 @@ typedef int (*bg_read_video_func_t)(void * priv, gavl_video_frame_t* frame, int
  *  @{
  */
 
-#define BG_PLUGIN_REMOVABLE    (1<<0)  //!< Plugin handles removable media (CD, DVD etc.)
-#define BG_PLUGIN_FILE         (1<<1)  //!< Plugin reads/writes files
-#define BG_PLUGIN_RECORDER     (1<<2)  //!< Plugin does hardware recording
-
-#define BG_PLUGIN_URL          (1<<3)  //!< Plugin can load URLs
-#define BG_PLUGIN_PLAYBACK     (1<<4)  //!< Plugin is an audio or video driver for playback
-
-#define BG_PLUGIN_BYPASS       (1<<5)  //!< Plugin can send A/V data directly to the output bypassing the player engine
-
-#define BG_PLUGIN_KEEP_RUNNING (1<<6) //!< Plugin should not be stopped and restarted if tracks change
-
-#define BG_PLUGIN_INPUT_HAS_SYNC (1<<7) //!< For input plugins in bypass mode: Plugin will set the time via callback
-
-#define BG_PLUGIN_STDIN         (1<<8)  //!< Plugin can read from stdin ("-")
-
-#define BG_PLUGIN_TUNER         (1<<9)  //!< Plugin has some kind of tuner. Channels will be loaded as tracks.
-#define BG_PLUGIN_FILTER_1     (1<<10)  //!< Plugin acts as a filter with one input
-
-#define BG_PLUGIN_EMBED_WINDOW (1<<11)  //!< Plugin can embed it's window into another application
-
+#define BG_PLUGIN_REMOVABLE        (1<<0)  //!< Plugin handles removable media (CD, DVD etc.)
+#define BG_PLUGIN_FILE             (1<<1)  //!< Plugin reads/writes files
+#define BG_PLUGIN_RECORDER         (1<<2)  //!< Plugin does hardware recording
+#define BG_PLUGIN_URL              (1<<3)  //!< Plugin can load URLs
+#define BG_PLUGIN_PLAYBACK         (1<<4)  //!< Plugin is an audio or video driver for playback
+#define BG_PLUGIN_STDIN            (1<<8)  //!< Plugin can read from stdin ("-")
+#define BG_PLUGIN_TUNER            (1<<9)  //!< Plugin has some kind of tuner. Channels will be loaded as tracks.
+#define BG_PLUGIN_FILTER_1        (1<<10)  //!< Plugin acts as a filter with one input
+#define BG_PLUGIN_EMBED_WINDOW    (1<<11)  //!< Plugin can embed it's window into another application
 #define BG_PLUGIN_VISUALIZE_FRAME (1<<12)  //!< Visualization plugin outputs video frames
+#define BG_PLUGIN_VISUALIZE_GL    (1<<13)  //!< Visualization plugin outputs via OpenGL
+#define BG_PLUGIN_PP              (1<<14)  //!< Postprocessor
+#define BG_PLUGIN_CALLBACKS       (1<<15)  //!< Plugin can be opened from callbacks
+#define BG_PLUGIN_BROADCAST       (1<<16)  //!< Plugin can broadcasts (e.g. webstreams)
+#define BG_PLUGIN_DEVPARAM        (1<<17)  //!< Plugin has pluggable devices as parameters, which must be updated regurarly
 
-#define BG_PLUGIN_VISUALIZE_GL (1<<13)  //!< Visualization plugin outputs via OpenGL
-
-#define BG_PLUGIN_PP  (1<<14)  //!< Postprocessor
-#define BG_PLUGIN_CALLBACKS     (1<<15)  //!< Plugin can be opened from callbacks
-
-#define BG_PLUGIN_UNSUPPORTED  (1<<24)  //!< Plugin is not supported. Only for a foreign API plugins
+#define BG_PLUGIN_UNSUPPORTED     (1<<24)  //!< Plugin is not supported. Only for a foreign API plugins
 
 
 #define BG_PLUGIN_ALL 0xFFFFFFFF //!< Mask of all possible plugin flags
@@ -131,7 +120,7 @@ typedef int (*bg_read_video_func_t)(void * priv, gavl_video_frame_t* frame, int
 /** @}
  */
 
-#define BG_PLUGIN_API_VERSION 19
+#define BG_PLUGIN_API_VERSION 23
 
 /* Include this into all plugin modules exactly once
    to let the plugin loader obtain the API version */
@@ -163,8 +152,6 @@ typedef enum
     /*
      */
     
-    BG_STREAM_ACTION_BYPASS, //!< A/V data will bypass the player. It will only be chosen if the BG_PLUGIN_BYPASS flag (see below) is present. Currently, this is used only for Audio-CD playback to the soundcard.
-    
     /*
      *  Future support for compressed frames
      *  must go here
@@ -369,25 +356,6 @@ typedef struct bg_input_callbacks_s bg_input_callbacks_t;
 
 struct bg_input_callbacks_s
   {
-  /** \brief Track changed
-   *  \param data The data member of this bg_input_callbacks_s struct
-   *  \param track The track number starting with 0
-   *
-   *  This is called by plugins, which support multiple tracks and can switch to a new track without
-   *  closing/reopening (e.g. the audio-cd player)
-   */
-   void (*track_changed)(void * data, int track);
-
-  /** \brief Time changed
-   *  \param data The data member of this bg_input_callbacks_s struct
-   *  \param time The current time
-   *
-   *  This is used only by plugins, which do playback without the player engine
-   *  (currently only the audio-cd player) to update the displayed time. Normal plugins never call this.
-   */
-  
-  void (*time_changed)(void * data, gavl_time_t time);
-  
   /** \brief Duration changed
    *  \param data The data member of this bg_input_callbacks_s struct
    *  \param time The new duration
@@ -664,6 +632,17 @@ struct bg_input_plugin_s
   
   int (*start)(void * priv);
 
+  /** \brief Get frame table
+   *  \param priv The handle returned by the create() method
+   *  \param stream Stream index (starting with 0)
+   *  \returns A newly allocated frame table or NULL
+   *
+   *  The returned frame table must be freed with
+   *  \ref gavL_frame_table_destroy.
+   */
+
+  gavl_frame_table_t * (*get_frame_table)(void * priv, int stream);
+    
   /** \brief Read audio samples
    *  \param priv The handle returned by the create() method
    *  \param frame The frame, where the samples will be copied
@@ -697,7 +676,21 @@ struct bg_input_plugin_s
    */
   
   bg_read_video_func_t read_video;
-  
+
+  /** \brief Skip frames in a video stream
+      \param stream Stream index (starting with 0)
+      \param time The time to skip to (will be changed to the true time)
+      \param scale Scale by which the time is scaled
+      \param exact 1 if an exact skip should be done, 0 for faster approximate skip
+      
+      Use this function if it turns out, that the machine is too weak to
+      decode all frames. Set exact to 0 to make the skipping even faster
+      but less accurate.
+
+  */
+
+  void (*skip_video)(void * priv, int stream, int64_t * time, int scale, int exact);
+    
   /** \brief Query if a new subtitle is available
    *  \param priv The handle returned by the create() method
    *  \param stream Stream index starting with 0
@@ -743,36 +736,6 @@ struct bg_input_plugin_s
                             int64_t * start_time,
                             int64_t * duration, int stream);
   
-  /* The following 3 functions are only meaningful for plugins, which
-     have the BG_PLUGIN_BYPASS flag set. */
-
-  /** \brief Update a plugin in bypass mode
-   *  \param priv The handle returned by the create() method
-   *  \returns 1 on success, 0 on error
-   *
-   *  For plugins in bypass mode, this function must be called
-   *  periodically by the application, so the plugin can call the
-   *  callbacks if something interesting happened.
-   */
-    
-  int (*bypass)(void * priv);
-  
-  /** \brief pause a plugin in bypass mode
-   *  \param priv The handle returned by the create() method
-   *  \param pause 1 for pausing, 0 for resuming
-   */
-  
-  void (*bypass_set_pause)(void * priv, int pause);
-
-  /** \brief Set volume for a plugin in bypass mode
-   *  \param priv The handle returned by the create() method
-   *  \param volume Volume in dB (0 is maximum).
-   *
-   * This function is optional.
-   */
-  
-  void (*bypass_set_volume)(void * priv, float volume);
-    
   /** \brief Seek within a media track
    *  \param priv The handle returned by the create() method
    *  \param time Time to seek to
@@ -810,6 +773,23 @@ struct bg_input_plugin_s
  *  \brief Audio output
  */ 
 
+/** \ingroup plugin_oa
+ *  \brief typedef for audio output callbacks
+ *
+ */
+
+typedef struct bg_oa_callbacks_s bg_oa_callbacks_t;
+
+/** \ingroup plugin_oa
+ *  \brief Callbacks for audio output plugins
+ *
+ */
+
+struct bg_oa_callbacks_s
+  {
+  bg_read_audio_func_t read_audio;
+  };
+
 /** \ingroup plugin_oa
  *  \brief Typedef for audio output plugin
  */
@@ -1097,8 +1077,9 @@ struct bg_ov_plugin_s
    *  \param priv The handle returned by the create() method
    *  \param window Window identifier
    *
-   *  Call this immediately after creation of the plugin to embed video output
-   *  into a foreign application. For X11, the window identifier has the form
+   *  Call this immediately after creation of the plugin to embed 
+   *  video output into a foreign application. 
+   *  For X11, the window identifier has the form
    *  \<display_name\>:\<normal_id\>:\<fullscreen_id\>. 
    */
   
@@ -1111,6 +1092,23 @@ struct bg_ov_plugin_s
   
   const char * (*get_window)(void * priv);
   
+  /** \brief Set window class
+   *  \param priv The handle returned by the create() method
+   *  \param name The name of the window
+   *  \param klass The class of the window
+   *
+   *  This makes sense probably only in an X11 environment.
+   *  If the klass argument is the same for all windows of an
+   *  application, they, might be grouped together in the
+   *  window list. On X11 this results in a call to
+   *  XSetClassHint().
+   */
+
+  void (*set_window_options)(void * priv, const char * name, 
+                             const char * klass, 
+                             const gavl_video_frame_t * icon,
+                             const gavl_video_format_t * icon_format);
+
   /** \brief Set window title
    *  \param priv The handle returned by the create() method
    *  \param title The title for the window
@@ -1142,11 +1140,11 @@ struct bg_ov_plugin_s
    *  \param priv The handle returned by the create() method
    *  \returns a newly allocated video frame
    *
-   *  This optional method allocates a video frame in a plugin specific manner
-   *  (e.g. in a shared memory segment). If this funtion is defined, all frames
-   *  which are passed to the plugin, must be allocated by this function.
-   *  Before the plugin is closed, all created frames must be freed with
-   *  the destroy_frame() method.
+   *  This optional method allocates a video frame in a plugin specific 
+   *  manner (e.g. in a shared memory segment). If this funtion is 
+   *  defined, all frames which are passed to the plugin, must be allocated
+   *  by this function. Before the plugin is closed, all created frames must
+   *  be freed with the destroy_frame() method.
    */
   
   gavl_video_frame_t * (*create_frame)(void * priv);
@@ -1201,7 +1199,7 @@ struct bg_ov_plugin_s
    *  \param priv The handle returned by the create() method
    *  \param frame Frame to display
    *  
-   *  This function is like put_video() with the diffderence, that
+   *  This function is like put_video() with the difference, that
    *  the frame will be remembered and redisplayed, when an expose event
    *  is received.
    */
@@ -1266,6 +1264,45 @@ struct bg_ov_plugin_s
  *  \brief Encoder
  */ 
 
+/** \ingroup plugin_ov
+ * \brief Typedef for callbacks for the encoder plugin
+ *
+ */
+
+typedef struct bg_encoder_callbacks_s bg_encoder_callbacks_t;
+
+/** \ingroup plugin_ov
+ * \brief Callbacks for the encoder plugin
+ *
+ */
+
+struct bg_encoder_callbacks_s
+  {
+  
+  /** \brief   Output file callback
+   *  \param   data The data member of this bg_ov_callbacks_s struct
+   *  \param   filename Name of the created file
+   *  \returns 1 if the file may be created, 0 else
+   *
+   *  This is called whenever an output file is created.
+   */
+  
+  int (*create_output_file)(void * data, const char * filename);
+
+  /** \brief   Temp file callback
+   *  \param   data The data member of this bg_ov_callbacks_s struct
+   *  \param   filename Name of the created file
+   *  \returns 1 if the file may be created, 0 else
+   *
+   *  This is called whenever a temporary file is created.
+   */
+
+  int (*create_temp_file)(void * data, const char * filename);
+  
+  void * data;//!< Application specific data passed as the first argument to all callbacks.
+  };
+
+
 /** \ingroup plugin_e
  *  \brief Typedef for encoder plugin
  */
@@ -1285,27 +1322,27 @@ struct bg_encoder_plugin_s
   int max_video_streams;  //!< Maximum number of video streams. -1 means infinite
   int max_subtitle_text_streams;//!< Maximum number of text subtitle streams. -1 means infinite
   int max_subtitle_overlay_streams;//!< Maximum number of overlay subtitle streams. -1 means infinite
-
-  /** \brief Return the file extension
+  
+  /** \brief Set callbacks
    *  \param priv The handle returned by the create() method
-   *  \returns The file extension
-   *
-   *  If a plugin supports more than one output format, the actual format
-   *  is configured as a parameter. This function returns the extension
-   *  according to the format.
+   *  \param cb Callback structure
    */
   
-  const char * (*get_extension)(void * priv);
+  void (*set_callbacks)(void * priv, bg_encoder_callbacks_t * cb);
   
   /** \brief Open a file
    *  \param priv The handle returned by the create() method
-   *  \param filename Name of the file to be opened
+   *  \param filename Name of the file to be opened (without extension!)
    *  \param metadata Metadata to be written to the file
    *  \param chapter_list Chapter list (optional, can be NULL)
+   *
+   *  The extension is added automatically by the plugin.
+   *  To keep track of the written files, use the \ref bg_encoder_callbacks_t.
    */
   
   int (*open)(void * data, const char * filename,
-              const bg_metadata_t * metadata, const bg_chapter_list_t * chapter_list);
+              const bg_metadata_t * metadata,
+              const bg_chapter_list_t * chapter_list);
   
   /** \brief Return the filename, which can be passed to the player
    *  \param priv The handle returned by the create() method
@@ -1372,7 +1409,7 @@ struct bg_encoder_plugin_s
    */
   
   int (*add_audio_stream)(void * priv, const char * language,
-                          gavl_audio_format_t * format);
+                          const gavl_audio_format_t * format);
 
   /** \brief Add a video stream
    *  \param priv The handle returned by the create() method
@@ -1384,7 +1421,7 @@ struct bg_encoder_plugin_s
    *  needed by the plugin, after \ref start() was called.
    */
   
-  int (*add_video_stream)(void * priv, gavl_video_format_t * format);
+  int (*add_video_stream)(void * priv, const gavl_video_format_t * format);
 
   /** \brief Add a text subtitle stream
    *  \param priv The handle returned by the create() method
@@ -1392,7 +1429,8 @@ struct bg_encoder_plugin_s
    *  \returns Index of this stream (starting with 0)
    */
   
-  int (*add_subtitle_text_stream)(void * priv, const char * language, int * timescale);
+  int (*add_subtitle_text_stream)(void * priv, const char * language,
+                                  int * timescale);
   
   /** \brief Add a text subtitle stream
    *  \param priv The handle returned by the create() method
@@ -1407,7 +1445,7 @@ struct bg_encoder_plugin_s
    */
   
   int (*add_subtitle_overlay_stream)(void * priv, const char * language,
-                                     gavl_video_format_t * format);
+                                     const gavl_video_format_t * format);
   
   /* Set parameters for the streams */
 
@@ -1760,6 +1798,28 @@ struct bg_image_reader_plugin_s
   int (*read_image)(void * priv, gavl_video_frame_t * frame);
   };
 
+/**  
+ * \brief Typedef for callbacks for the image writer plugin
+ */
+
+typedef struct bg_iw_callbacks_s bg_iw_callbacks_t;
+
+struct bg_iw_callbacks_s
+  {
+  
+  /** \brief   Output file callback
+   *  \param   data The data member of this bg_ov_callbacks_s struct
+   *  \param   filename Name of the created file
+   *  \returns 1 if the file may be created, 0 else
+   *
+   *  This is called whenever an output file is created.
+   */
+  
+  int (*create_output_file)(void * data, const char * filename);
+  
+  void * data;//!< Application specific data passed as the first argument to all callbacks.
+  };
+
 /** \brief Typedef for image writer plugin
  *
  */
@@ -1773,18 +1833,14 @@ typedef struct bg_image_writer_plugin_s bg_image_writer_plugin_t;
 struct bg_image_writer_plugin_s
   {
   bg_plugin_common_t common; //!< Infos and functions common to all plugin types
-  const char * extensions; //!< Supported file extensions (space separated)
-
-  /** \brief Return the file extension
+  const char * extensions; //!< File extensions (space separated)
+  
+  /** \brief Set callbacks
    *  \param priv The handle returned by the create() method
-   *  \returns The extension
-   *
-   *  This function is mandatory for all plugins. Most plugins will always
-   *  return the same extension. Others might have multiple supported formats,
-   *  which are selected through parameters.
+   *  \param cb Callback structure
    */
-
-  const char * (*get_extension)(void * priv);
+  
+  void (*set_callbacks)(void * priv, bg_iw_callbacks_t * cb);
   
   /** \brief Write the file header
    *  \param priv The handle returned by the create() method
@@ -2035,13 +2091,13 @@ typedef struct bg_visualization_plugin_s bg_visualization_plugin_t;
 struct bg_visualization_plugin_s
   {
   bg_plugin_common_t common; //!< Infos and functions common to all plugin types
-  /** \brief return callback \param priv The handle returned by the
+
+  /** \brief return callback
    *  \param priv The handle returned by the create() method
-   *
-   *  create() method \returns The callbacks or NULL
+   *  \param cb The callbacks to be called
    */
   
-  bg_ov_callbacks_t * (*get_callbacks)(void * priv);
+  void (*set_callbacks)(void * priv, bg_ov_callbacks_t * cb);
 
   /** \brief Open a frame based visualization plugin
    *  \param priv The handle returned by the create() method
