@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -54,6 +54,18 @@ typedef enum
     BG_PLUGIN_API_FREI0R,      //!< frei0r
   } bg_plugin_api_t;
 
+/** \ingroup plugin_registry
+ *  \brief Identifiers for stream types
+ */
+
+typedef enum
+  {
+    BG_STREAM_AUDIO             = (1<<0),
+    BG_STREAM_SUBTITLE_TEXT     = (1<<1),
+    BG_STREAM_SUBTITLE_OVERLAY  = (1<<2),
+    BG_STREAM_VIDEO             = (1<<3),
+  } bg_stream_type_t;
+
 /** \ingroup plugin_registry
  *  \brief Typedef for plugin info
  */
@@ -108,6 +120,18 @@ struct bg_plugin_info_s
   
   };
 
+/** \ingroup plugin_registry
+ *  \brief Creation options for a plugin registry
+ *
+ 
+ */
+
+typedef struct
+  {
+  char ** blacklist; //!< Plugins, which should be ignored
+  int dont_save;            //!< If 1, don't save the registry after it was created
+  } bg_plugin_registry_options_t;
+
 /** \ingroup plugin_registry
  *  \brief Opaque handle for a plugin registry
  *
@@ -165,6 +189,36 @@ struct bg_plugin_handle_s
 bg_plugin_registry_t *
 bg_plugin_registry_create(bg_cfg_section_t * section);
 
+/** \ingroup plugin_registry
+ * \brief Create a plugin registry with options
+ * \param section A configuration section
+ * \param opt The options structure
+ *
+ *  The configuration section will be owned exclusively
+ *  by the plugin registry, applications should not touch it.
+ */
+
+bg_plugin_registry_t *
+bg_plugin_registry_create_with_options(bg_cfg_section_t * section,
+                                       const bg_plugin_registry_options_t * opt);
+
+
+
+/** \ingroup plugin_registry
+ * \brief Scan for pluggable devices
+ * \param plugin_reg A plugin registry
+ * \param type_mask Mask of all types you want to have the devices scanned for
+ * \param flag_mask Mask of all flags you want to have the devices scanned for
+ *
+ *  Some plugins offer a list of supported devices as parameters. To update these
+ *  (e.g. if pluggable devices are among them), call this function right after you
+ *  created the plugin registry
+ */
+
+void bg_plugin_registry_scan_devices(bg_plugin_registry_t * plugin_reg,
+                                     uint32_t type_mask, uint32_t flag_mask);
+
+
 /** \ingroup plugin_registry
  * \brief Destroy a plugin registry
  * \param reg A plugin registry
@@ -377,6 +431,140 @@ void bg_plugin_registry_set_parameter_info(bg_plugin_registry_t * reg,
                                            uint32_t flag_mask,
                                            bg_parameter_info_t * ret);
 
+/** \ingroup plugin_registry
+ *  \brief Set a parameter info for selecting and configuring input plugins
+ *  \param reg A plugin registry
+ *  \param type_mask Mask of all returned types
+ *  \param flag_mask Mask of all returned flags
+ *  \param ret Where the parameter info will be copied
+ *
+ */
+
+void bg_plugin_registry_set_parameter_info_input(bg_plugin_registry_t * reg,
+                                                 uint32_t type_mask,
+                                                 uint32_t flag_mask,
+                                                 bg_parameter_info_t * ret);
+
+
+/** \ingroup plugin_registry
+ *  \brief Set a parameter of an input plugin
+ *  \param data A plugin registry cast to void
+ *  \param name Name
+ *  \param val Value
+ *
+ */
+
+void bg_plugin_registry_set_parameter_input(void * data, const char * name,
+                                            const bg_parameter_value_t * val);
+
+int bg_plugin_registry_get_parameter_input(void * data, const char * name,
+                                            bg_parameter_value_t * val);
+
+
+/** \ingroup plugin_registry
+ *  \brief Create a parameter array for encoders
+ *  \param reg       A plugin registry
+ *  \param type_mask Mask of all stream types to be encoded
+ *  \param flag_mask Mask of all returned plugin flags
+ *  \returns Parameter array for setting up encoders
+ *
+ *  Free the returned parameters with
+ *  \ref bg_parameter_info_destroy_array
+ *
+ *  If you create a config section from the returned parameters
+ *  (with \ref bg_cfg_section_create_from_parameters or \ref bg_cfg_section_create_items)
+ *  the resulting encoding section will contain the complete encoder setup.
+ *  It can be manipulated through the bg_encoder_section_*() functions.
+ */
+
+bg_parameter_info_t *
+bg_plugin_registry_create_encoder_parameters(bg_plugin_registry_t * reg,
+                                             uint32_t stream_type_mask,
+                                             uint32_t flag_mask);
+
+/** \ingroup plugin_registry
+ *  \brief Get the name for an encoding plugin
+ *  \param plugin_ref A plugin registry
+ *  \param s An encoder section (see \ref bg_plugin_registry_create_encoder_parameters)
+ *  \param stream_type The stream type to encode
+ *  \param stream_mask The mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \returns Returns the plugin name or NULL if the stream will be encoded by the video encoder
+ */
+
+const char * 
+bg_encoder_section_get_plugin(bg_plugin_registry_t * plugin_reg,
+                              bg_cfg_section_t * s,
+                              bg_stream_type_t stream_type,
+                              int stream_mask);
+
+/** \ingroup plugin_registry
+ *  \brief Get the plugin configuration for an encoding plugin
+ *  \param plugin_ref A plugin registry
+ *  \param s An encoder section (see \ref bg_plugin_registry_create_encoder_parameters)
+ *  \param stream_type The stream type to encode
+ *  \param stream_mask The mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \param section_ret If non-null returns the config section for the plugin
+ *  \param params_ret If non-null returns the parameters for the plugin
+ */
+
+  
+void
+bg_encoder_section_get_plugin_config(bg_plugin_registry_t * plugin_reg,
+                                     bg_cfg_section_t * s,
+                                     bg_stream_type_t stream_type,
+                                     int stream_mask,
+                                     bg_cfg_section_t ** section_ret,
+                                     const bg_parameter_info_t ** params_ret);
+
+/** \ingroup plugin_registry
+ *  \brief Get the stream configuration for an encoding plugin
+ *  \param plugin_ref A plugin registry
+ *  \param s An encoder section (see \ref bg_plugin_registry_create_encoder_parameters)
+ *  \param stream_type The stream type to encode
+ *  \param stream_mask The mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \param section_ret If non-null returns the config section for the stream
+ *  \param params_ret If non-null returns the parameters for the stream
+ */
+
+void
+bg_encoder_section_get_stream_config(bg_plugin_registry_t * plugin_reg,
+                                     bg_cfg_section_t * s,
+                                     bg_stream_type_t stream_type,
+                                     int stream_mask,
+                                     bg_cfg_section_t ** section_ret,
+                                     const bg_parameter_info_t ** params_ret);
+
+
+/** \ingroup plugin_registry
+ *  \brief Get an encoder configuration section from a registry
+ *  \param plugin_ref A plugin registry
+ *  \param type_mask The stream mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \param flag_mask The mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \returns The encoder section with the values from the registry
+*/
+
+bg_cfg_section_t *
+bg_encoder_section_get_from_registry(bg_plugin_registry_t * plugin_reg,
+                                     const bg_parameter_info_t * parameters,
+                                     uint32_t type_mask,
+                                     uint32_t flag_mask);
+
+/** \ingroup plugin_registry
+ *  \brief Store an encoder configuration in a registry
+ *  \param plugin_ref A plugin registry
+ *  \param s The encoder section to store
+ *  \param type_mask The stream mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \param flag_mask The mask passed to \ref bg_plugin_registry_create_encoder_parameters
+ *  \returns The encoder section with the values from the registry
+ */
+
+void
+bg_encoder_section_store_in_registry(bg_plugin_registry_t * plugin_reg,
+                                     bg_cfg_section_t * s,
+                                     const bg_parameter_info_t * parameters,
+                                     uint32_t type_mask,
+                                     uint32_t flag_mask);
+
 
 /** \ingroup plugin_registry_defaults 
  *  \brief Set the default for a particular plugin type
@@ -389,7 +577,7 @@ void bg_plugin_registry_set_parameter_info(bg_plugin_registry_t * reg,
  */
 
 void bg_plugin_registry_set_default(bg_plugin_registry_t * reg,
-                                    bg_plugin_type_t type,
+                                    bg_plugin_type_t type, uint32_t flag_mask,
                                     const char * plugin_name);
 
 /** \ingroup plugin_registry_defaults
@@ -401,7 +589,7 @@ void bg_plugin_registry_set_default(bg_plugin_registry_t * reg,
  *  Note, that the registry does not store a default input plugin.
  */
 const bg_plugin_info_t * bg_plugin_registry_get_default(bg_plugin_registry_t * reg,
-                                                        bg_plugin_type_t type);
+                                                        bg_plugin_type_t type, uint32_t flag_mask);
 
 
 /** \defgroup plugin_registry_defaults Defaults saved between sessions
@@ -688,18 +876,33 @@ void bg_plugin_unref(bg_plugin_handle_t * h);
  *  If the reference count gets zero, the plugin will
  *  be destroyed
  */
+
 void bg_plugin_unref_nolock(bg_plugin_handle_t * h);
 
-/* Check if 2 plugins handles are equal */
-
 /** \ingroup plugin_registry
- *  \brief Check if 2 plugins are equal
- *  \param h1 A Plugin handle
- *  \param h2 Another plugin handle
- *  \returns 1 if the plugins are equal, 0 else
+ *  \brief Create a plugin info from a plugin
+ *  \param plugin A plugin
+ *  \param plugin_priv Handle returned by the create() method
+ *  \param module_filename Module filename or NULL
+ *  \returns A newly allocated plugin info
+ *
+ *  Use this function only if you create a plugin handle outside a plugin
+ *  registry. Free the returned info with \ref bg_plugin_info_destroy
  */
 
-int bg_plugin_equal(bg_plugin_handle_t * h1,
-                    bg_plugin_handle_t * h2);                    
+bg_plugin_info_t * bg_plugin_info_create(const bg_plugin_common_t * plugin,
+                                         void * plugin_priv,
+                                         const char * module_filename);
+
+/** \ingroup plugin_registry
+ *  \brief Create an empty plugin handle
+ *  \returns A newly allocated plugin handle
+ *
+ *  Use this function only if you create a plugin handle outside a plugin
+ *  registry. Free the returned info with \ref bg_plugin_unref
+ */
+
+bg_plugin_handle_t * bg_plugin_handle_create();
+
 
 #endif // __BG_PLUGINREGISTRY_H_
