@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -125,6 +125,21 @@ void bg_display_html_help(const char * path);
 
 char * bg_create_unique_filename(char * format);
 
+/** \brief Ensure a file extension
+ *  \param filename Filename (with or without extension)
+ *  \param extension Extension to look for
+ *  \returns A newly allocated filename
+ *
+ *  This function checks case insensitively if filename
+ *  ends with the extension. If yes, it returns a copy of
+ *  the filename. If not, it returns a copy with the extension
+ *  appended. The extention must not start with the dot.
+ */
+
+char * bg_filename_ensure_extension(const char * filename,
+                                    const char * ext);
+
+
 
 /** @} */
 
@@ -388,6 +403,15 @@ char * bg_audio_format_to_string(gavl_audio_format_t * format, int use_tabs);
 
 char * bg_video_format_to_string(gavl_video_format_t * format, int use_tabs);
 
+/** \brief Create a stream label
+ *  \param index Index of the stream (starting with 0)
+ *  \param info Information (or NULL)
+ *  \param language Language (or NULL)
+ *  \returns A newly allocated string
+ */
+
+char * bg_get_stream_label(int index, const char * info, const char * language);
+
 /** \brief Dump to stderr
  *  \param format Format (printf compatible)
  */
