@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -22,6 +22,6 @@
 
 /* This pops up a which shows all informations about a selected track */
 
-void bg_gtk_album_enrty_show(const bg_album_entry_t * entry, GtkWidget * parent);
+void bg_gtk_album_entry_show(const bg_album_entry_t * entry, GtkWidget * parent);
 
 
