@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -32,7 +32,10 @@ GdkPixbuf * bg_gtk_pixbuf_scale_alpha(GdkPixbuf * src,
 GdkPixbuf * bg_gtk_pixbuf_from_frame(gavl_video_format_t * format,
                                      gavl_video_frame_t * frame);
 
-void bg_gtk_init(int * argc, char *** argv, char * default_window_icon);
+void bg_gtk_init(int * argc, char *** argv, 
+                 const char * default_window_icon,
+                 const char * default_name,
+                 const char * default_class);
 
 void bg_gdk_pixbuf_render_pixmap_and_mask(GdkPixbuf *pixbuf,
                                           GdkPixmap **pixmap_return,
