@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -61,7 +61,7 @@ int bg_gavl_audio_set_parameter(void * data, const char * name, const bg_paramet
     }
   SP_INT(fixed_samplerate);
 
-  if(!strcmp(name, "force_sampleformat"))
+  if(!strcmp(name, "sampleformat"))
     {
     gavl_sample_format_t force_format = GAVL_SAMPLE_NONE;
     if(!strcmp(val->val_str, "8"))
@@ -208,16 +208,19 @@ void bg_gavl_audio_options_set_format(const bg_gavl_audio_options_t * opt,
                                       gavl_audio_format_t * out_format)
   {
   int channel_index;
-  gavl_audio_format_copy(out_format, in_format);
 
-  if(opt->fixed_samplerate)
+  if(in_format)
+    gavl_audio_format_copy(out_format, in_format);
+
+  if(opt->fixed_samplerate || !in_format)
     {
     out_format->samplerate = opt->samplerate;
     }
-  if(opt->fixed_channel_setup)
+  if(opt->fixed_channel_setup || !in_format)
     {
-    out_format->num_channels = opt->num_front_channels + opt->num_rear_channels + opt->num_lfe_channels;
-
+    out_format->num_channels =
+      opt->num_front_channels + opt->num_rear_channels + opt->num_lfe_channels;
+    
     channel_index = 0;
     switch(opt->num_front_channels)
       {
@@ -337,20 +340,19 @@ framerate_rates[NUM_FRAME_RATES] =
     { FRAME_RATE_60,            60,    1 },
   };
 
-static void set_frame_rate_mode(bg_gavl_video_options_t * opt,
-                                const bg_parameter_value_t * val)
+static int get_frame_rate_mode(const char * str)
   {
   int i;
   for(i = 0; i < NUM_FRAME_RATES; i++)
     {
-    if(!strcmp(val->val_str, framerate_strings[i].name))
+    if(!strcmp(str, framerate_strings[i].name))
       {
-      opt->framerate_mode = framerate_strings[i].rate;
-      return;
+      return framerate_strings[i].rate;
       }
     }
+  return FRAME_RATE_USER;
   }
-
+                
 
 #define SP_FLAG(s, flag) if(!strcmp(name, s)) {               \
   flags = gavl_video_options_get_conversion_flags(opt->opt);  \
@@ -492,9 +494,9 @@ static void set_frame_size_mode(bg_gavl_video_options_t * opt,
     }
   }
 
-static void set_frame_size(const bg_gavl_video_options_t * opt,
-                           const gavl_video_format_t * in_format,
-                           gavl_video_format_t * out_format)
+void bg_gavl_video_options_set_frame_size(const bg_gavl_video_options_t * opt,
+                                          const gavl_video_format_t * in_format,
+                                          gavl_video_format_t * out_format)
   {
   int i;
   
@@ -551,7 +553,7 @@ int bg_gavl_video_set_parameter(void * data, const char * name,
     }
   else if(!strcmp(name, "framerate"))
     {
-    set_frame_rate_mode(opt, val);
+    opt->framerate_mode = get_frame_rate_mode(val->val_str);
     return 1;
     }
   else if(!strcmp(name, "frame_size"))
@@ -559,6 +561,11 @@ int bg_gavl_video_set_parameter(void * data, const char * name,
     set_frame_size_mode(opt, val);
     return 1;
     }
+  else if(!strcmp(name, "pixelformat"))
+    {
+    opt->pixelformat = gavl_string_to_pixelformat(val->val_str);
+    return 1;
+    }
 
   //  SP_INT(fixed_framerate);
   SP_INT(frame_duration);
@@ -646,9 +653,9 @@ void bg_gavl_video_options_free(bg_gavl_video_options_t * opt)
   }
 
 
-static void set_framerate(const bg_gavl_video_options_t * opt,
-                          const gavl_video_format_t * in_format,
-                          gavl_video_format_t * out_format)
+void bg_gavl_video_options_set_framerate(const bg_gavl_video_options_t * opt,
+                                         const gavl_video_format_t * in_format,
+                                         gavl_video_format_t * out_format)
   {
   int i;
   if(opt->framerate_mode == FRAME_RATE_FROM_INPUT)
@@ -691,14 +698,23 @@ static void set_interlace(const bg_gavl_video_options_t * opt,
     out_format->interlace_mode = in_format->interlace_mode;
   }
 
+void bg_gavl_video_options_set_pixelformat(const bg_gavl_video_options_t * opt,
+                                           const gavl_video_format_t * in_format,
+                                           gavl_video_format_t * out_format)
+  {
+  if(opt->pixelformat == GAVL_PIXELFORMAT_NONE)
+    out_format->pixelformat = in_format->pixelformat;
+  else
+    out_format->pixelformat = opt->pixelformat;
+  }
 
 void bg_gavl_video_options_set_format(const bg_gavl_video_options_t * opt,
                                       const gavl_video_format_t * in_format,
                                       gavl_video_format_t * out_format)
   {
-  set_framerate(opt, in_format, out_format);
+  bg_gavl_video_options_set_framerate(opt, in_format, out_format);
   set_interlace(opt, in_format, out_format);
-  set_frame_size(opt, in_format, out_format);
+  bg_gavl_video_options_set_frame_size(opt, in_format, out_format);
   }
 
 
