@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -38,83 +38,21 @@ bg_cfg_section_t * bg_cfg_section_create(const char * name)
   return ret;
   }
 
-bg_cfg_section_t *
-bg_cfg_section_create_from_parameters(const char * name,
-                                      const bg_parameter_info_t * parameters)
-  {
-  bg_cfg_section_t * ret;
-  bg_cfg_section_t * last_child = (bg_cfg_section_t*)0;
-  bg_cfg_section_t * last_subchild;
-  
-  int i, j;
-  
-  ret = bg_cfg_section_create(name);
-
-  i = 0;
-  while(parameters[i].name)
-    {
-    bg_cfg_section_find_item(ret, &(parameters[i]));
-    i++;
-    }
-
-  /* Add child sections */
-  
-  i = 0;
-  while(parameters[i].name)
-    {
-    if((parameters[i].type == BG_PARAMETER_MULTI_LIST) ||
-       (parameters[i].type == BG_PARAMETER_MULTI_MENU) ||
-       (parameters[i].type == BG_PARAMETER_MULTI_CHAIN))
-      {
-      if(!last_child)
-        {
-        ret->children = bg_cfg_section_create(parameters[i].name);
-        last_child = ret->children;
-        }
-      else
-        {
-        last_child->next = bg_cfg_section_create(parameters[i].name);
-        last_child = last_child->next;
-        }
-      j = 0;
-
-      last_subchild = (bg_cfg_section_t*)0;
-      while(parameters[i].multi_names[j])
-        {
-        if(parameters[i].multi_parameters[j])
-          {
-          if(!last_subchild)
-            {
-            last_child->children =
-              bg_cfg_section_create_from_parameters(parameters[i].multi_names[j],
-                                                    parameters[i].multi_parameters[j]);
-            last_subchild = last_child->children;
-            }
-          else
-            {
-            last_subchild->next =
-              bg_cfg_section_create_from_parameters(parameters[i].multi_names[j],
-                                                    parameters[i].multi_parameters[j]);
-            last_subchild = last_subchild->next;
-            }
-          }
-        j++;
-        }
-      }
-    i++;
-    }
-  return ret;
-  }
-
-
 bg_cfg_section_t * bg_cfg_section_find_subsection(bg_cfg_section_t * s,
                                                   const char * name)
   {
+  int i;
   bg_cfg_section_t * prev_section;
   bg_cfg_section_t * section;
 
-  section = s->children;
+  /* Try references */
+  for(i = 0; i < s->num_refs; i++)
+    {
+    if(!strcmp(s->refs[i]->name, name))
+      return s->refs[i];
+    }
 
+  section = s->children;
   prev_section = (bg_cfg_section_t *)0;
   
   while(section)
@@ -790,6 +728,8 @@ void bg_cfg_section_destroy(bg_cfg_section_t * s)
     free(s->gettext_domain);
   if(s->gettext_directory)
     free(s->gettext_directory);
+  if(s->refs)
+    free(s->refs);
   
   free(s);
   }
@@ -1062,7 +1002,8 @@ int bg_cfg_section_get_parameter_float(bg_cfg_section_t * section,
   }
 
 int bg_cfg_section_get_parameter_string(bg_cfg_section_t * section,
-                                         const char * name, const char ** value)
+                                        const char * name,
+                                        const char ** value)
   {
   bg_cfg_item_t * item;
   item = find_item_by_name(section, name, 0);
@@ -1090,7 +1031,6 @@ static void copy_contents(const bg_cfg_section_t * src, bg_cfg_section_t * ret)
   bg_cfg_section_t * src_child;
   bg_cfg_section_t * end_child = (bg_cfg_section_t*)0;
   
-
   /* Copy items */
   
   src_item = src->items;
@@ -1130,6 +1070,40 @@ static void copy_contents(const bg_cfg_section_t * src, bg_cfg_section_t * ret)
     }
   }
 
+static void copy_refs(const bg_cfg_section_t * src, bg_cfg_section_t * ret)
+  {
+  bg_cfg_section_t * end_child, *new_child;
+  int i;
+
+  if(src->num_refs)
+    return;
+  
+  end_child = ret->children;
+  
+  if(ret->children)
+    {
+    end_child = ret->children;
+    while(end_child->next)
+      end_child = end_child->next;
+    }
+
+  for(i = 0; i < src->num_refs; i++)
+    {
+    new_child = bg_cfg_section_copy(src->refs[i]);
+
+    if(ret->children)
+      {
+      end_child->next = new_child;
+      end_child = end_child->next;
+      }
+    else
+      {
+      ret->children = new_child;
+      end_child = new_child;
+      }
+    }
+  }
+
 /* Copy one config section to another */
 
 bg_cfg_section_t * bg_cfg_section_copy(const bg_cfg_section_t * src)
@@ -1139,7 +1113,7 @@ bg_cfg_section_t * bg_cfg_section_copy(const bg_cfg_section_t * src)
   ret = calloc(1, sizeof(*ret));
   ret->name = bg_strdup(ret->name, src->name);
   copy_contents(src, ret);
-  
+  copy_refs(src, ret);
   return ret;
   }
 
@@ -1205,8 +1179,18 @@ void bg_cfg_section_set_name(bg_cfg_section_t * s, const char * name,
   s->gettext_directory = bg_strdup(s->gettext_directory, gettext_directory);
   }
 
-void bg_cfg_section_create_items(bg_cfg_section_t * section,
-                                 const bg_parameter_info_t * info)
+bg_cfg_section_t *
+bg_cfg_section_create_from_parameters(const char * name,
+                                      const bg_parameter_info_t * parameters)
+  {
+  bg_cfg_section_t * ret;
+  ret = bg_cfg_section_create(name);
+  bg_cfg_section_create_items(ret, parameters);
+  return ret;
+  }
+
+static void create_items(bg_cfg_section_t * section,
+                         const bg_parameter_info_t * info, int stop_at_section)
   {
   int i;
   int j;
@@ -1218,35 +1202,66 @@ void bg_cfg_section_create_items(bg_cfg_section_t * section,
 
   while(info[i].name)
     {
-    bg_cfg_section_find_item(section, &(info[i]));
+    if((info[i].type == BG_PARAMETER_SECTION) &&
+       stop_at_section)
+      return;
     
-    if(info[i].multi_parameters)
+    if(info[i].flags & BG_PARAMETER_OWN_SECTION)
       {
-      j = 0;
+      subsection =
+        bg_cfg_section_find_subsection(section, info[i].name);
+      i++;
+      create_items(subsection,
+                   &info[i], 1);
 
-      subsection = bg_cfg_section_find_subsection(section, info[i].name);
-  
-      while(info[i].multi_names[j])
+      /* Skip what we read so far */
+      while(info[i].type != BG_PARAMETER_SECTION)
         {
-        if(info[i].multi_parameters[j])
-          {
-          subsubsection =
-            bg_cfg_section_find_subsection(subsection, info[i].multi_names[j]);
-          
-          bg_cfg_section_create_items(subsubsection,
-                                      info[i].multi_parameters[j]);
-          }
-        j++;
+        if(!info[i].name)
+          return;
+        i++;
         }
       }
-    i++;
+    else
+      {
+      //      fprintf(stderr, "Section: %s, parameter: %s\n",
+      //            section->name, info[i].name);
+      
+      bg_cfg_section_find_item(section, &(info[i]));
+    
+      if(info[i].multi_parameters)
+        {
+        j = 0;
+
+        subsection = bg_cfg_section_find_subsection(section, info[i].name);
+  
+        while(info[i].multi_names[j])
+          {
+          if(info[i].multi_parameters[j])
+            {
+            subsubsection =
+              bg_cfg_section_find_subsection(subsection, info[i].multi_names[j]);
+          
+            bg_cfg_section_create_items(subsubsection,
+                                        info[i].multi_parameters[j]);
+            }
+          j++;
+          }
+        }
+      i++;
+      }
     }
   }
 
+void bg_cfg_section_create_items(bg_cfg_section_t * section,
+                                 const bg_parameter_info_t * info)
+  {
+  create_items(section, info, 0);
+  }
 
 
 void bg_cfg_section_delete_subsection(bg_cfg_section_t * section,
-                                   bg_cfg_section_t * subsection)
+                                      bg_cfg_section_t * subsection)
   {
   bg_cfg_section_t * before;
 
@@ -1277,9 +1292,17 @@ void bg_cfg_section_delete_subsection(bg_cfg_section_t * section,
   
   }
 
-                                  
-void bg_cfg_section_restore(bg_cfg_section_t * section, bg_cfg_section_t * section_saved)
+void bg_cfg_section_add_ref(bg_cfg_section_t * s, bg_cfg_section_t * ref)
   {
-  free_contents(section);
-  copy_contents(section_saved, section);
+  int i;
+  /* Add refs only once */
+  for(i = 0; i < s->num_refs; i++)
+    {
+    if(!strcmp(ref->name, s->refs[i]->name))
+      return;
+    }
+  
+  s->refs = realloc(s->refs, (s->num_refs+1)*sizeof(*s->refs));
+  s->refs[s->num_refs] = ref;
+  s->num_refs++;
   }
