@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -1433,7 +1433,7 @@ int bg_input_plugin_load_edl(bg_plugin_registry_t * reg,
   ret = calloc(1, sizeof(*ret));
   *ret1 = ret;
     
-  ret->plugin_reg = reg;
+  //  ret->plugin_reg = reg;
   ret->plugin = (bg_plugin_common_t*)(&edl_plugin);
   pthread_mutex_init(&(ret->mutex),(pthread_mutexattr_t *)0);
 
