@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -77,6 +77,8 @@ struct bg_dialog_s
   guint select_handler_id;
 
   int result;
+  
+  bg_plugin_registry_t * plugin_reg;
   };
 
 static int parent_index(dialog_section_t * s)
@@ -210,7 +212,7 @@ static void reset_section(dialog_section_t * s)
       if(s->widgets[i].cfg_subsection_save)
         {
         cfg_subsection = bg_cfg_section_find_subsection(s->cfg_section, s->widgets[i].info->name);
-        bg_cfg_section_restore(cfg_subsection, s->widgets[i].cfg_subsection_save);
+        bg_cfg_section_transfer(s->widgets[i].cfg_subsection_save, cfg_subsection);
         }
       if(s->widgets[i].funcs->apply_sub_params)
         s->widgets[i].funcs->apply_sub_params(&(s->widgets[i]));
@@ -464,7 +466,6 @@ static bg_dialog_t * create_dialog(const char * title)
                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
   gtk_container_add(GTK_CONTAINER(ret->scrolledwindow), ret->treeview);
   gtk_widget_show(ret->scrolledwindow);
-
   
   /* Create the rest */
 
@@ -474,7 +475,7 @@ static bg_dialog_t * create_dialog(const char * title)
   gtk_widget_show(hbox);
   
   ret->mainbox = gtk_vbox_new(0, 5);
-  gtk_box_pack_start(GTK_BOX(ret->mainbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(ret->mainbox), hbox, TRUE, TRUE, 0);
   
   buttonbox = gtk_hbutton_box_new();
   gtk_box_set_spacing(GTK_BOX(buttonbox), 10);
@@ -494,13 +495,14 @@ static bg_dialog_t * create_dialog(const char * title)
 
 static GtkWidget * create_section(dialog_section_t * section,
                                   const bg_parameter_info_t * info,
-                                  bg_cfg_section_t * cfg_section,
+                                  bg_cfg_section_t * s,
                                   bg_set_parameter_func_t set_param,
                                   bg_get_parameter_func_t get_param,
                                   void * data,
-                                  const char * translation_domain)
+                                  const char * translation_domain,
+                                  bg_plugin_registry_t * plugin_reg)
   {
-  int i, count;
+  int i, count, j;
   int row, column, num_columns;
   bg_cfg_section_t * cfg_subsection;
   
@@ -523,6 +525,10 @@ static GtkWidget * create_section(dialog_section_t * section,
   
   section->num_widgets = 0;
   i = 0;
+
+  if(info[0].type == BG_PARAMETER_SECTION)
+    i++;
+  
   while(info[i].name &&
         (info[i].type != BG_PARAMETER_SECTION))
     {
@@ -531,7 +537,13 @@ static GtkWidget * create_section(dialog_section_t * section,
     i++;
     }
   section->infos = info;
-  section->cfg_section = cfg_section;
+  
+  if((info[0].type == BG_PARAMETER_SECTION) &&
+     (info[0].flags & BG_PARAMETER_OWN_SECTION))
+    section->cfg_section =
+      bg_cfg_section_find_subsection(s, info[0].name);
+  else
+    section->cfg_section = s;
   section->callback_data = data;
   section->set_param = set_param;
   section->get_param = get_param;
@@ -559,33 +571,50 @@ static GtkWidget * create_section(dialog_section_t * section,
       translation_domain = info[i].gettext_domain;
     if(info[i].gettext_directory)
       bg_bindtextdomain(translation_domain, info[i].gettext_directory);
+
+    /* Check what to skip */
+    if((info[i].flags & BG_PARAMETER_HIDE_DIALOG) ||
+       ((info[i].type == BG_PARAMETER_BUTTON) && !set_param) ||
+       (info[i].type == BG_PARAMETER_SECTION))
+      {
+      i++;
+      continue;
+      }
     
-    if(info[i].flags & BG_PARAMETER_HIDE_DIALOG)
+    if(info[i].flags & BG_PARAMETER_PLUGIN)
       {
-      i++;
-      continue;
+      section->widgets[count].plugin_reg = plugin_reg;
       }
-    if((info[i].type == BG_PARAMETER_BUTTON) &&
-       !set_param)
-      {
-      i++;
-      continue;
-      }
-      
+    
     if((info[i].flags & BG_PARAMETER_SYNC) ||
        (info[i].type == BG_PARAMETER_BUTTON))
       {
       section->widgets[count].change_callback = set_param;
       section->widgets[count].change_callback_data = data;
       }
-    section->widgets[count].info = &(info[i]);
+    section->widgets[count].info = &info[i];
 
-    section->widgets[count].cfg_section = cfg_section;
-    if(info[i].multi_parameters)
+    section->widgets[count].cfg_section = section->cfg_section;
+    
+    if(info[i].multi_parameters && section->cfg_section)
       {
-      cfg_subsection = bg_cfg_section_find_subsection(cfg_section, info[i].name);
+      cfg_subsection = bg_cfg_section_find_subsection(section->cfg_section, info[i].name);
+
+      /* Add references to the plugin registry */
+      if(section->widgets[count].plugin_reg)
+        {
+        j = 0;
+        while(info[i].multi_names[j])
+          {
+          bg_cfg_section_add_ref(cfg_subsection,
+                                 bg_plugin_registry_get_section(section->widgets[count].plugin_reg,
+                                                                info[i].multi_names[j]));
+          j++;
+          }
+        }
       section->widgets[count].cfg_subsection_save = bg_cfg_section_copy(cfg_subsection);
       }
+    
     switch(info[i].type)
       {
       case BG_PARAMETER_BUTTON:
@@ -656,12 +685,12 @@ static GtkWidget * create_section(dialog_section_t * section,
         break;
       case BG_PARAMETER_MULTI_LIST:
         bg_gtk_create_multi_list(&(section->widgets[count]),
-                                 set_param, data,
+                                 set_param, get_param, data,
                                  translation_domain);
         break;
       case BG_PARAMETER_MULTI_CHAIN:
         bg_gtk_create_multi_chain(&(section->widgets[count]),
-                                  set_param, data,
+                                  set_param, get_param, data,
                                   translation_domain);
         break;
       case BG_PARAMETER_POSITION:
@@ -675,20 +704,22 @@ static GtkWidget * create_section(dialog_section_t * section,
                                  &row, &num_columns);
 
     /* Get the value from the config data... */
-    if(cfg_section)
-      bg_cfg_section_get_parameter(cfg_section, &(info[i]),
+    if(section->cfg_section)
+      bg_cfg_section_get_parameter(section->cfg_section, &info[i],
                                    &(section->widgets[count].value));
+    /* ... or from the get_param function */
+    else if(get_param &&
+            get_param(data, info[i].name, &(section->widgets[count].value)))
+      ;
     /* ... or from the parameter default */
     else
-      {
       bg_parameter_value_copy(&(section->widgets[count].value),
                               &(info[i].val_default),
-                              &(info[i]));
-      }
+                              &info[i]);
     
     bg_parameter_value_copy(&section->widgets[count].last_value,
                             &section->widgets[count].value,
-                            &(info[i]));
+                            &info[i]);
     
     if(section->widgets[count].info->flags & BG_PARAMETER_SYNC)
       bg_gtk_change_callback_block(&section->widgets[count], 1);
@@ -768,20 +799,21 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
       gtk_tree_store_append(GTK_TREE_STORE(model), &root_iter, NULL);
       gtk_tree_store_set(GTK_TREE_STORE(model), &root_iter, COLUMN_NAME,
                          TR_DOM(info[index].long_name), -1);
-            
-      while(info[index].type == BG_PARAMETER_SECTION)
-        index++;
       
       table = create_section(&(ret->root_section.children[i]), &(info[index]),
                              section, set_param, get_param, callback_data,
-                             translation_domain);
+                             translation_domain, ret->plugin_reg);
       
       ret->root_section.children[i].notebook_index =
         gtk_notebook_get_n_pages(GTK_NOTEBOOK(ret->notebook));
       gtk_notebook_append_page(GTK_NOTEBOOK(ret->notebook), table, label);
 
       ret->root_section.children[i].parent = &(ret->root_section);
-            
+
+      while(info[index].type == BG_PARAMETER_SECTION)
+        index++;
+
+      
       while(info[index].name &&
             (info[index].type != BG_PARAMETER_SECTION))
         index++;
@@ -793,11 +825,11 @@ bg_dialog_t * bg_dialog_create(bg_cfg_section_t * section,
     gtk_widget_show(label);
 
     ret->root_section.num_children = 1;
-    ret->root_section.children = calloc(1,
-                           ret->root_section.num_children * sizeof(dialog_section_t));
+    ret->root_section.children = calloc(ret->root_section.num_children,
+                                        sizeof(*ret->root_section.children));
     table =
       create_section(ret->root_section.children, info, section, set_param, get_param,
-                     callback_data, (const char *)0);
+                     callback_data, (const char *)0, ret->plugin_reg);
     gtk_notebook_append_page(GTK_NOTEBOOK(ret->notebook), table, label);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(ret->notebook), 1);
     gtk_widget_hide(ret->scrolledwindow);
@@ -854,7 +886,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
     
     table = create_section(&(parent->children[parent->num_children]),
                            info, section, set_param, get_param, callback_data,
-                           (const char*)0);
+                           (const char*)0, d->plugin_reg);
     tab_label = gtk_label_new(name);
     gtk_widget_show(tab_label);
 
@@ -915,13 +947,11 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
       
       gtk_tree_store_set(GTK_TREE_STORE(model), &iter, COLUMN_NAME,
                          info[item_index].long_name, -1);
-
-      item_index++;
       
       table = create_section(&(parent->children[section_index]),
                              &(info[item_index]),
                              section, set_param, get_param, callback_data,
-                             translation_domain);
+                             translation_domain, d->plugin_reg);
       
       parent->children[section_index].parent = parent;
 
@@ -931,6 +961,7 @@ void bg_dialog_add_child(bg_dialog_t *d, void * _parent,
       gtk_notebook_append_page(GTK_NOTEBOOK(d->notebook),
                                table, tab_label);
       
+      item_index++;
       while((info[item_index].name) &&
             (info[item_index].type != BG_PARAMETER_SECTION))
         item_index++;
@@ -960,7 +991,7 @@ int bg_dialog_show(bg_dialog_t * d, void * parent)
   if(d->visible)
     {
     gtk_window_present(GTK_WINDOW(d->window));
-    return;
+    return 0;
     }
   if(parent)
     {
@@ -1082,3 +1113,7 @@ void * bg_dialog_add_parent(bg_dialog_t *d, void * _parent, const char * label)
   return &(parent->children[parent->num_children-1]);
   }
 
+void bg_dialog_set_plugin_registry(bg_dialog_t * d, bg_plugin_registry_t * plugin_reg)
+  {
+  d->plugin_reg = plugin_reg;
+  }
