@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -288,6 +288,9 @@ void bg_gtk_time_display_update(bg_gtk_time_display_t * d,
     case BG_GTK_DISPLAY_MODE_TIMECODE:
       gavl_timecode_prettyprint_short(time, buf);
       break;
+    case BG_GTK_DISPLAY_MODE_FRAMECOUNT:
+      sprintf(buf, "%"PRId64, time);
+      break;
     }
   
   pos = &(buf[strlen(buf)]);
