@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -32,8 +32,6 @@
 #include <gui_gtk/plugin.h>
 #include <gui_gtk/gtkutils.h>
 
-
-
 struct bg_gtk_plugin_widget_single_s
   {
   GtkWidget * label;
@@ -395,7 +393,7 @@ bg_gtk_plugin_widget_single_create(char * label,
                                                    type_mask,
                                                    flag_mask);
 
-  default_info = bg_plugin_registry_get_default(reg, type_mask);
+  default_info = bg_plugin_registry_get_default(reg, type_mask, flag_mask);
 
   
   /* Make combo */
