@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -686,6 +686,10 @@ static void update_pixmaps(bg_gtk_vumeter_t * m)
 static void draw_dynamic(bg_gtk_vumeter_t * m)
   {
   int i;
+
+  if(!GTK_WIDGET_REALIZED(m->layout) || !m->pixmap_width || !m->pixmap_height)
+    return;
+  
   if(!m->pixmaps_valid)
     update_pixmaps(m);
 
@@ -858,14 +862,10 @@ void bg_gtk_vumeter_set_format(bg_gtk_vumeter_t * m,
   m->num_channels = format->num_channels;
   }
 
-void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
-                           gavl_audio_frame_t * frame)
+void bg_gtk_vumeter_update_peak(bg_gtk_vumeter_t * m,
+                                double * ampl, int samples)
   {
   int i;
-  double ampl[GAVL_MAX_CHANNELS];
-  gavl_peak_detector_reset(m->pd);
-  gavl_peak_detector_update(m->pd, frame);
-  gavl_peak_detector_get_peaks(m->pd, (double*)0, (double*)0, ampl);
   
   for(i = 0; i < m->num_channels; i++)
     {
@@ -883,7 +883,7 @@ void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
         m->meters[i].peak_age = 0;
         }
       else
-        m->meters[i].peak_age += frame->valid_samples;
+        m->meters[i].peak_age += samples;
       }
     else /* Lowpass */
       {
@@ -895,7 +895,7 @@ void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
         m->meters[i].peak_age = 0;
         }
       else
-        m->meters[i].peak_age += frame->valid_samples;
+        m->meters[i].peak_age += samples;
       }
     }
   
@@ -903,6 +903,16 @@ void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
   draw_dynamic(m);
   }
 
+void bg_gtk_vumeter_update(bg_gtk_vumeter_t * m,
+                           gavl_audio_frame_t * frame)
+  {
+  double ampl[GAVL_MAX_CHANNELS];
+  gavl_peak_detector_reset(m->pd);
+  gavl_peak_detector_update(m->pd, frame);
+  gavl_peak_detector_get_peaks(m->pd, (double*)0, (double*)0, ampl);
+  bg_gtk_vumeter_update_peak(m, ampl, frame->valid_samples);
+  }
+
 void bg_gtk_vumeter_draw(bg_gtk_vumeter_t * m)
   {
   pthread_mutex_lock(&(m->analysis_mutex));
