@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -88,8 +88,11 @@ static const struct
   }
 flag_names[] =
   {
-    { "sync",        BG_PARAMETER_SYNC },
+    { "sync",        BG_PARAMETER_SYNC        },
     { "hide_dialog", BG_PARAMETER_HIDE_DIALOG },
+    { "no_sort",     BG_PARAMETER_NO_SORT     },
+    { "plugin",      BG_PARAMETER_PLUGIN      },
+    { "own_section", BG_PARAMETER_OWN_SECTION },
   };
 
 static int string_to_flags(const char * str)
@@ -811,3 +814,16 @@ void bg_parameters_2_xml(const bg_parameter_info_t * info, xmlNodePtr xml_parame
   BG_XML_SET_PROP(xml_parameters, num_key, tmp_string);
   free(tmp_string);
   }
+
+void
+bg_parameters_dump(const bg_parameter_info_t * info, const char * filename)
+  {
+  xmlDocPtr  xml_doc;
+  xmlNodePtr xml_params;
+  xml_doc = xmlNewDoc((xmlChar*)"1.0");
+  xml_params = xmlNewDocRawNode(xml_doc, NULL, (xmlChar*)"PARAMETERS", NULL);
+  xmlDocSetRootElement(xml_doc, xml_params);
+  bg_parameters_2_xml(info, xml_params);
+  xmlSaveFile(filename, xml_doc);
+  xmlFreeDoc(xml_doc);
+  }
