@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -29,21 +29,40 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "player.video"
 
-void bg_player_video_create(bg_player_t * p, bg_plugin_registry_t * plugin_reg)
+void bg_player_video_create(bg_player_t * p,
+                            bg_plugin_registry_t * plugin_reg)
   {
-  bg_gavl_video_options_init(&(p->video_stream.options));
-  p->video_stream.fc =
-    bg_video_filter_chain_create(&p->video_stream.options,
-                                 plugin_reg);
+  bg_player_video_stream_t * s = &p->video_stream;
+  
+  s->th = bg_player_thread_create(p->thread_common);
+  
+  bg_gavl_video_options_init(&s->options);
+
+  s->fc = bg_video_filter_chain_create(&s->options,
+                                       plugin_reg);
+  
+  pthread_mutex_init(&s->config_mutex,NULL);
+  pthread_mutex_init(&s->eof_mutex,NULL);
+  s->ss = &p->subtitle_stream;
+  s->msg_queue = bg_msg_queue_create();
+  
+  s->accel_map = bg_accelerator_map_create();
+  s->osd = bg_osd_create();
   
-  pthread_mutex_init(&(p->video_stream.config_mutex),(pthread_mutexattr_t *)0);
   }
 
 void bg_player_video_destroy(bg_player_t * p)
   {
-  pthread_mutex_destroy(&(p->video_stream.config_mutex));
-  bg_gavl_video_options_free(&(p->video_stream.options));
-  bg_video_filter_chain_destroy(p->video_stream.fc);
+  bg_player_video_stream_t * s = &p->video_stream;
+  pthread_mutex_destroy(&s->config_mutex);
+  pthread_mutex_destroy(&s->eof_mutex);
+  bg_gavl_video_options_free(&s->options);
+  bg_video_filter_chain_destroy(s->fc);
+  bg_player_thread_destroy(s->th);
+  bg_msg_queue_destroy(s->msg_queue);
+
+  bg_osd_destroy(s->osd);
+  bg_accelerator_map_destroy(s->accel_map);
   }
 
 int bg_player_video_init(bg_player_t * player, int video_stream)
@@ -51,8 +70,14 @@ int bg_player_video_init(bg_player_t * player, int video_stream)
   bg_player_video_stream_t * s;
   s = &(player->video_stream);
 
-  s->in_func = bg_player_input_read_video;
-  s->in_data = player->input_context;
+  s->skip = 0;
+  
+  if(s->do_still)
+    s->in_func = bg_player_input_read_video_still;
+  else
+    s->in_func = bg_player_input_read_video;
+
+  s->in_data = player;
   s->in_stream = player->current_video_stream;
   
   if(!DO_VIDEO(player->flags))
@@ -60,7 +85,7 @@ int bg_player_video_init(bg_player_t * player, int video_stream)
   
   if(!DO_SUBTITLE_ONLY(player->flags))
     {
-    bg_player_input_get_video_format(player->input_context);
+    bg_player_input_get_video_format(player);
     
     bg_video_filter_chain_connect_input(s->fc, s->in_func,
                                         s->in_data, s->in_stream);
@@ -72,35 +97,21 @@ int bg_player_video_init(bg_player_t * player, int video_stream)
     s->in_stream = 0;
     }
   
-  if(!bg_player_ov_init(player->ov_context))
+  if(!bg_player_ov_init(&player->video_stream))
     return 0;
 
   if(!DO_SUBTITLE_ONLY(player->flags))
     bg_video_filter_chain_set_out_format(s->fc, &(s->output_format));
   
-  /* Initialize video fifo */
-
-  if(DO_VIDEO(player->flags))
-    {
-    if(s->input_format.framerate_mode == GAVL_FRAMERATE_STILL)
-      s->fifo = bg_fifo_create(2,
-                               bg_player_ov_create_frame,
-                               (void*)(player->ov_context));
-    else 
-      s->fifo = bg_fifo_create(NUM_VIDEO_FRAMES,
-                               bg_player_ov_create_frame,
-                               (void*)(player->ov_context));
-    }
-  
   if(DO_SUBTITLE_ONLY(player->flags))
     {
     /* Video output already initialized */
-    bg_player_ov_set_subtitle_format(player->ov_context);
+    bg_player_ov_set_subtitle_format(&player->video_stream);
 
     bg_player_subtitle_init_converter(player);
     
     s->in_func = bg_player_input_read_video_subtitle_only;
-    s->in_data = player->input_context;
+    s->in_data = player;
     s->in_stream = 0;
     }
   
@@ -109,12 +120,7 @@ int bg_player_video_init(bg_player_t * player, int video_stream)
 
 void bg_player_video_cleanup(bg_player_t * player)
   {
-  if(player->video_stream.fifo)
-    {
-    bg_fifo_destroy(player->video_stream.fifo, bg_player_ov_destroy_frame,
-                    (void*)(player->ov_context));
-    player->video_stream.fifo = (bg_fifo_t*)0;
-    }
+  
   }
 
 /* Configuration stuff */
@@ -150,25 +156,6 @@ const bg_parameter_info_t * bg_player_get_video_parameters(bg_player_t * p)
   return parameters;
   }
 
-#if 0
-void bg_player_set_video_parameter(void * data, char * name,
-                                   bg_parameter_value_t * val)
-  {
-  bg_player_t * player = (bg_player_t*)data;
-
-  if(!name)
-    return;
-
-  pthread_mutex_lock(&(player->video_stream.config_mutex));
-
-  bg_gavl_video_set_parameter(&(player->video_stream.options),
-                              name, val);
-  
-  pthread_mutex_unlock(&(player->video_stream.config_mutex));
-
-  }
-#endif
-
 void bg_player_set_video_parameter(void * data, const char * name,
                                    const bg_parameter_value_t * val)
   {
@@ -277,3 +264,32 @@ void bg_player_set_video_filter_parameter(void * data, const char * name,
 
   
   }
+
+int
+bg_player_read_video(bg_player_t * p, gavl_video_frame_t * frame)
+  {
+  bg_player_video_stream_t * s = &p->video_stream;
+  return s->in_func(s->in_data, frame, s->in_stream);
+  }
+
+void bg_player_video_set_eof(bg_player_t * p)
+  {
+  bg_msg_t * msg;
+  
+  bg_log(BG_LOG_INFO, LOG_DOMAIN, "Detected EOF");
+  pthread_mutex_lock(&p->video_stream.eof_mutex);
+  pthread_mutex_lock(&p->audio_stream.eof_mutex);
+
+  p->video_stream.eof = 1;
+  
+  if(p->audio_stream.eof)
+    {
+    msg = bg_msg_queue_lock_write(p->command_queue);
+    bg_msg_set_id(msg, BG_PLAYER_CMD_SETSTATE);
+    bg_msg_set_arg_int(msg, 0, BG_PLAYER_STATE_EOF);
+    bg_msg_queue_unlock_write(p->command_queue);
+    }
+  
+  pthread_mutex_unlock(&p->audio_stream.eof_mutex);
+  pthread_mutex_unlock(&p->video_stream.eof_mutex);
+  }
