@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -80,9 +80,6 @@ flag_names[] =
     { "File",         BG_PLUGIN_FILE           }, /* Plugin reads/writes files      */
     { "URL",          BG_PLUGIN_URL            }, /* Plugin reads URLs or streams   */
     { "Playback",     BG_PLUGIN_PLAYBACK       }, /* Output plugins for playback    */
-    { "Bypass",       BG_PLUGIN_BYPASS         }, /* Plugin can bypass playback engine */
-    { "KeepRunning", BG_PLUGIN_KEEP_RUNNING   }, /* Plugin should not be stopped and restarted if tracks change */
-    { "HasSync",     BG_PLUGIN_INPUT_HAS_SYNC }, /* FOR INPUTS ONLY: Plugin will set the time via callback */
     { "Stdin",          BG_PLUGIN_STDIN         }, /* Plugin reads from stdin */
     { "Tuner",          BG_PLUGIN_TUNER         }, /* Plugin has tuner */
     { "Filter1",        BG_PLUGIN_FILTER_1      }, /* Filter with one input port */
@@ -91,6 +88,8 @@ flag_names[] =
     { "VisualizeGL",    BG_PLUGIN_VISUALIZE_GL },
     { "PP",             BG_PLUGIN_PP },
     { "Callbacks",      BG_PLUGIN_CALLBACKS },
+    { "Broadcast",      BG_PLUGIN_BROADCAST },
+    { "Devparam",       BG_PLUGIN_DEVPARAM },
     { "Unsupported",    BG_PLUGIN_UNSUPPORTED   },
     { (char*)0,    0                           },
   };
@@ -468,6 +467,17 @@ static void save_plugin(xmlNodePtr parent, const bg_plugin_info_t * info)
     xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
     }
 
+  xml_item = xmlNewTextChild(xml_plugin, (xmlNsPtr)0, (xmlChar*)module_time_key, NULL);
+  sprintf(buffer, "%ld", info->module_time);
+  xmlAddChild(xml_item, BG_XML_NEW_TEXT(buffer));
+  xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
+
+  xml_item = xmlNewTextChild(xml_plugin, (xmlNsPtr)0, (xmlChar*)priority_key, NULL);
+  sprintf(buffer, "%d", info->priority);
+  xmlAddChild(xml_item, BG_XML_NEW_TEXT(buffer));
+  xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
+
+
   
   if(info->parameters)
     {
@@ -593,15 +603,6 @@ static void save_plugin(xmlNodePtr parent, const bg_plugin_info_t * info)
     xmlAddChild(xml_item, BG_XML_NEW_TEXT(buffer));
     xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
     }
-  xml_item = xmlNewTextChild(xml_plugin, (xmlNsPtr)0, (xmlChar*)module_time_key, NULL);
-  sprintf(buffer, "%ld", info->module_time);
-  xmlAddChild(xml_item, BG_XML_NEW_TEXT(buffer));
-  xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
-
-  xml_item = xmlNewTextChild(xml_plugin, (xmlNsPtr)0, (xmlChar*)priority_key, NULL);
-  sprintf(buffer, "%d", info->priority);
-  xmlAddChild(xml_item, BG_XML_NEW_TEXT(buffer));
-  xmlAddChild(xml_plugin, BG_XML_NEW_TEXT("\n"));
 
   if(info->devices && info->devices->device)
     save_devices(xml_plugin, info->devices);
