@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -34,6 +34,7 @@
 
 #include <gmerlin/cfg_registry.h>
 #include <gmerlin/pluginregistry.h>
+#include <gmerlin/pluginfuncs.h>
 #include <config.h>
 #include <gmerlin/utils.h>
 #include <gmerlin/singlepic.h>
@@ -692,23 +693,25 @@ typedef struct
   char * filename_buffer;
   
   gavl_video_format_t format;
-
+  
+  bg_encoder_callbacks_t * cb;
+  
   int have_header;
+  
+  bg_iw_callbacks_t iw_callbacks;
+  
   } encoder_t;
 
+static int iw_callbacks_create_output_file(void * priv, const char * filename)
+  {
+  encoder_t * e = priv;
+  return bg_encoder_cb_create_output_file(e->cb, filename);
+  }
+
 static bg_parameter_info_t *
 create_encoder_parameters(bg_plugin_registry_t * plugin_reg)
   {
-  int i;
-  bg_parameter_info_t * ret;
-  ret =
-    calloc(sizeof(parameters_encoder)/sizeof(parameters_encoder[0])+1,
-           sizeof(*ret));
-  
-  for(i = 0; i < sizeof(parameters_encoder)/sizeof(parameters_encoder[0]); i++)
-    {
-    bg_parameter_info_copy(&ret[i], &parameters_encoder[i]);
-    }
+  bg_parameter_info_t * ret = bg_parameter_info_copy_array(parameters_encoder);
   bg_plugin_registry_set_parameter_info(plugin_reg,
                                         BG_PLUGIN_IMAGE_WRITER,
                                         BG_PLUGIN_FILE, &ret[0]);
@@ -750,6 +753,9 @@ static void set_parameter_encoder(void * priv, const char * name,
       info = bg_plugin_find_by_name(e->plugin_reg, val->val_str);
       e->plugin_handle = bg_plugin_load(e->plugin_reg, info);
       e->image_writer = (bg_image_writer_plugin_t*)(e->plugin_handle->plugin);
+      
+      if(e->image_writer->set_callbacks)
+        e->image_writer->set_callbacks(e->plugin_handle->priv, &e->iw_callbacks);
       }
     }
   else if(!strcmp(name, "frame_digits"))
@@ -769,27 +775,12 @@ static void set_parameter_encoder(void * priv, const char * name,
     }
   }
 
-
-static const char * get_extension_encoder(void * data)
+static void set_callbacks_encoder(void * data, bg_encoder_callbacks_t * cb)
   {
-  const char * plugin_extension;
-  
-  encoder_t * e;
-  e = (encoder_t *)data;
-
-  if(!e->extension)
-    {
-    /* Create extension */
-    
-    plugin_extension = e->image_writer->get_extension(e->plugin_handle->priv);
-    e->extension_mask = bg_sprintf("-%%0%d"PRId64"%s", e->frame_digits, plugin_extension);
-    e->extension      = bg_sprintf(e->extension_mask, (int64_t)e->frame_offset);
-
-    }
-  return e->extension;
+  encoder_t * e = data;
+  e->cb = cb;
   }
 
-
 static int open_encoder(void * data, const char * filename,
                         const bg_metadata_t * metadata,
                         const bg_chapter_list_t * chapter_list)
@@ -804,9 +795,21 @@ static int open_encoder(void * data, const char * filename,
   e->mask = bg_strdup(e->mask, filename);
 
   filename_len = strlen(filename);
-  
-  e->mask[filename_len - strlen(get_extension_encoder(data))] = '\0';
 
+  if(!e->extension)
+    {
+    char ** extensions;
+
+    extensions = bg_strbreak(e->image_writer->extensions, ' ');
+    
+    /* Create extension */
+    
+    e->extension_mask = bg_sprintf("-%%0%d"PRId64".%s", e->frame_digits, extensions[0]);
+    e->extension      = bg_sprintf(e->extension_mask, (int64_t)e->frame_offset);
+    
+    bg_strbreak_free(extensions);
+    }
+  
   e->mask = bg_strcat(e->mask, e->extension_mask);
 
 
@@ -857,7 +860,7 @@ static int start_encoder(void * data)
   return e->have_header;
   }
      
-static int add_video_stream_encoder(void * data, gavl_video_format_t * format)
+static int add_video_stream_encoder(void * data, const gavl_video_format_t * format)
   {
   encoder_t * e;
   e = (encoder_t *)data;
@@ -970,11 +973,11 @@ const bg_encoder_plugin_t encoder_plugin =
     .max_audio_streams = 0,
     .max_video_streams = 1,
 
-    .get_extension =     get_extension_encoder,
-    
     /* Open a file, filename base is without extension, which
        will be added by the plugin */
-        
+    
+    .set_callbacks =     set_callbacks_encoder,
+    
     .open =              open_encoder,
     .get_filename =      get_filename_encoder,
     
@@ -1031,5 +1034,8 @@ void * bg_singlepic_encoder_create(bg_plugin_registry_t * reg)
 
   ret->plugin_reg = reg;
 
+  ret->iw_callbacks.data = ret;
+  ret->iw_callbacks.create_output_file = iw_callbacks_create_output_file;
+  
   return ret;
   }
