@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -40,7 +40,7 @@
 
 #include <fcntl.h>
 //#include <sys/types.h>
-//#include <sys/socket.h>
+#include <sys/socket.h>
 #include <sys/un.h>
 
 #include <netinet/in.h>
@@ -73,6 +73,7 @@ bg_host_address_t * bg_host_address_create()
 
 void bg_host_address_destroy(bg_host_address_t * a)
   {
+  freeaddrinfo(a->addr);
   free(a);
   }
 
@@ -95,69 +96,6 @@ static int create_socket(int domain, int type, int protocol)
   return ret;
   }
 
-
-/* gethostbyname */
-
-#if 0
-static int hostbyname(bg_host_address_t * a, const char * hostname)
-  {
-  struct hostent   h_ent;
-  struct hostent * h_ent_p;
-  int gethostbyname_buffer_size;
-
-  char * gethostbyname_buffer = (char*)0;
-  int result, herr;
-  int ret = 0;
-  
-  gethostbyname_buffer_size = 1024;
-  gethostbyname_buffer = malloc(gethostbyname_buffer_size);
-
-    
-  while((result = gethostbyname_r(hostname,
-                                  &h_ent,
-                                  gethostbyname_buffer,
-                                  gethostbyname_buffer_size,
-                                  &h_ent_p, &herr)) == ERANGE)
-    {
-    gethostbyname_buffer_size *= 2;
-    gethostbyname_buffer = realloc(gethostbyname_buffer,
-                                  gethostbyname_buffer_size);
-    }
-  
-  /* Fill in return value           */
-
-  if(result || (h_ent_p == NULL))
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Could not resolve address");
-    goto fail;
-    }
-  if(h_ent_p->h_addrtype == AF_INET)
-    {
-    a->addr_type = AF_INET;
-    memcpy(&(a->addr.ipv4_addr),
-           h_ent_p->h_addr, sizeof(a->addr.ipv4_addr));
-    }
-  else if(h_ent_p->h_addrtype == AF_INET6)
-    {
-    a->addr_type = AF_INET6;
-    memcpy(&(a->addr.ipv6_addr),
-           h_ent_p->h_addr, sizeof(a->addr.ipv6_addr));
-    }
-  else
-    {
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "No known address space");
-    goto fail;
-    }
-  ret = 1;
-
-  fail:
-  
-  if(gethostbyname_buffer)
-    free(gethostbyname_buffer);
-  return ret;
-  }
-#endif
-
 /* */
 
 static void address_set_port(struct addrinfo * info, int port)
@@ -212,7 +150,12 @@ static struct addrinfo * hostbyname(const char * hostname, int port, int socktyp
            hostname, gai_strerror(err));
     return (struct addrinfo *)0;
     }
-
+#if 0
+  if(ret[0].ai_addr->sa_family == AF_INET)
+    fprintf(stderr, "Got IPV4 address\n");
+  else if(ret[0].ai_addr->sa_family == AF_INET6)
+    fprintf(stderr, "Got IPV6 address\n");
+#endif  
   address_set_port(ret, port);
   
   return ret;
@@ -236,6 +179,8 @@ int bg_host_address_set(bg_host_address_t * a, const char * hostname,
 int bg_socket_connect_inet(bg_host_address_t * a, int milliseconds)
   {
   int ret = -1;
+  int err;
+  socklen_t err_len;
 
   struct timeval timeout;
   fd_set write_fds;
@@ -263,11 +208,19 @@ int bg_socket_connect_inet(bg_host_address_t * a, int milliseconds)
       timeout.tv_usec = 1000 * (milliseconds % 1000);
       FD_ZERO (&write_fds);
       FD_SET (ret, &write_fds);
-      if(!select(ret+1, (fd_set*)0, &write_fds,(fd_set*)0,&timeout))
+
+      err = select(ret+1, (fd_set*)0, &write_fds,(fd_set*)0,&timeout);
+      
+      if(!err)
         {
         bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Connection timed out");
         return -1;
         }
+      else if(err < 0)
+        {
+        bg_log(BG_LOG_ERROR, LOG_DOMAIN, "select() failed on connect");
+        return -1;
+        }
       }
     else
       {
@@ -275,6 +228,18 @@ int bg_socket_connect_inet(bg_host_address_t * a, int milliseconds)
       return -1;
       }
     }
+
+  /* Check for error */
+
+  err_len = sizeof(err);
+  getsockopt(ret, SOL_SOCKET, SO_ERROR, &err, &err_len);
+
+  if(err)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Connecting failed: %s",
+           strerror(err));
+    return -1;
+    }
   
   /* Set back to blocking mode */
   
@@ -316,17 +281,65 @@ void bg_socket_disconnect(int sock)
   close(sock);
   }
 
+/* Older systems assign an ipv4 address to localhost,
+   newer systems (e.g. Ubuntu Karmic) assign an ipv6 address to localhost.
+
+   To test this, we make a name lookup for "localhost" and test if it returns
+   an IPV4 or an IPV6 address */
+
+static int have_ipv6()
+  {
+  struct addrinfo hints;
+  struct addrinfo * ret;
+  int err, has_ipv6;
+  
+  memset(&hints, 0, sizeof(hints));
+  hints.ai_family   = PF_UNSPEC;
+  hints.ai_socktype = SOCK_STREAM; // SOCK_DGRAM
+  hints.ai_protocol = 0; // 0
+  hints.ai_flags    = 0;
+
+  if((err = getaddrinfo("localhost", (char*)0 /* service */,
+                        &hints, &ret)))
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot resolve address of localhost: %s",
+           gai_strerror(err));
+    return 0;
+    }
+
+  if(ret[0].ai_addr->sa_family == AF_INET6)
+    has_ipv6 = 1;
+  else
+    has_ipv6 = 0;
+
+  freeaddrinfo(ret);
+  return has_ipv6;
+  }
+
 /* Server socket (stream oriented) */
 
 int bg_listen_socket_create_inet(int port,
                                  int queue_size,
-                                 uint32_t addr)
+                                 int flags)
   {
-  int ret;
-  struct sockaddr_in name;
+  int ret, err, use_ipv6;
+  struct sockaddr_in  name_ipv4;
+  struct sockaddr_in6 name_ipv6;
+
+  if(flags & BG_SOCKET_LOOPBACK)
+    use_ipv6 = have_ipv6();
+  else
+    use_ipv6 = 0;
+  
+  memset(&name_ipv4, 0, sizeof(name_ipv4));
+  memset(&name_ipv6, 0, sizeof(name_ipv6));
+  
+  if(use_ipv6)
+    ret = create_socket(PF_INET6, SOCK_STREAM, 0);
+  else
+    ret = create_socket(PF_INET, SOCK_STREAM, 0);
   
   /* Create the socket. */
-  ret = create_socket(PF_INET, SOCK_STREAM, 0);
   if (ret < 0)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot create inet server socket");
@@ -334,10 +347,30 @@ int bg_listen_socket_create_inet(int port,
     }
   
   /* Give the socket a name. */
-  name.sin_family = AF_INET;
-  name.sin_port = htons (port);
-  name.sin_addr.s_addr = htonl (INADDR_ANY);
-  if (bind (ret, (struct sockaddr *) &name, sizeof (name)) < 0)
+
+  if(use_ipv6)
+    {
+    name_ipv6.sin6_family = AF_INET6;
+    name_ipv6.sin6_port   = htons(port);
+    if(flags & BG_SOCKET_LOOPBACK)
+      name_ipv6.sin6_addr = in6addr_loopback;
+    else
+      name_ipv6.sin6_addr = in6addr_any;
+
+    err = bind(ret, (struct sockaddr *)&name_ipv6, sizeof(name_ipv6));
+    }
+  else
+    {
+    name_ipv4.sin_family = AF_INET;
+    name_ipv4.sin_port = htons(port);
+    if(flags & BG_SOCKET_LOOPBACK)
+      name_ipv4.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+    else
+      name_ipv4.sin_addr.s_addr = htonl(INADDR_ANY);
+    err = bind(ret, (struct sockaddr *)&name_ipv4, sizeof(name_ipv4));
+    }
+  
+  if(err < 0)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot bind inet socket: %s", strerror(errno));
     return -1;
@@ -441,7 +474,11 @@ int bg_socket_write_data(int fd, const uint8_t * data, int len)
   int result;
   result = send(fd, data, len, MSG_NOSIGNAL);
   if(result != len)
+    {
+    bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Sending data failed: %s", 
+           strerror(errno));    
     return 0;
+    }
   return result;
   }
 
