@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -44,6 +44,9 @@
 #include <gmerlin/log.h>
 #define LOG_DOMAIN "utils"
 
+#include <gmerlin/translation.h>
+
+
 #include <md5.h>
 
 
@@ -559,3 +562,29 @@ void bg_diprintf(int indent, const char * format, ...)
   vfprintf(stderr, format, argp);
   va_end(argp);
   }
+
+char * bg_filename_ensure_extension(const char * filename,
+                                    const char * ext)
+  {
+  const char * pos;
+
+  if((pos = strrchr(filename, '.')) &&
+     (!strcasecmp(pos+1, ext)))
+    return bg_strdup(NULL, filename);
+  else
+    return bg_sprintf("%s.%s", filename, ext);
+  }
+
+char * bg_get_stream_label(int index, const char * info, const char * language)
+  {
+  char * label;
+  if(info && language && *language)
+    label = bg_sprintf("%s [%s]", info, bg_get_language_name(language));
+  else if(info)
+    label = bg_sprintf("%s", info);
+  else if(language && *language)
+    label = bg_sprintf(TR("Stream %d [%s]"), index+1, bg_get_language_name(language));
+  else
+    label = bg_sprintf(TR("Stream %d"), index+1);
+  return label;
+  }
