@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -74,6 +74,8 @@ struct bg_visualizer_s
   double fps;
   
   const char * display_string;
+
+  bg_ov_callbacks_t * cb;
   };
 
 static int proc_write_func(void * data, const uint8_t * ptr, int len)
@@ -528,6 +530,29 @@ static int handle_slave_message(bg_visualizer_t * v)
     case BG_VIS_SLAVE_MSG_END:
       return 0;
       break;
+    case BG_VIS_MSG_CB_MOTION: // x, y, mask
+      if(v->cb && v->cb->motion_callback)
+        v->cb->motion_callback(v->cb->data,
+                               bg_msg_get_arg_int(v->msg, 0),
+                               bg_msg_get_arg_int(v->msg, 1),
+                               bg_msg_get_arg_int(v->msg, 2));
+      break;
+    case BG_VIS_MSG_CB_BUTTON: // x, y, button, mask
+      if(v->cb && v->cb->button_callback)
+        v->cb->button_callback(v->cb->data,
+                               bg_msg_get_arg_int(v->msg, 0),
+                               bg_msg_get_arg_int(v->msg, 1),
+                               bg_msg_get_arg_int(v->msg, 2),
+                               bg_msg_get_arg_int(v->msg, 3));
+      break;
+    case BG_VIS_MSG_CB_BUTTON_REL: // x, y, button, mask
+      if(v->cb && v->cb->button_release_callback)
+        v->cb->button_release_callback(v->cb->data,
+                                       bg_msg_get_arg_int(v->msg, 0),
+                                       bg_msg_get_arg_int(v->msg, 1),
+                                       bg_msg_get_arg_int(v->msg, 2),
+                                       bg_msg_get_arg_int(v->msg, 3));
+      break;
     }
   return 1;
   }
@@ -541,28 +566,33 @@ void bg_visualizer_update(bg_visualizer_t * v,
   if(!v->proc)
     {
     if(v->ov_plugin)
+      {
       v->ov_plugin->handle_events(v->ov_handle->priv);
+      }
     pthread_mutex_unlock(&v->mutex);
     return;
     }
-  
-  bg_msg_set_id(v->msg, BG_VIS_MSG_AUDIO_DATA);
 
-  if(!bg_msg_write_audio_frame(v->msg,
-                               &v->audio_format,
-                               frame,
-                               proc_write_func, v))
+  if(frame)
     {
-    bg_subprocess_close(v->proc);
-    v->proc = (bg_subprocess_t*)0;
-    bg_log(BG_LOG_ERROR, LOG_DOMAIN,
-           "Visualization process crashed, restart to try again");
+    bg_msg_set_id(v->msg, BG_VIS_MSG_AUDIO_DATA);
+    if(!bg_msg_write_audio_frame(v->msg,
+                                 &v->audio_format,
+                                 frame,
+                                 proc_write_func, v))
+      {
+      bg_subprocess_close(v->proc);
+      v->proc = (bg_subprocess_t*)0;
+      bg_log(BG_LOG_ERROR, LOG_DOMAIN,
+             "Visualization process crashed, restart to try again");
+      }
+    bg_msg_free(v->msg);
     }
-  bg_msg_free(v->msg);
-  
-  if(v->ov_plugin)
-    v->ov_plugin->handle_events(v->ov_handle->priv);
 
+  if(v->ov_plugin)
+    {
+    v->ov_plugin->handle_events(v->ov_handle->priv);
+    }
   /* Handle messages from slave */
   bg_msg_set_id(v->msg, BG_VIS_MSG_TELL);
   write_message(v);
@@ -604,3 +634,9 @@ int bg_visualizer_need_restart(bg_visualizer_t * v)
   {
   return v->proc && v->changed;
   }
+
+void bg_visualizer_set_callbacks(bg_visualizer_t* v,
+                                 bg_ov_callbacks_t * cb)
+  {
+  v->cb = cb;
+  }
