@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -372,7 +372,7 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
   if(!evt || (evt->type != MotionNotify))
     {
     w->idle_counter++;
-    if(w->idle_counter == IDLE_MAX)
+    if(w->idle_counter >= IDLE_MAX)
       {
       if(!w->pointer_hidden)
         {
@@ -381,13 +381,12 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
         XFlush(w->dpy);
         w->pointer_hidden = 1;
         }
-
-      if(w->screensaver_disabled)
-        bg_x11_window_ping_screensaver(w);
       w->idle_counter = 0;
       }
     }
 
+  bg_x11_screensaver_ping(&w->scr);
+  
   if(w->need_focus && window_is_viewable(w->dpy, w->current->focus_child))
     {
     XSetInputFocus(w->dpy, w->current->focus_child,
@@ -411,7 +410,8 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
     w->wait_for_completion = 0;
     return;
     }
-    
+
+  
   switch(evt->type)
     {
     case Expose:
@@ -653,42 +653,42 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
         }
       break;
     case CreateNotify:
-      if((evt->xcreatewindow.parent == w->normal.win) &&
-         (evt->xcreatewindow.window != w->normal.focus_child))
+      if(evt->xcreatewindow.parent == w->normal.win)
+        cur = &w->normal;
+      else if(evt->xcreatewindow.parent == w->fullscreen.win)
+        cur = &w->fullscreen;
+      else
+        break;
+      
+      if((evt->xcreatewindow.window != cur->focus_child) &&
+         (evt->xcreatewindow.window != cur->subwin))
         {
-        w->normal.child = evt->xcreatewindow.window;
-        bg_x11_window_embed_child(w, &w->normal);
-        }
-      if(evt->xcreatewindow.parent == w->fullscreen.win &&
-         (evt->xcreatewindow.window != w->fullscreen.focus_child))
-        {
-        w->fullscreen.child = evt->xcreatewindow.window;
-        bg_x11_window_embed_child(w, &w->fullscreen);
+        cur->child = evt->xcreatewindow.window;
+        bg_x11_window_embed_child(w, cur);
         }
       break;
     case DestroyNotify:
       if(evt->xdestroywindow.event == w->normal.win)
+        cur = &w->normal;
+      else if(evt->xdestroywindow.event == w->fullscreen.win)
+        cur = &w->fullscreen;
+      else
+        break;
+
+      if(evt->xdestroywindow.window == cur->child)
         {
-        w->normal.child = None;
-        w->normal.child_xembed = 0;
-        if(w->normal.child_accel_map)
-          bg_accelerator_map_clear(w->normal.child_accel_map);
-        // XDefineCursor(w->dpy, w->normal.win, w->fullscreen_cursor);
-        }
-      if(evt->xdestroywindow.event == w->fullscreen.win)
-        {
-        w->fullscreen.child = None;
-        w->fullscreen.child_xembed = 0;
-        if(w->fullscreen.child_accel_map)
-          bg_accelerator_map_clear(w->fullscreen.child_accel_map);
-        // XDefineCursor(w->dpy, w->fullscreen.win,
-        //              w->fullscreen_cursor);
+        cur->child = None;
+        cur->child_xembed = 0;
+        if(cur->child_accel_map)
+          bg_accelerator_map_clear(cur->child_accel_map);
         }
       break;
+#if 0
     case FocusIn:
       break;
     case FocusOut:
       break;
+#endif
     case ConfigureNotify:
       if(w->current->win == w->normal.win)
         {
@@ -699,12 +699,21 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
           
           if(w->normal.parent == w->root)
             {
-            bg_x11_window_get_coords(w,
+            bg_x11_window_get_coords(w->dpy,
                                   w->normal.win,
                                   &w->window_x, &w->window_y,
                                   (int*)0, (int*)0);
             }
           bg_x11_window_size_changed(w);
+
+          if(w->normal.subwin != None)
+            {
+            XResizeWindow(w->dpy,
+                          w->normal.subwin,
+                          evt->xconfigure.width,
+                          evt->xconfigure.height);
+            
+            }
           }
         else if(evt->xconfigure.window == w->normal.parent)
           {
@@ -721,6 +730,14 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
           w->window_width  = evt->xconfigure.width;
           w->window_height = evt->xconfigure.height;
           bg_x11_window_size_changed(w);
+
+          if(w->fullscreen.subwin != None)
+            {
+            XResizeWindow(w->dpy,
+                          w->fullscreen.subwin,
+                          evt->xconfigure.width,
+                          evt->xconfigure.height);
+            }
           }
         else if(evt->xconfigure.window == w->fullscreen.parent)
           {
@@ -732,6 +749,7 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
         }
       break;
     case MotionNotify:
+      
       w->idle_counter = 0;
       if(w->pointer_hidden)
         {
@@ -741,18 +759,21 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
         w->pointer_hidden = 0;
         }
 
-      if(evt->xmotion.window == w->normal.win)
+      if((evt->xmotion.window == w->normal.win) ||
+         (evt->xmotion.window == w->normal.subwin))
         cur = &w->normal;
-      else if(evt->xmotion.window == w->fullscreen.win)
+      else if((evt->xmotion.window == w->fullscreen.win) ||
+              (evt->xmotion.window == w->fullscreen.subwin))
         cur = &w->fullscreen;
       else
         return;
-
+      
       if(cur->modality)
         return;
       
       transform_coords(w, evt->xmotion.x, evt->xmotion.y, &x_src, &y_src);
 
+
       if(w->callbacks && w->callbacks->motion_callback)
         {
         key_mask = x11_to_key_mask(evt->xmotion.state);
@@ -760,29 +781,6 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
                                       x_src, y_src, key_mask);
         }
       
-      /* Send to parent */
-      if(w->current->parent != w->root)
-        {
-        XMotionEvent motion_event;
-        memset(&motion_event, 0, sizeof(motion_event));
-        motion_event.type = MotionNotify;
-        motion_event.display = w->dpy;
-        motion_event.window = w->current->parent;
-        motion_event.root = w->root;
-        motion_event.time = evt->xmotion.time;
-        motion_event.x = evt->xmotion.x;
-        motion_event.y = evt->xmotion.y;
-        motion_event.x_root = evt->xmotion.x_root;
-        motion_event.y_root = evt->xmotion.y_root;
-        motion_event.state  = evt->xmotion.state;
-        motion_event.same_screen = evt->xmotion.same_screen;
-
-        
-        XSendEvent(motion_event.display,
-                   motion_event.window,
-                   False, None, (XEvent *)(&motion_event));
-        // XFlush(w->dpy);
-        }
       break;
     case UnmapNotify:
       if(evt->xunmap.window == w->normal.win)
@@ -802,6 +800,11 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
                                             CurrentTime,
                                             XEMBED_REQUEST_FOCUS,
                                             0, 0, 0);
+
+        XDefineCursor(w->dpy, w->normal.win, None);
+        w->idle_counter = 0;
+        w->pointer_hidden = 0;
+        
         }
       else if(evt->xmap.window == w->fullscreen.win)
         {
@@ -812,6 +815,11 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
                                             CurrentTime,
                                             XEMBED_REQUEST_FOCUS,
                                             0, 0, 0);
+
+        XDefineCursor(w->dpy, w->fullscreen.win, None);
+        w->idle_counter = 0;
+        w->pointer_hidden = 0;
+
         
         //        bg_x11_window_set_fullscreen_mapped(w, &w->fullscreen);
         }
@@ -823,16 +831,16 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
       break;
     case KeyPress:
     case KeyRelease:
-      
-      
       XLookupString(&(evt->xkey), &key_char, 1, &keysym, NULL);
       evt->xkey.state &= STATE_IGNORE;
       
       if((evt->xkey.window == w->normal.win) ||
-         (evt->xkey.window == w->normal.focus_child))
+         (evt->xkey.window == w->normal.focus_child) ||
+         (evt->xkey.window == w->normal.subwin))
         cur = &w->normal;
       else if((evt->xkey.window == w->fullscreen.win) ||
-              (evt->xkey.window == w->fullscreen.focus_child))
+              (evt->xkey.window == w->fullscreen.focus_child) ||
+              (evt->xkey.window == w->fullscreen.subwin))
         cur = &w->fullscreen;
       else
         {
@@ -872,8 +880,8 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
           /* Here, we see why generic key callbacks are bad:
              One key callback is ok, but if we have more than one
              (i.e. in embedded or embedding windows), one might always
-             eat up all events. At lease callbacks should return zero
-             to signify, that the event should be propagated */
+             eat up all events. At least callbacks should return zero
+             to notify, that the event should be propagated */
 
           if(w->callbacks &&
              w->callbacks->key_callback &&
@@ -913,23 +921,24 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
 
         XSendEvent(key_event.display,
                    key_event.window,
-                   False, 0, (XEvent *)(&key_event));
+                   False, NoEventMask, (XEvent *)(&key_event));
         XFlush(w->dpy);
         }
       break;
     case ButtonPress:
     case ButtonRelease:
-
-      if(evt->xbutton.window == w->normal.win)
+      
+      if((evt->xbutton.window == w->normal.win) ||
+         (evt->xbutton.window == w->normal.subwin))
         cur = &w->normal;
-      else if(evt->xbutton.window == w->fullscreen.win)
+      else if((evt->xbutton.window == w->fullscreen.win) ||
+              (evt->xbutton.window == w->fullscreen.subwin))
         cur = &w->fullscreen;
       else
         return;
-
+      
       if(cur->modality)
         return;
-
       
       transform_coords(w, evt->xbutton.x, evt->xbutton.y, &x_src, &y_src);
       evt->xkey.state &= STATE_IGNORE;
@@ -988,7 +997,7 @@ void bg_x11_window_handle_event(bg_x11_window_t * w, XEvent * evt)
 
         XSendEvent(button_event.display,
                    button_event.window,
-                   False, 0, (XEvent *)(&button_event));
+                   False, NoEventMask, (XEvent *)(&button_event));
         //        XFlush(w->dpy);
         }
 
