@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -23,6 +23,9 @@
 #include <x11/x11.h>
 #include <x11/x11_window_private.h>
 
+#include <gmerlin/log.h>
+#define LOG_DOMAIN "x11_video"
+
 static video_driver_t const * const drivers[] =
   {
     &ximage_driver,
@@ -88,24 +91,6 @@ int bg_x11_window_set_contrast(bg_x11_window_t * w, float val)
   return set_contrast(w);
   }
 
-static int set_hue(bg_x11_window_t * w)
-  {
-  if(w->video_open &&
-     w->current_driver->driver->set_hue &&
-     (w->current_driver->flags & DRIVER_FLAG_HUE))
-    {
-    w->current_driver->driver->set_hue(w->current_driver, w->hue);
-    return 1;
-    }
-  return 0;
-  }
-
-int bg_x11_window_set_hue(bg_x11_window_t * w, float val)
-  {
-  w->hue = val;
-  return set_hue(w);
-  }
-
 static void init(bg_x11_window_t * w)
   {
   int num_drivers, i;
@@ -119,9 +104,14 @@ static void init(bg_x11_window_t * w)
       w->drivers[i].driver->init(&w->drivers[i]);
     }
   
-  /* TODO: Get screen resolution */
+  /*
+   *  Possible TODO: Get screen resolution
+   *  (maybe better if we don't care at all)
+   */
+  
   w->window_format.pixel_width = 1;
   w->window_format.pixel_height = 1;
+  w->idle_counter = 0;
   }
 
 void bg_x11_window_cleanup_video(bg_x11_window_t * w)
@@ -240,11 +230,20 @@ int bg_x11_window_open_video(bg_x11_window_t * w,
       break;
       }
     /* Flag as unusable */
+    bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Trying %s driver",
+           w->drivers[min_index].driver->name);
     if(!w->drivers[min_index].driver->open(&w->drivers[min_index]))
+      {
+      bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Opening %s driver failed",
+             w->drivers[min_index].driver->name);
+      
       w->drivers[min_index].pixelformat = GAVL_PIXELFORMAT_NONE;
+      }
     else
       {
       w->current_driver = &w->drivers[min_index];
+      bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Opening %s driver succeeded",
+             w->drivers[min_index].driver->name);
       break;
       }
     }
@@ -268,9 +267,7 @@ int bg_x11_window_open_video(bg_x11_window_t * w,
   set_contrast(w);
   set_saturation(w);
   set_brightness(w);
-  set_hue(w);
   
-
   return 1;
   }
 
@@ -367,46 +364,49 @@ void bg_x11_window_set_rectangles(bg_x11_window_t * w,
 void bg_x11_window_put_frame_internal(bg_x11_window_t * w,
                                       gavl_video_frame_t * f)
   {
+  gavl_video_frame_t * f1;
+  int i;
+  
+  if(!w->current_driver->driver->add_overlay_stream && w->has_overlay)
+    {
+    if(!w->out_frame)
+      w->out_frame = bg_x11_window_create_frame(w);
+    
+    gavl_video_frame_copy(&w->video_format, w->out_frame, f);
+    
+    for(i = 0; i < w->num_overlay_streams; i++)
+      gavl_overlay_blend(w->overlay_streams[i].ctx, w->out_frame);
+    f1 = w->out_frame;
+    }
+  else
+    f1 = f;
+  
   if(w->do_sw_scale)
     {
-    gavl_video_scaler_scale(w->scaler, f, w->window_frame);
+    gavl_video_scaler_scale(w->scaler, f1, w->window_frame);
     w->current_driver->driver->put_frame(w->current_driver,
                                          w->window_frame);
     }
   else
     {
-    w->current_driver->driver->put_frame(w->current_driver, f);
+    w->current_driver->driver->put_frame(w->current_driver, f1);
     }
   }
 
 void bg_x11_window_put_frame(bg_x11_window_t * w, gavl_video_frame_t * f)
   {
-  int i;
   w->still_mode = 0;
-  if(!w->current_driver->driver->add_overlay_stream)
-    {
-    for(i = 0; i < w->num_overlay_streams; i++)
-      gavl_overlay_blend(w->overlay_streams[i].ctx, f);
-    }
   bg_x11_window_put_frame_internal(w, f);
   }
 
 void bg_x11_window_put_still(bg_x11_window_t * w, gavl_video_frame_t * f)
   {
-  int i;
   w->still_mode = 1;
-
   if(!w->still_frame)
-    w->still_frame = bg_x11_window_create_frame(w);
-  
-  gavl_video_frame_copy(&w->video_format, w->still_frame, f);
-  
-  if(!w->current_driver->driver->add_overlay_stream)
     {
-    for(i = 0; i < w->num_overlay_streams; i++)
-      gavl_overlay_blend(w->overlay_streams[i].ctx, w->still_frame);
+    w->still_frame = bg_x11_window_create_frame(w);
     }
-  
+  gavl_video_frame_copy(&w->video_format, w->still_frame, f);
   bg_x11_window_put_frame_internal(w, w->still_frame);
   }
 
@@ -414,6 +414,7 @@ void bg_x11_window_put_still(bg_x11_window_t * w, gavl_video_frame_t * f)
 void bg_x11_window_close_video(bg_x11_window_t * w)
   {
   int i;
+  
   if(w->window_frame)
     {
     if(w->current_driver->driver->destroy_frame)
@@ -424,12 +425,14 @@ void bg_x11_window_close_video(bg_x11_window_t * w)
     }
   if(w->still_frame)
     {
-    if(w->current_driver->driver->destroy_frame)
-      w->current_driver->driver->destroy_frame(w->current_driver, w->still_frame);
-    else
-      gavl_video_frame_destroy(w->still_frame);
+    bg_x11_window_destroy_frame(w, w->still_frame);
     w->still_frame = (gavl_video_frame_t*)0;
     }
+  if(w->out_frame)
+    {
+    bg_x11_window_destroy_frame(w, w->out_frame);
+    w->out_frame = (gavl_video_frame_t*)0;
+    }
   
   if(w->overlay_streams)
     {
