@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -30,8 +30,6 @@
 
 #include <X11/Xatom.h>
 
-#include <X11/Xutil.h>
-
 #include <gmerlin/translation.h>
 #include <gmerlin/utils.h>
 #include <gmerlin/log.h>
@@ -64,131 +62,6 @@ int XShmGetEventBase (Display *);
 
 /* Screensaver detection */
 
-static void check_screensaver(bg_x11_window_t * w)
-  {
-  char * env;
-  
-  /* Check for gnome */
-  env = getenv("GNOME_DESKTOP_SESSION_ID");
-  if(env)
-    {
-    w->screensaver_mode = SCREENSAVER_MODE_GNOME;
-    return;
-    }
-
-  /* Check for KDE */
-  env = getenv("KDE_FULL_SESSION");
-  if(env && !strcmp(env, "true"))
-    {
-    w->screensaver_mode = SCREENSAVER_MODE_KDE;
-    return;
-    }
-
-  /* TODO: xfce4 */
-  
-  }
-
-static void disable_screensaver(bg_x11_window_t * w)
-  {
-  int interval, prefer_blank, allow_exp;
-
-#if HAVE_XDPMS
-  int nothing;
-#endif // HAVE_XDPMS
-  
-  if(w->screensaver_disabled)
-    return;
-
-#if HAVE_XDPMS
-  if(DPMSQueryExtension(w->dpy, &nothing, &nothing))
-    {
-    BOOL onoff;
-    CARD16 state;
-    
-    DPMSInfo(w->dpy, &state, &onoff);
-    if(onoff)
-      {
-      w->dpms_disabled = 1;
-      DPMSDisable(w->dpy);       // monitor powersave off
-      }
-    }
-#endif // HAVE_XDPMS
-    
-  switch(w->screensaver_mode)
-    {
-    case SCREENSAVER_MODE_XLIB:
-      XGetScreenSaver(w->dpy, &w->screensaver_saved_timeout,
-                      &interval, &prefer_blank,
-                      &allow_exp);
-      if(w->screensaver_saved_timeout)
-        w->screensaver_was_enabled = 1;
-      else
-        w->screensaver_was_enabled = 0;
-      XSetScreenSaver(w->dpy, 0, interval, prefer_blank, allow_exp);
-      break;
-    case SCREENSAVER_MODE_GNOME:
-      break;
-    case SCREENSAVER_MODE_KDE:
-      w->screensaver_was_enabled =
-        (system
-             ("dcop kdesktop KScreensaverIface isEnabled 2>/dev/null | sed 's/1/true/g' | grep true 2>/dev/null >/dev/null")
-         == 0);
-      
-      if(w->screensaver_was_enabled)
-        system("dcop kdesktop KScreensaverIface enable false > /dev/null");
-      break;
-    }
-  w->screensaver_disabled = 1;
-  }
-
-static void enable_screensaver(bg_x11_window_t * w)
-  {
-  int dummy, interval, prefer_blank, allow_exp;
-
-  if(!w->screensaver_disabled)
-    return;
-
-#if HAVE_XDPMS
-  if(w->dpms_disabled)
-    {
-    if(DPMSQueryExtension(w->dpy, &dummy, &dummy))
-      {
-      if(DPMSEnable(w->dpy))
-        {
-        // DPMS does not seem to be enabled unless we call DPMSInfo
-        BOOL onoff;
-        CARD16 state;
-
-        DPMSForceLevel(w->dpy, DPMSModeOn);      
-        DPMSInfo(w->dpy, &state, &onoff);
-        }
-
-      }
-    w->dpms_disabled = 0;
-    }
-#endif // HAVE_XDPMS
-  
-  w->screensaver_disabled = 0;
-  
-  
-  if(!w->screensaver_was_enabled)
-    return;
-  
-  switch(w->screensaver_mode)
-    {
-    case SCREENSAVER_MODE_XLIB:
-      XGetScreenSaver(w->dpy, &dummy, &interval, &prefer_blank,
-                      &allow_exp);
-      XSetScreenSaver(w->dpy, w->screensaver_saved_timeout, interval, prefer_blank,
-                      allow_exp);
-      break;
-    case SCREENSAVER_MODE_GNOME:
-      break;
-    case SCREENSAVER_MODE_KDE:
-      break;
-    }
-  }
-
 static int check_disable_screensaver(bg_x11_window_t * w)
   {
   /* Never change global settings if we are embedded */
@@ -203,26 +76,6 @@ static int check_disable_screensaver(bg_x11_window_t * w)
 
 void bg_x11_window_ping_screensaver(bg_x11_window_t * w)
   {
-  struct timeval tm;
-  gettimeofday(&tm, (struct timezone *)0);
-
-  if(tm.tv_sec - w->screensaver_last_ping_time < 40) // 40 Sec interval
-    {
-    return;
-    }
-
-  w->screensaver_last_ping_time = tm.tv_sec;
-  
-  switch(w->screensaver_mode)
-    {
-    case SCREENSAVER_MODE_XLIB:
-      break;
-    case SCREENSAVER_MODE_GNOME:
-      system("gnome-screensaver-command --poke > /dev/null 2> /dev/null");
-      break;
-    case SCREENSAVER_MODE_KDE:
-      break;
-    }
   }
 
 
@@ -255,8 +108,8 @@ wm_check_capability(Display *dpy, Window root, Atom list, Atom wanted)
   return retval;
   }
 
-static void
-netwm_set_state(bg_x11_window_t * w, Window win, int action, Atom state)
+void
+bg_x11_window_set_netwm_state(Display * dpy, Window win, Window root, int action, Atom state)
   {
   /* Setting _NET_WM_STATE by XSendEvent works only, if the window
      is already mapped!! */
@@ -264,15 +117,14 @@ netwm_set_state(bg_x11_window_t * w, Window win, int action, Atom state)
   XEvent e;
   memset(&e,0,sizeof(e));
   e.xclient.type = ClientMessage;
-  e.xclient.message_type = w->_NET_WM_STATE;
-  //  e.xclient.display = w->dpy;
+  e.xclient.message_type = XInternAtom(dpy, "_NET_WM_STATE", False);
   e.xclient.window = win;
   e.xclient.send_event = True;
   e.xclient.format = 32;
   e.xclient.data.l[0] = action;
   e.xclient.data.l[1] = state;
   
-  XSendEvent(w->dpy, w->root, False,
+  XSendEvent(dpy, root, False,
              SubstructureRedirectMask | SubstructureNotifyMask, &e);
   }
 
@@ -345,18 +197,18 @@ void bg_x11_window_set_fullscreen_mapped(bg_x11_window_t * win,
   {
   if(win->fullscreen_mode & FULLSCREEN_MODE_NET_ABOVE)
     {
-    netwm_set_state(win, w->win,
-                    _NET_WM_STATE_ADD, win->_NET_WM_STATE_ABOVE);
+    bg_x11_window_set_netwm_state(win->dpy, w->win, win->root,
+                                  _NET_WM_STATE_ADD, win->_NET_WM_STATE_ABOVE);
     }
   else if(win->fullscreen_mode & FULLSCREEN_MODE_NET_STAYS_ON_TOP)
     {
-    netwm_set_state(win, w->win,
-                    _NET_WM_STATE_ADD, win->_NET_WM_STATE_STAYS_ON_TOP);
+    bg_x11_window_set_netwm_state(win->dpy, w->win, win->root,
+                                  _NET_WM_STATE_ADD, win->_NET_WM_STATE_STAYS_ON_TOP);
     }
   if(win->fullscreen_mode & FULLSCREEN_MODE_NET_FULLSCREEN)
     {
-    netwm_set_state(win, w->win,
-                    _NET_WM_STATE_ADD, win->_NET_WM_STATE_FULLSCREEN);
+    bg_x11_window_set_netwm_state(win->dpy, w->win, win->root,
+                                  _NET_WM_STATE_ADD, win->_NET_WM_STATE_FULLSCREEN);
     }
   }
 
@@ -573,8 +425,8 @@ static int open_display(bg_x11_window_t * w)
   /* Check, which fullscreen modes we have */
   
   w->fullscreen_mode = get_fullscreen_mode(w);
-  
-  check_screensaver(w);
+
+  bg_x11_screensaver_init(&w->scr, w->dpy);
   
   /* Get xinerama screens */
 
@@ -592,9 +444,7 @@ static int open_display(bg_x11_window_t * w)
   return 1;
   }
 
-
-
-void bg_x11_window_get_coords(bg_x11_window_t * w,
+void bg_x11_window_get_coords(Display * dpy,
                               Window win,
                               int * x, int * y, int * width,
                               int * height)
@@ -609,18 +459,16 @@ void bg_x11_window_get_coords(bg_x11_window_t * w,
   unsigned int depth_return;
   //  Window child_return;
 
-  XGetGeometry(w->dpy, win, &root_return, &x_return, &y_return,
+  XGetGeometry(dpy, win, &root_return, &x_return, &y_return,
                &width_return, &height_return,
                &border_width_return, &depth_return);
   
-  XQueryTree(w->dpy, win, &root_return, &parent_return,
+  XQueryTree(dpy, win, &root_return, &parent_return,
              &children_return, &nchildren_return);
 
   if(nchildren_return)
-    {
     XFree(children_return);
-    }
-
+  
   if(x) *x = x_return;
   if(y) *y = y_return;
   
@@ -629,7 +477,7 @@ void bg_x11_window_get_coords(bg_x11_window_t * w,
   
   if((x || y) && (parent_return != root_return))
     {
-    XGetGeometry(w->dpy, parent_return, &root_return,
+    XGetGeometry(dpy, parent_return, &root_return,
                  &x_return, &y_return,
                  &width_return, &height_return,
                  &border_width_return, &depth_return);
@@ -698,14 +546,14 @@ void bg_x11_window_init(bg_x11_window_t * w)
     {
     //    fprintf(stderr, "bg_x11_window_init %ld %ld\n", w->current->win,
     //            w->current->parent);
-    bg_x11_window_get_coords(w, w->current->parent,
+    bg_x11_window_get_coords(w->dpy, w->current->parent,
                       (int*)0, (int*)0,
                       &w->window_width, &w->window_height);
     XMoveResizeWindow(w->dpy, w->current->win, 0, 0,
                       w->window_width, w->window_height);
     }
   else
-    bg_x11_window_get_coords(w, w->current->win,
+    bg_x11_window_get_coords(w->dpy, w->current->win,
                       (int*)0, (int*)0,
                       &w->window_width, &w->window_height);
 #endif
@@ -752,7 +600,6 @@ void bg_x11_window_embed_parent(bg_x11_window_t * win,
 void bg_x11_window_embed_child(bg_x11_window_t * win,
                                window_t * w)
   {
-  //  XDefineCursor(win->dpy, w->child, None);
   XSelectInput(win->dpy, w->child, FocusChangeMask | ExposureMask |
                PropertyChangeMask);
   
@@ -763,11 +610,71 @@ void bg_x11_window_embed_child(bg_x11_window_t * win,
   bg_x11_window_check_embed_property(win, w);
   }
 
+static void create_subwin(bg_x11_window_t * w,
+                          window_t * win,
+                          int depth, Visual * v, unsigned long attr_mask,
+                          XSetWindowAttributes * attr)
+  {
+  int width, height;
+  
+  bg_x11_window_get_coords(w->dpy, win->win,
+                           NULL, NULL, &width, &height);
+  win->subwin = XCreateWindow(w->dpy,
+                              win->win, 0, 0, width, height, 0,
+                              depth, InputOutput, v, attr_mask, attr);
+  XMapWindow(w->dpy, win->subwin);
+  }
+
+void bg_x11_window_create_subwins(bg_x11_window_t * w,
+                                  int depth, Visual * v)
+  {
+  unsigned long attr_mask;
+  XSetWindowAttributes attr;
+  
+  w->sub_colormap = XCreateColormap(w->dpy, RootWindow(w->dpy, w->screen),
+                                    v, AllocNone);
+
+  memset(&attr, 0, sizeof(attr));
+
+  attr_mask = CWEventMask | CWColormap;
+  
+  attr.event_mask =
+    ExposureMask |
+    ButtonPressMask |
+    ButtonReleaseMask |
+    KeyPressMask |
+    PointerMotionMask |
+    KeyReleaseMask;
+  
+  attr.colormap = w->sub_colormap;
+  
+  create_subwin(w, &w->normal, depth, v, attr_mask, &attr);
+  create_subwin(w, &w->fullscreen, depth, v, attr_mask, &attr);
+  }
+
+static void destroy_subwin(bg_x11_window_t * w,
+                           window_t * win)
+  {
+  if(win->subwin != None)
+    {
+    XDestroyWindow(w->dpy, win->subwin);
+    win->subwin = None;
+    }
+  }
+                          
+
+void bg_x11_window_destroy_subwins(bg_x11_window_t * w)
+  {
+  destroy_subwin(w, &w->normal);
+  destroy_subwin(w, &w->fullscreen);
+  
+  }
+
 static int create_window(bg_x11_window_t * w,
                          int width, int height)
   {
   const char * display_name;
-  long event_mask;
+  unsigned long event_mask;
   XColor black;
   Atom wm_protocols[2];
   XWMHints * wmhints;
@@ -787,8 +694,7 @@ static int create_window(bg_x11_window_t * w,
   wmhints->initial_state = NormalState;
   wmhints->flags |= InputHint|StateHint;
   
-  /* Not clear why this is needed. Not creating the colormap
-     results in a BadMatch error */
+  /* Creating windows without colormap results in a BadMatch error */
   w->colormap = XCreateColormap(w->dpy, RootWindow(w->dpy, w->screen),
                                 w->visual,
                                 AllocNone);
@@ -1045,10 +951,11 @@ int bg_x11_window_set_fullscreen(bg_x11_window_t * w,int fullscreen)
       return 0;
     /* Unmap fullscreen window */
 #if 1
-    netwm_set_state(w, w->fullscreen.win,
-                    _NET_WM_STATE_REMOVE, w->_NET_WM_STATE_FULLSCREEN);
-    netwm_set_state(w, w->fullscreen.win,
-                    _NET_WM_STATE_REMOVE, w->_NET_WM_STATE_ABOVE);
+    bg_x11_window_set_netwm_state(w->dpy, w->fullscreen.win, w->root,
+                                  _NET_WM_STATE_REMOVE, w->_NET_WM_STATE_FULLSCREEN);
+
+    bg_x11_window_set_netwm_state(w->dpy, w->fullscreen.win, w->root,
+                                  _NET_WM_STATE_REMOVE, w->_NET_WM_STATE_ABOVE);
     XUnmapWindow(w->dpy, w->fullscreen.win);
 #endif
     XWithdrawWindow(w->dpy, w->fullscreen.win, w->screen);
@@ -1073,9 +980,9 @@ int bg_x11_window_set_fullscreen(bg_x11_window_t * w,int fullscreen)
   if(ret)
     {
     if(check_disable_screensaver(w))
-      disable_screensaver(w);
+      bg_x11_screensaver_disable(&w->scr);
     else
-      enable_screensaver(w);
+      bg_x11_screensaver_enable(&w->scr);
     }
   return ret;
   }
@@ -1116,6 +1023,9 @@ bg_x11_window_t * bg_x11_window_create(const char * display_string)
   bg_x11_window_set_gl_attribute(ret, BG_GL_ATTRIBUTE_BLUE_SIZE, 8);
   bg_x11_window_set_gl_attribute(ret, BG_GL_ATTRIBUTE_DOUBLEBUFFER, 1);
   
+  ret->icon      = None;
+  ret->icon_mask = None;
+  
   return ret;
   }
 
@@ -1135,6 +1045,10 @@ void bg_x11_window_destroy(bg_x11_window_t * w)
   {
   bg_x11_window_cleanup_video(w);
   bg_x11_window_cleanup_gl(w);
+  bg_x11_window_destroy_subwins(w);
+  
+  if(w->colormap != None)
+    XFreeColormap(w->dpy, w->colormap);
   
   if(w->normal.win != None)
     XDestroyWindow(w->dpy, w->normal.win);
@@ -1158,12 +1072,23 @@ void bg_x11_window_destroy(bg_x11_window_t * w)
   if(w->xinerama)
     XFree(w->xinerama);
 #endif
-  if(w->gl_vi)
-    XFree(w->gl_vi);
+  
+#ifdef GAVE_GLX
+  if(w->gl_fbconfigs)
+    XFree(w->gl_fbconfigs);
+#endif
+  
+  if(w->icon != None)
+    XFreePixmap(w->dpy, w->icon);
+  
+  if(w->icon_mask != None)
+    XFreePixmap(w->dpy, w->icon_mask);
   
   if(w->dpy)
+    {
     XCloseDisplay(w->dpy);
-  
+    bg_x11_screensaver_cleanup(&w->scr);
+    }
   if(w->display_string_parent)
     free(w->display_string_parent);
   if(w->display_string_child)
@@ -1235,6 +1160,16 @@ static const bg_parameter_info_t common_parameters[] =
       .help_string = TRS("Use hardware scaling even if it involves more CPU intensive pixelformat conversions"),
 
     },
+#ifdef HAVE_GLX
+    {
+      .name =        "background_color",
+      .long_name =   TRS("Background color"),
+      .type =        BG_PARAMETER_COLOR_RGB,
+      .flags =       BG_PARAMETER_SYNC,
+      .help_string = TRS("Specify the background color for videos with alpha channel. This is only used by the OpenGL driver."),
+
+    },
+#endif
     {
       .name =        "sw_scaler",
       .long_name =   TRS("Software scaler"),
@@ -1335,6 +1270,13 @@ bg_x11_window_set_parameter(void * data, const char * name,
     {
     win->disable_screensaver_fullscreen = val->val_i;
     }
+#ifdef HAVE_GLX
+  else if(!strcmp(name, "background_color"))
+    {
+    memcpy(win->background_color, val->val_color, 3 * sizeof(float));
+    }
+#endif
+  
   else if(!strcmp(name, "force_hw_scale"))
     {
     win->force_hw_scale = val->val_i;
@@ -1426,68 +1368,23 @@ void bg_x11_window_set_size(bg_x11_window_t * win, int width, int height)
   win->window_height = height;
   }
 
-#ifdef HAVE_GLX
-static const struct
-  {
-  int glx_attribute;
-  int is_boolean;
-  }
-gl_attribute_map[BG_GL_ATTRIBUTE_NUM] =
-  {
-    [BG_GL_ATTRIBUTE_BUFFER_SIZE]       = { GLX_BUFFER_SIZE,      0 },
-    [BG_GL_ATTRIBUTE_LEVEL]             = { GLX_LEVEL,            0 },
-    [BG_GL_ATTRIBUTE_RGBA]              = { GLX_RGBA,             1 },
-    [BG_GL_ATTRIBUTE_DOUBLEBUFFER]      = { GLX_DOUBLEBUFFER,     1 },
-    [BG_GL_ATTRIBUTE_STEREO]            = { GLX_STEREO,           1 },
-    [BG_GL_ATTRIBUTE_AUX_BUFFERS]       = { GLX_AUX_BUFFERS,      0 },
-    [BG_GL_ATTRIBUTE_RED_SIZE]          = { GLX_RED_SIZE,         0 },
-    [BG_GL_ATTRIBUTE_GREEN_SIZE]        = { GLX_GREEN_SIZE,       0 },
-    [BG_GL_ATTRIBUTE_BLUE_SIZE]         = { GLX_BLUE_SIZE,        0 },
-    [BG_GL_ATTRIBUTE_ALPHA_SIZE]        = { GLX_ALPHA_SIZE,       0 },
-    [BG_GL_ATTRIBUTE_DEPTH_SIZE]        = { GLX_DEPTH_SIZE,       0 },
-    [BG_GL_ATTRIBUTE_STENCIL_SIZE]      = { GLX_STENCIL_SIZE,     0 },
-    [BG_GL_ATTRIBUTE_ACCUM_RED_SIZE]    = { GLX_ACCUM_RED_SIZE,   0 },
-    [BG_GL_ATTRIBUTE_ACCUM_GREEN_SIZE]  = { GLX_ACCUM_GREEN_SIZE, 0 },
-    [BG_GL_ATTRIBUTE_ACCUM_BLUE_SIZE]   = { GLX_ACCUM_BLUE_SIZE,  0 },
-    [BG_GL_ATTRIBUTE_ACCUM_ALPHA_SIZE]  = { GLX_ACCUM_ALPHA_SIZE, 0 },
-  };
-#endif
 
 int bg_x11_window_realize(bg_x11_window_t * win)
   {
   int ret;
-  int screen;
-
-#ifdef HAVE_GLX
-  int attr_index = 0, i;
-  /* Attributes we need for video playback */
-
-  int attr_list[64];
-  for(i = 0; i < BG_GL_ATTRIBUTE_NUM; i++)
-    {
-    if(!win->gl_attributes[i].changed)
-      continue;
-    attr_list[attr_index++] = gl_attribute_map[i].glx_attribute;
-    
-    if(!gl_attribute_map[i].is_boolean)
-      attr_list[attr_index++] = win->gl_attributes[i].value;
-    }
-
-  attr_list[attr_index] = None;
-#endif
-
+  
   if(!win->dpy && !open_display(win))
     return 0;
   
-#ifdef HAVE_GLX
+// #ifdef HAVE_GLX
+#if 0
   win->gl_vi = glXChooseVisual(win->dpy, win->screen, attr_list);
   
   if(!win->gl_vi)
     {
     bg_log(BG_LOG_WARNING, LOG_DOMAIN, "Could not get GL Visual");
-    screen = DefaultScreen(win->dpy);
-    win->visual = DefaultVisual(win->dpy, screen);
-    win->depth = DefaultDepth(win->dpy, screen);
+    win->visual = DefaultVisual(win->dpy, win->screen);
+    win->depth = DefaultDepth(win->dpy, win->screen);
     }
   else
     {
@@ -1495,12 +1392,14 @@ int bg_x11_window_realize(bg_x11_window_t * win)
     win->depth  = win->gl_vi->depth;
     }
 
-#else
-  screen = DefaultScreen(win->dpy);
-  win->visual = DefaultVisual(win->dpy, screen);
-  win->depth = DefaultDepth(win->dpy, screen);
 #endif
+
+  win->visual = DefaultVisual(win->dpy, win->screen);
+  win->depth = DefaultDepth(win->dpy, win->screen);
   
+  bg_log(BG_LOG_DEBUG, LOG_DOMAIN, "Got Visual 0x%lx depth %d",
+         win->visual->visualid, win->depth);
+
   ret = create_window(win, win->window_width, win->window_height);
   bg_x11_window_init_gl(win);
   return ret;
@@ -1513,25 +1412,82 @@ void bg_x11_window_set_callbacks(bg_x11_window_t * win,
   win->callbacks = callbacks;
   }
 
-
-
 void bg_x11_window_set_title(bg_x11_window_t * w, const char * title)
   {
   if(w->normal.parent == w->root)
     XmbSetWMProperties(w->dpy, w->normal.win, title,
                        title, NULL, 0, NULL, NULL, NULL);
+  if(w->fullscreen.parent == w->root)
+    XmbSetWMProperties(w->dpy, w->fullscreen.win, title,
+                       title, NULL, 0, NULL, NULL, NULL);
   }
 
-void bg_x11_window_set_class_hint(bg_x11_window_t * w,
-                                  char * name, char * klass)
+void bg_x11_window_set_options(bg_x11_window_t * w,
+                               const char * name, 
+                               const char * klass,
+                               const gavl_video_frame_t * icon,
+                               const gavl_video_format_t * icon_format)
   {
-  XClassHint xclasshint={name,klass};
+  /* Set Class hints */
+  if(name && klass)
+    {
+    XClassHint xclasshint;
 
-  if(w->normal.parent == w->root)
-    XSetClassHint(w->dpy, w->normal.win, &xclasshint);
+    /* const madness */
+    xclasshint.res_name = bg_strdup(NULL, name);
+    xclasshint.res_class = bg_strdup(NULL, klass);
 
-  if(w->fullscreen.parent == w->root)
-    XSetClassHint(w->dpy, w->fullscreen.win, &xclasshint);
+    if(w->normal.parent == w->root)
+      XSetClassHint(w->dpy, w->normal.win, &xclasshint);
+
+    if(w->fullscreen.parent == w->root)
+      XSetClassHint(w->dpy, w->fullscreen.win, &xclasshint);
+
+    free(xclasshint.res_name);
+    free(xclasshint.res_class);
+    }
+
+  /* Set Icon (TODO) */
+  if(icon && icon_format)
+    {
+    XWMHints xwmhints;
+    memset(&xwmhints, 0, sizeof(xwmhints));
+
+    if((w->normal.parent == w->root) ||
+       (w->fullscreen.parent == w->root))
+      {
+      if(w->icon != None)
+        {
+        XFreePixmap(w->dpy, w->icon);
+        w->icon = None; 
+        }
+      if(w->icon_mask != None)
+        {
+        XFreePixmap(w->dpy, w->icon_mask);
+        w->icon_mask = None; 
+        }
+      
+      bg_x11_window_make_icon(w,
+                              icon,
+                              icon_format,
+                              &w->icon,
+                              &w->icon_mask);
+      
+      xwmhints.icon_pixmap = w->icon;
+      xwmhints.icon_mask   = w->icon_mask;
+      
+      if(xwmhints.icon_pixmap != None)
+        xwmhints.flags |= IconPixmapHint;
+      
+      if(xwmhints.icon_mask != None)
+        xwmhints.flags |= IconMaskHint;
+      
+      if(w->normal.parent == w->root)
+        XSetWMHints(w->dpy, w->normal.win, &xwmhints);
+      if(w->fullscreen.parent == w->root)
+        XSetWMHints(w->dpy, w->fullscreen.win, &xwmhints);
+      }
+    }
   }
 
 void bg_x11_window_show(bg_x11_window_t * win, int show)
@@ -1539,11 +1495,10 @@ void bg_x11_window_show(bg_x11_window_t * win, int show)
   show_window(win, win->current, show);
   
   if(show && check_disable_screensaver(win))
-    disable_screensaver(win);
+    bg_x11_screensaver_disable(&win->scr);
   else
-    enable_screensaver(win);
-
-
+    bg_x11_screensaver_enable(&win->scr);
+  
   if(!show)
     {
     XSync(win->dpy, False);
@@ -1586,8 +1541,10 @@ Window bg_x11_window_get_toplevel(bg_x11_window_t * w, Window win)
   return win;
   }
 
-void bg_x11_window_send_xembed_message(bg_x11_window_t * w, Window win, long time,
-                                       int message, int detail, int data1, int data2)
+void 
+bg_x11_window_send_xembed_message(bg_x11_window_t * w, Window win, 
+                                  long time, int message, int detail, 
+                                  int data1, int data2)
   {
   XClientMessageEvent xclient;
 
@@ -1655,3 +1612,59 @@ int bg_x11_window_check_embed_property(bg_x11_window_t * win,
     }
   return 1;
   }
+
+gavl_pixelformat_t 
+bg_x11_window_get_pixelformat(Display * dpy, Visual * visual, int depth)
+  {
+  int bpp;
+  XPixmapFormatValues * pf;
+  int i;
+  int num_pf;
+  gavl_pixelformat_t ret = GAVL_PIXELFORMAT_NONE;
+  
+  bpp = 0;
+  pf = XListPixmapFormats(dpy, &num_pf);
+  for(i = 0; i < num_pf; i++)
+    {
+    if(pf[i].depth == depth)
+      bpp = pf[i].bits_per_pixel;
+    }
+  XFree(pf);
+  
+  ret = GAVL_PIXELFORMAT_NONE;
+  switch(bpp)
+    {
+    case 16:
+      if((visual->red_mask == 63488) &&
+         (visual->green_mask == 2016) &&
+         (visual->blue_mask == 31))
+        ret = GAVL_RGB_16;
+      else if((visual->blue_mask == 63488) &&
+              (visual->green_mask == 2016) &&
+              (visual->red_mask == 31))
+        ret = GAVL_BGR_16;
+      break;
+    case 24:
+      if((visual->red_mask == 0xff) && 
+         (visual->green_mask == 0xff00) &&
+         (visual->blue_mask == 0xff0000))
+        ret = GAVL_RGB_24;
+      else if((visual->red_mask == 0xff0000) && 
+         (visual->green_mask == 0xff00) &&
+         (visual->blue_mask == 0xff))
+        ret = GAVL_BGR_24;
+      break;
+    case 32:
+      if((visual->red_mask == 0xff) && 
+         (visual->green_mask == 0xff00) &&
+         (visual->blue_mask == 0xff0000))
+        ret = GAVL_RGB_32;
+      else if((visual->red_mask == 0xff0000) && 
+         (visual->green_mask == 0xff00) &&
+         (visual->blue_mask == 0xff))
+        ret = GAVL_BGR_32;
+      break;
+    }
+  return ret;
+  }
+
