@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -457,46 +457,3 @@ void bg_alsa_create_card_parameters(bg_parameter_info_t * ret,
   snd_ctl_card_info_free(info);
   
   }
-
-#if 0
-
-void bg_alsa_create_card_parameters(bg_parameter_info_t * ret)
-  {
-  int i, istart;
-  int num_cards = 1; /* default */
-  int card_index = -1;
-  char * c_tmp;
-  while(!snd_card_next(&card_index))
-    {
-    if(card_index > -1)
-      num_cards++;
-    else
-      break;
-    }
-
-  ret->name      = bg_strdup((char*)0, "card");
-  ret->long_name = bg_strdup((char*)0, TRS("Card"));
-  ret->type = BG_PARAMETER_STRINGLIST;
-
-  istart = 1;
-  
-  ret->multi_names   = calloc(num_cards+istart,
-                              sizeof(*(ret->multi_names)));
-  ret->multi_labels   = calloc(num_cards+istart,
-                               sizeof(*(ret->multi_labels)));
-  
-  ret->val_default.val_str = bg_strdup((char*)0, "default");
-
-  ret->multi_labels[0] = bg_strdup((char*)0, TRS("Default"));
-  ret->multi_names[0]  = bg_strdup((char*)0, "default");
-  
-  for(i = istart; i < num_cards; i++)
-    {
-    snd_card_get_name(i-istart, &c_tmp);
-    //    snd_card_get_longname(i, &c_tmp);
-    ret->multi_labels[i] = bg_strdup(NULL, c_tmp);
-    ret->multi_names[i] = bg_sprintf("hw:%d,0", i-1);
-    free(c_tmp);
-    }
-  }
-#endif
