@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -25,6 +25,7 @@
 #include <gmerlin/translation.h>
 
 #include <gmerlin/plugin.h>
+#include <gmerlin/pluginfuncs.h>
 #include <gmerlin/utils.h>
 #include <gmerlin/log.h>
 
@@ -33,25 +34,33 @@
 
 #define LOG_DOMAIN "e_lqt"
 
-#define TEXT_TIME_SCALE GAVL_TIME_SCALE
-// #define TEXT_TIME_SCALE 1000
+#define CODEC_PARAMETER \
+    { \
+      .name =      "codec", \
+      .long_name = TRS("Codec"), \
+    }
 
-static const bg_parameter_info_t stream_parameters[] = 
+
+static const bg_parameter_info_t audio_parameters[] = 
   {
-    {
-      .name =      "codec",
-      .long_name = TRS("Codec"),
-    },
+    CODEC_PARAMETER,
+    { /* End */ }
+  };
+
+static const bg_parameter_info_t video_parameters[] = 
+  {
+    BG_ENCODER_FRAMERATE_PARAMS, /* Must come first (before the codec is set) */
+    CODEC_PARAMETER,
+    { /* End */ }
   };
 
 typedef struct
   {
   int max_riff_size;
   char * filename;
+  char * filename_tmp;
   quicktime_t * file;
   
-  //  bg_parameter_info_t * parameters;
-
   char * audio_codec_name;
   char * video_codec_name;
 
@@ -68,6 +77,8 @@ typedef struct
   /* Needed for calculating the duration of the last chapter */
   gavl_time_t duration;
   
+  bg_encoder_callbacks_t * cb;
+  
   struct
     {
     gavl_audio_format_t format;
@@ -81,6 +92,7 @@ typedef struct
     gavl_video_format_t format;
     uint8_t ** rows;
     lqt_codec_info_t ** codec_info;
+    bg_encoder_framerate_t fr;
     } * video_streams;
   
   struct
@@ -109,6 +121,11 @@ static void * create_lqt()
   return ret;
   }
 
+static void set_callbacks_lqt(void * data, bg_encoder_callbacks_t * cb)
+  {
+  e_lqt_t * e = data;
+  e->cb = cb;
+  }
 
 static const struct
   {
@@ -117,24 +134,22 @@ static const struct
   }
 extensions[] =
   {
-    { LQT_FILE_QT  | LQT_FILE_QT_OLD,      ".mov" },
-    { LQT_FILE_AVI | LQT_FILE_AVI_ODML,    ".avi" },
-    { LQT_FILE_MP4,                        ".mp4" },
-    { LQT_FILE_M4A,                        ".m4a" },
-    { LQT_FILE_3GP,                        ".3gp" },
+    { LQT_FILE_QT  | LQT_FILE_QT_OLD,      "mov" },
+    { LQT_FILE_AVI | LQT_FILE_AVI_ODML,    "avi" },
+    { LQT_FILE_MP4,                        "mp4" },
+    { LQT_FILE_M4A,                        "m4a" },
+    { LQT_FILE_3GP,                        "3gp" },
   };
 
-static const char * get_extension_lqt(void * data)
+static const char * get_extension(int type)
   {
   int i;
-  e_lqt_t * e = (e_lqt_t*)data;
-
   for(i = 0; i < sizeof(extensions)/sizeof(extensions[0]); i++)
     {
-    if(extensions[i].type_mask & e->file_type)
+    if(extensions[i].type_mask & type)
       return extensions[i].extension;
     }
-  return extensions[0].extension; /* ".mov" */
+  return extensions[0].extension; /* "mov" */
   }
 
 static int open_lqt(void * data, const char * filename,
@@ -143,13 +158,26 @@ static int open_lqt(void * data, const char * filename,
   {
   char * track_string;
   e_lqt_t * e = (e_lqt_t*)data;
+
+  e->filename = bg_filename_ensure_extension(filename, get_extension(e->file_type));
+
+  if(!bg_encoder_cb_create_output_file(e->cb, e->filename))
+    return 0;
   
   if(e->make_streamable && !(e->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML)))
-    e->filename = bg_sprintf("%s.tmp", filename);
+    {
+    e->filename_tmp = bg_sprintf("%s.tmp", e->filename);
+    
+    if(!bg_encoder_cb_create_temp_file(e->cb, e->filename_tmp))
+      return 0;
+    
+    e->file = lqt_open_write(e->filename_tmp, e->file_type);
+    }
   else
-    e->filename = bg_strdup(e->filename, filename);
-
-  e->file = lqt_open_write(e->filename, e->file_type);
+    {
+    
+    e->file = lqt_open_write(e->filename, e->file_type);
+    }
   if(!e->file)
     {
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Cannot open file %s", e->filename);
@@ -192,7 +220,7 @@ static int open_lqt(void * data, const char * filename,
   }
 
 static int add_audio_stream_lqt(void * data, const char * language,
-                                gavl_audio_format_t * format)
+                                const gavl_audio_format_t * format)
   {
   e_lqt_t * e = (e_lqt_t*)data;
 
@@ -233,7 +261,7 @@ static int add_subtitle_text_stream_lqt(void * data, const char * language, int
 
 
 static int add_video_stream_lqt(void * data,
-                                gavl_video_format_t* format)
+                                const gavl_video_format_t* format)
   {
   e_lqt_t * e = (e_lqt_t*)data;
 
@@ -323,6 +351,20 @@ static int start_lqt(void * data)
       lqt_set_chapter_track(e->file, e->chapter_track_id);
       }
     }
+  else /* AVI case: Check if QT-only audio codecs were added */
+    {
+    for(i = 0; i < e->num_audio_streams; i++)
+      {
+      if(!e->audio_streams[i].codec_info[0]->wav_ids ||
+         // TODO: Make LQT_WAV_ID_NONE part of the public lqt API
+         (e->audio_streams[i].codec_info[0]->wav_ids[0] == -1)) 
+        {
+        bg_log(BG_LOG_ERROR, LOG_DOMAIN, "Audio codec %s cannot be written to AVI files",
+               e->audio_streams[i].codec_info[0]->name);
+        return 0;
+        }
+      }
+    }
   
   return 1;
   }
@@ -371,6 +413,11 @@ static int write_subtitle_text_lqt(void * data,const char * text,
     bg_log(BG_LOG_ERROR, LOG_DOMAIN, "AVI subtitles not supported");
     return 0;
     }
+
+  //  fprintf(stderr, "write subtitle %"PRId64", %"PRId64", \"%s\"\n",
+  //        start, duration, text);
+          
+
   /* Put empty subtitle if the last end time is not equal to
      this start time */
   if(e->subtitle_text_streams[stream].last_end_time < start)
@@ -391,7 +438,6 @@ static int close_lqt(void * data, int do_delete)
   {
   int i;
   gavl_time_t chapter_time;
-  char * filename_final, *pos;
   int num_chapters;
   e_lqt_t * e = (e_lqt_t*)data;
   
@@ -449,16 +495,12 @@ static int close_lqt(void * data, int do_delete)
   if(do_delete)
     remove(e->filename);
 
-  else if(e->make_streamable && !(e->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML)))
+  else if(e->filename_tmp)
     {
-    filename_final = bg_strdup((char*)0, e->filename);
-    pos = strrchr(filename_final, '.');
-    *pos = '\0';
     bg_log(BG_LOG_INFO, LOG_DOMAIN, "Making streamable....");
-    quicktime_make_streamable(e->filename, filename_final);
+    quicktime_make_streamable(e->filename_tmp, e->filename);
     bg_log(BG_LOG_INFO, LOG_DOMAIN, "Making streamable....done");
-    remove(e->filename);
-    free(filename_final);
+    remove(e->filename_tmp);
     }
   
   if(e->filename)
@@ -466,6 +508,11 @@ static int close_lqt(void * data, int do_delete)
     free(e->filename);
     e->filename = (char*)0;
     }
+  if(e->filename_tmp)
+    {
+    free(e->filename_tmp);
+    e->filename_tmp = (char*)0;
+    }
   if(e->audio_streams)
     {
     for(i = 0; i < e->num_audio_streams; i++)
@@ -510,15 +557,12 @@ static void destroy_lqt(void * data)
 
 static void create_parameters(e_lqt_t * e)
   {
-  e->audio_parameters = calloc(2, sizeof(*(e->audio_parameters)));
-  e->video_parameters = calloc(2, sizeof(*(e->video_parameters)));
-
-  bg_parameter_info_copy(&(e->audio_parameters[0]), &(stream_parameters[0]));
-  bg_parameter_info_copy(&(e->video_parameters[0]), &(stream_parameters[0]));
+  e->audio_parameters = bg_parameter_info_copy_array(audio_parameters);
+  e->video_parameters = bg_parameter_info_copy_array(video_parameters);
   
   bg_lqt_create_codec_info(&(e->audio_parameters[0]),
                            1, 0, 1, 0);
-  bg_lqt_create_codec_info(&(e->video_parameters[0]),
+  bg_lqt_create_codec_info(&(e->video_parameters[2]),
                            0, 1, 1, 0);
   
   }
@@ -654,28 +698,23 @@ static void set_video_parameter_lqt(void * data, int stream, const char * name,
   
   if(!name)
     return;
-
-  
-  if(!strcmp(name, "codec"))
+  else if(bg_encoder_set_framerate_parameter(&e->video_streams[stream].fr,
+                                             name, val))
+    return;
+  else if(!strcmp(name, "codec"))
     {
     /* Now we can add the stream */
 
     e->video_streams[stream].codec_info =
       lqt_find_video_codec_by_name(val->val_str);
     
-    if(e->file_type == LQT_FILE_AVI)
+    if(e->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML))
       {
-      //      e->video_streams[stream].format.image_width *=
-      //        e->video_streams[stream].format.pixel_width;
-      
-      //      e->video_streams[stream].format.image_width /=
-      //        e->video_streams[stream].format.pixel_height;
-
       e->video_streams[stream].format.pixel_width = 1;
       e->video_streams[stream].format.pixel_height = 1;
 
-      //      e->video_streams[stream].format.frame_width =
-      //        e->video_streams[stream].format.image_width;
+      bg_encoder_set_framerate(&e->video_streams[stream].fr,
+                               &e->video_streams[stream].format);
       }
     
     lqt_gavl_add_video_track(e->file, &e->video_streams[stream].format,
@@ -804,12 +843,12 @@ like H.264/AVC, AAC, MP3, Divx compatible etc. Also supported are chapters and t
     .max_video_streams =         -1,
     .max_subtitle_text_streams = -1,
 
+    .set_callbacks =         set_callbacks_lqt,
+    
     .get_audio_parameters =         get_audio_parameters_lqt,
     .get_video_parameters =         get_video_parameters_lqt,
     .get_subtitle_text_parameters = get_subtitle_text_parameters_lqt,
 
-    .get_extension =        get_extension_lqt,
-    
     .open =                 open_lqt,
 
     .add_audio_stream =     add_audio_stream_lqt,
