@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -26,6 +26,7 @@
 #include <config.h>
 #include <gmerlin/translation.h>
 #include <gmerlin/plugin.h>
+#include <gmerlin/pluginfuncs.h>
 #include <gmerlin/utils.h>
 
 #include <png.h>
@@ -46,6 +47,9 @@ typedef struct
   int subtitles_written;
 
   bg_metadata_t metadata;
+
+  bg_encoder_callbacks_t * cb;
+  
   } spumux_t;
 
 static void * create_spumux()
@@ -57,11 +61,10 @@ static void * create_spumux()
   return ret;
   }
 
-static char const * const extension = "xml";
-
-static const char * get_extension_spumux(void * priv)
+static void set_callbacks_spumux(void * data, bg_encoder_callbacks_t * cb)
   {
-  return extension;
+  spumux_t * e = data;
+  e->cb = cb;
   }
 
 static int open_spumux(void * priv, const char * filename,
@@ -74,7 +77,11 @@ static int open_spumux(void * priv, const char * filename,
   if(metadata)
     bg_metadata_copy(&spumux->metadata, metadata);
   
-  spumux->filename = bg_strdup(spumux->filename, filename);
+  spumux->filename = bg_filename_ensure_extension(filename, "xml");
+  
+  if(!bg_encoder_cb_create_output_file(spumux->cb, spumux->filename))
+    return 0;
+  
   spumux->filename_template = bg_strdup(spumux->filename_template, filename);
 
   pos = strrchr(spumux->filename_template, '.');
@@ -82,7 +89,7 @@ static int open_spumux(void * priv, const char * filename,
 
   spumux->filename_template = bg_strcat(spumux->filename_template, "_%05d.png");
   
-  spumux->xml_file = fopen(filename, "w");
+  spumux->xml_file = fopen(spumux->filename, "w");
 
   fprintf(spumux->xml_file, "<subpictures>\n  <stream>\n");
 
@@ -90,7 +97,7 @@ static int open_spumux(void * priv, const char * filename,
   }
 
 static int add_subtitle_overlay_stream_spumux(void * priv, const char * language,
-                                              gavl_video_format_t * format)
+                                              const gavl_video_format_t * format)
   {
   spumux_t * spumux = (spumux_t*)priv;
   gavl_video_format_copy((&spumux->format), format);
@@ -114,7 +121,7 @@ static void get_subtitle_overlay_format_spumux(void * priv, int stream,
 static void print_time(FILE * out, gavl_time_t time, gavl_video_format_t * format)
   {
   int h, m, s, f;
-
+    
   f = gavl_time_to_frames(format->timescale, format->frame_duration, time % GAVL_TIME_SCALE);
   time /= GAVL_TIME_SCALE;
   s = time % 60;
@@ -141,6 +148,12 @@ static int write_subtitle_overlay_spumux(void * priv, gavl_overlay_t * ovl, int
 
   image_filename = bg_sprintf(spumux->filename_template, spumux->subtitles_written);
 
+  if(!bg_encoder_cb_create_output_file(spumux->cb, image_filename))
+    {
+    free(image_filename);
+    return 0;
+    }
+  
   if(!bg_pngwriter_write_header(priv, image_filename,
                                 &tmp_format, &spumux->metadata))
     return 0;
@@ -176,7 +189,7 @@ static int close_spumux(void * priv, int do_delete)
     {
     for(i = 0; i < spumux->subtitles_written; i++)
       {
-      image_filename = bg_sprintf(spumux->filename_template, spumux->subtitles_written);
+      image_filename = bg_sprintf(spumux->filename_template, i);
       remove(image_filename);
       free(image_filename);
       }
@@ -243,7 +256,7 @@ const bg_encoder_plugin_t the_plugin =
 
     .max_subtitle_overlay_streams = 1,
     
-    .get_extension =        get_extension_spumux,
+    .set_callbacks =        set_callbacks_spumux,
     
     .open =                 open_spumux,
 
