@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -1204,7 +1204,7 @@ const bg_recorder_plugin_t the_plugin =
       .long_name =     TRS("V4L2"),
       .description =   TRS("video4linux 2 recording plugin. Supports only video and no tuner decives."),
       .type =          BG_PLUGIN_RECORDER_VIDEO,
-      .flags =         BG_PLUGIN_RECORDER,
+      .flags =         BG_PLUGIN_RECORDER | BG_PLUGIN_DEVPARAM,
       .priority =      BG_PLUGIN_PRIORITY_MAX,
       .create =        create_v4l,
       .destroy =       destroy_v4l,
