@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -55,8 +55,6 @@
 #define ACCEL_DEC_SATURATION    11<<8
 #define ACCEL_INC_CONTRAST      12<<8
 #define ACCEL_DEC_CONTRAST      13<<8
-#define ACCEL_INC_HUE           14<<8
-#define ACCEL_DEC_HUE           15<<8
 #define ACCEL_FIT_WINDOW        16<<8
 #define ACCEL_SHRINK_WINDOW     17<<8
 
@@ -78,8 +76,6 @@ static const bg_accelerator_t accels[] =
     { BG_KEY_S,        BG_KEY_SHIFT_MASK, ACCEL_INC_SATURATION    },
     { BG_KEY_c,                        0, ACCEL_DEC_CONTRAST      },
     { BG_KEY_C,        BG_KEY_SHIFT_MASK, ACCEL_INC_CONTRAST      },
-    { BG_KEY_h,                        0, ACCEL_DEC_HUE           },
-    { BG_KEY_H,        BG_KEY_SHIFT_MASK, ACCEL_INC_HUE           },
     { BG_KEY_NONE,                     0,  0                      },
   };
 
@@ -372,40 +368,6 @@ static int accel_callback(void * data, int id)
           }
         }
       break;
-    case ACCEL_INC_HUE:
-      f_tmp = priv->hue + BG_HUE_DELTA;
-      if(f_tmp > BG_HUE_MAX)
-        f_tmp = BG_HUE_MAX;
-
-      if(bg_x11_window_set_hue(priv->win, f_tmp))
-        {
-        priv->hue = f_tmp;
-        if(priv->callbacks && priv->callbacks->hue_callback)
-          {
-          f_tmp_scaled =
-            (f_tmp-BG_HUE_MIN)/(BG_HUE_MAX - BG_HUE_MIN);
-          priv->callbacks->hue_callback(priv->callbacks->data,
-                                        f_tmp_scaled);
-          }
-        }
-      break;
-    case ACCEL_DEC_HUE:
-      f_tmp = priv->hue - BG_HUE_DELTA;
-      if(f_tmp < BG_HUE_MIN)
-        f_tmp = BG_HUE_MIN;
-
-      if(bg_x11_window_set_hue(priv->win, f_tmp))
-        {
-        priv->hue = f_tmp;
-        if(priv->callbacks && priv->callbacks->hue_callback)
-          {
-          f_tmp_scaled =
-            (f_tmp-BG_HUE_MIN)/(BG_HUE_MAX - BG_HUE_MIN);
-          priv->callbacks->hue_callback(priv->callbacks->data,
-                                        f_tmp_scaled);
-          }
-        }
-      break;
     case ACCEL_FIT_WINDOW:
       if(priv->is_open)
         {
@@ -496,7 +458,7 @@ static int button_callback(void * data, int x, int y, int button, int mask)
     {
     case 4:
       if(!priv->is_open)
-        return 0;
+        break;
       if((mask & BG_KEY_ALT_MASK) == BG_KEY_ALT_MASK)
         {
         /* Increase Zoom */
@@ -518,7 +480,7 @@ static int button_callback(void * data, int x, int y, int button, int mask)
       break;
     case 5:
       if(!priv->is_open)
-        return 0;
+        break;
       if((mask & BG_KEY_ALT_MASK) == BG_KEY_ALT_MASK)
         {
         /* Decrease Zoom */
@@ -550,7 +512,8 @@ static int button_callback(void * data, int x, int y, int button, int mask)
   return 0;
   }
 
-static int button_release_callback(void * data, int x, int y, int button, int mask)
+static int button_release_callback(void * data, int x, int y, int button, 
+                                   int mask)
   {
   x11_t * priv;
   priv = (x11_t *)data;
@@ -590,36 +553,6 @@ static void size_changed(void * data, int width, int height)
   if(priv->is_open)
     set_drawing_coords(priv);
   }
-#if 0
-/* For updating OSD */
-static void brightness_callback(void * data, float val)
-  {
-  x11_t * priv;
-  priv = (x11_t *)data;
-  if(priv->callbacks && priv->callbacks->brightness_callback)
-    priv->callbacks->brightness_callback(priv->callbacks->data,
-                                         val);
-  }
-
-static void saturation_callback(void * data, float val)
-  {
-  x11_t * priv;
-  priv = (x11_t *)data;
-  if(priv->callbacks && priv->callbacks->saturation_callback)
-    priv->callbacks->saturation_callback(priv->callbacks->data,
-                                         val);
- 
-  }
-
-static void contrast_callback(void * data, float val)
-  {
-  x11_t * priv;
-  priv = (x11_t *)data;
-  if(priv->callbacks && priv->callbacks->contrast_callback)
-    priv->callbacks->contrast_callback(priv->callbacks->data,
-                                       val);
-  }
-#endif
 
 static void * create_x11()
   {
@@ -693,15 +626,6 @@ static const bg_parameter_info_t common_parameters[] =
       .val_min =     { .val_f = ZOOM_MIN },
       .val_max =     { .val_f = ZOOM_MAX },
     },
-    {
-      .name =        "hue",
-      .long_name =   "Hue",
-      .type =        BG_PARAMETER_SLIDER_FLOAT,
-      .flags =       BG_PARAMETER_SYNC | BG_PARAMETER_HIDE_DIALOG,
-      .val_default = { .val_f = 0.0 },
-      .val_min =     { .val_f = BG_HUE_MIN },
-      .val_max =     { .val_f = BG_HUE_MAX },
-    },
     {
       .name =        "saturation",
       .long_name =   "Saturation",
@@ -775,11 +699,6 @@ static void set_parameter_x11(void * data,
     if(priv->is_open)
       set_drawing_coords(priv);
     }
-  else if(!strcmp(name, "hue"))
-    {
-    priv->hue = val->val_f;
-    bg_x11_window_set_hue(priv->win, val->val_f);
-    }
   else if(!strcmp(name, "saturation"))
     {
     priv->saturation = val->val_f;
@@ -863,10 +782,23 @@ static const char * get_window_x11(void * data)
 
 static void set_window_title_x11(void * data, const char * title)
   {
-  x11_t * priv = (x11_t*)data;
+  x11_t * priv = data;
   bg_x11_window_set_title(priv->win, title);
   }
 
+static void set_window_options_x11(void * data, 
+                                 const char * name,
+                                 const char * klass,
+                                 const gavl_video_frame_t * icon,
+                                 const gavl_video_format_t * icon_format)
+  {
+  x11_t * priv = data;
+  ensure_window_realized(priv);
+  bg_x11_window_set_options(priv->win, name, klass,
+                            icon, icon_format);
+  }
+
+
 static int open_x11(void * data, gavl_video_format_t * format, int keep_aspect)
   {
   x11_t * priv = (x11_t*)data;
@@ -996,6 +928,7 @@ const bg_ov_plugin_t the_plugin =
     
     .set_window =         set_window_x11,
     .get_window =         get_window_x11,
+    .set_window_options =   set_window_options_x11,
     .set_window_title =   set_window_title_x11,
     .open =               open_x11,
     .create_frame =    create_frame_x11,
