@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -359,7 +359,8 @@ static const bg_parameter_info_t info_3[] =
       .name =               "multilist",
       .long_name =          "Multilist",
       .type =               BG_PARAMETER_MULTI_LIST,
-      .flags =     PARAMETER_FLAGS,
+      .flags =     PARAMETER_FLAGS | BG_PARAMETER_NO_SORT,
+      .val_default = { .val_str = "multilist_1,multilist_2" },
       .multi_names =        (char const *[]){ "multilist_1", "multilist_2", NULL },
       .multi_labels =   (char const *[]){ "Multilist 1", "Multilist 2", NULL },
       .multi_descriptions = (char const *[]){ "Multilist 1", "Multilist 2", NULL },
@@ -631,7 +632,7 @@ int main(int argc, char ** argv)
 
   bg_cmdline_parse(global_options, &argc, &argv, NULL);
     
-  bg_gtk_init(&argc, &argv, (char*)0);
+  bg_gtk_init(&argc, &argv, NULL, NULL, NULL);
 
   
   //  test_dialog = bg_dialog_create(section, set_param, NULL, info, "Test dialog");
