@@ -1,7 +1,7 @@
 /*****************************************************************
  * gmerlin - a general purpose multimedia framework and applications
  *
- * Copyright (c) 2001 - 2008 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2010 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -26,7 +26,8 @@
 
 int main(int argc, char ** argv)
   {
-  bg_gtk_init(&argc, &argv, (char*)0);
+  bg_gtk_init(&argc, &argv, NULL, NULL, NULL);
+  
   bg_gtk_message("Switch coffemachine to backwards\rOr not?", BG_GTK_MESSAGE_ERROR, NULL);
   return 0;
   }
